Class: Aws::MediaLive::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MediaLive::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-medialive/client.rb,
sig/client.rbs
Overview
An API client for MediaLive. To construct a client, you need to configure a :region and :credentials.
client = Aws::MediaLive::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptInputDeviceTransferResponseSuccess, _BatchDeleteResponseSuccess, _BatchStartResponseSuccess, _BatchStopResponseSuccess, _BatchUpdateScheduleResponseSuccess, _CancelInputDeviceTransferResponseSuccess, _ClaimDeviceResponseSuccess, _CreateChannelPlacementGroupResponseSuccess, _CreateChannelResponseSuccess, _CreateCloudWatchAlarmTemplateGroupResponseSuccess, _CreateCloudWatchAlarmTemplateResponseSuccess, _CreateClusterResponseSuccess, _CreateEventBridgeRuleTemplateGroupResponseSuccess, _CreateEventBridgeRuleTemplateResponseSuccess, _CreateInputResponseSuccess, _CreateInputSecurityGroupResponseSuccess, _CreateMultiplexProgramResponseSuccess, _CreateMultiplexResponseSuccess, _CreateNetworkResponseSuccess, _CreateNodeRegistrationScriptResponseSuccess, _CreateNodeResponseSuccess, _CreatePartnerInputResponseSuccess, _CreateSdiSourceResponseSuccess, _CreateSignalMapResponseSuccess, _DeleteChannelPlacementGroupResponseSuccess, _DeleteChannelResponseSuccess, _DeleteClusterResponseSuccess, _DeleteInputResponseSuccess, _DeleteInputSecurityGroupResponseSuccess, _DeleteMultiplexProgramResponseSuccess, _DeleteMultiplexResponseSuccess, _DeleteNetworkResponseSuccess, _DeleteNodeResponseSuccess, _DeleteReservationResponseSuccess, _DeleteScheduleResponseSuccess, _DeleteSdiSourceResponseSuccess, _DescribeAccountConfigurationResponseSuccess, _DescribeChannelPlacementGroupResponseSuccess, _DescribeChannelResponseSuccess, _DescribeClusterResponseSuccess, _DescribeInputDeviceResponseSuccess, _DescribeInputDeviceThumbnailResponseSuccess, _DescribeInputResponseSuccess, _DescribeInputSecurityGroupResponseSuccess, _DescribeMultiplexProgramResponseSuccess, _DescribeMultiplexResponseSuccess, _DescribeNetworkResponseSuccess, _DescribeNodeResponseSuccess, _DescribeOfferingResponseSuccess, _DescribeReservationResponseSuccess, _DescribeScheduleResponseSuccess, _DescribeSdiSourceResponseSuccess, _DescribeThumbnailsResponseSuccess, _GetCloudWatchAlarmTemplateGroupResponseSuccess, _GetCloudWatchAlarmTemplateResponseSuccess, _GetEventBridgeRuleTemplateGroupResponseSuccess, _GetEventBridgeRuleTemplateResponseSuccess, _GetSignalMapResponseSuccess, _ListAlertsResponseSuccess, _ListChannelPlacementGroupsResponseSuccess, _ListChannelsResponseSuccess, _ListCloudWatchAlarmTemplateGroupsResponseSuccess, _ListCloudWatchAlarmTemplatesResponseSuccess, _ListClusterAlertsResponseSuccess, _ListClustersResponseSuccess, _ListEventBridgeRuleTemplateGroupsResponseSuccess, _ListEventBridgeRuleTemplatesResponseSuccess, _ListInputDeviceTransfersResponseSuccess, _ListInputDevicesResponseSuccess, _ListInputSecurityGroupsResponseSuccess, _ListInputsResponseSuccess, _ListMultiplexAlertsResponseSuccess, _ListMultiplexProgramsResponseSuccess, _ListMultiplexesResponseSuccess, _ListNetworksResponseSuccess, _ListNodesResponseSuccess, _ListOfferingsResponseSuccess, _ListReservationsResponseSuccess, _ListSdiSourcesResponseSuccess, _ListSignalMapsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVersionsResponseSuccess, _PurchaseOfferingResponseSuccess, _RebootInputDeviceResponseSuccess, _RejectInputDeviceTransferResponseSuccess, _RestartChannelPipelinesResponseSuccess, _StartChannelResponseSuccess, _StartDeleteMonitorDeploymentResponseSuccess, _StartInputDeviceMaintenanceWindowResponseSuccess, _StartInputDeviceResponseSuccess, _StartMonitorDeploymentResponseSuccess, _StartMultiplexResponseSuccess, _StartUpdateSignalMapResponseSuccess, _StopChannelResponseSuccess, _StopInputDeviceResponseSuccess, _StopMultiplexResponseSuccess, _TransferInputDeviceResponseSuccess, _UpdateAccountConfigurationResponseSuccess, _UpdateChannelClassResponseSuccess, _UpdateChannelPlacementGroupResponseSuccess, _UpdateChannelResponseSuccess, _UpdateCloudWatchAlarmTemplateGroupResponseSuccess, _UpdateCloudWatchAlarmTemplateResponseSuccess, _UpdateClusterResponseSuccess, _UpdateEventBridgeRuleTemplateGroupResponseSuccess, _UpdateEventBridgeRuleTemplateResponseSuccess, _UpdateInputDeviceResponseSuccess, _UpdateInputResponseSuccess, _UpdateInputSecurityGroupResponseSuccess, _UpdateMultiplexProgramResponseSuccess, _UpdateMultiplexResponseSuccess, _UpdateNetworkResponseSuccess, _UpdateNodeResponseSuccess, _UpdateNodeStateResponseSuccess, _UpdateReservationResponseSuccess, _UpdateSdiSourceResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_input_device_transfer(params = {}) ⇒ Struct
Accept an incoming input device transfer.
-
#batch_delete(params = {}) ⇒ Types::BatchDeleteResponse
Starts delete of resources.
-
#batch_start(params = {}) ⇒ Types::BatchStartResponse
Starts existing resources.
-
#batch_stop(params = {}) ⇒ Types::BatchStopResponse
Stops running resources.
-
#batch_update_schedule(params = {}) ⇒ Types::BatchUpdateScheduleResponse
Update a channel schedule.
-
#cancel_input_device_transfer(params = {}) ⇒ Struct
Cancel an input device transfer that you have requested.
-
#claim_device(params = {}) ⇒ Struct
Send a request to claim an AWS Elemental device that you have purchased from a third-party vendor.
-
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a new channel.
-
#create_channel_placement_group(params = {}) ⇒ Types::CreateChannelPlacementGroupResponse
Create a ChannelPlacementGroup in the specified Cluster.
-
#create_cloud_watch_alarm_template(params = {}) ⇒ Types::CreateCloudWatchAlarmTemplateResponse
Creates a cloudwatch alarm template to dynamically generate cloudwatch metric alarms on targeted resource types.
-
#create_cloud_watch_alarm_template_group(params = {}) ⇒ Types::CreateCloudWatchAlarmTemplateGroupResponse
Creates a cloudwatch alarm template group to group your cloudwatch alarm templates and to attach to signal maps for dynamically creating alarms.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Create a new Cluster.
-
#create_event_bridge_rule_template(params = {}) ⇒ Types::CreateEventBridgeRuleTemplateResponse
Creates an eventbridge rule template to monitor events and send notifications to your targeted resources.
-
#create_event_bridge_rule_template_group(params = {}) ⇒ Types::CreateEventBridgeRuleTemplateGroupResponse
Creates an eventbridge rule template group to group your eventbridge rule templates and to attach to signal maps for dynamically creating notification rules.
-
#create_input(params = {}) ⇒ Types::CreateInputResponse
Create an input.
-
#create_input_security_group(params = {}) ⇒ Types::CreateInputSecurityGroupResponse
Creates a Input Security Group.
-
#create_multiplex(params = {}) ⇒ Types::CreateMultiplexResponse
Create a new multiplex.
-
#create_multiplex_program(params = {}) ⇒ Types::CreateMultiplexProgramResponse
Create a new program in the multiplex.
-
#create_network(params = {}) ⇒ Types::CreateNetworkResponse
Create as many Networks as you need.
-
#create_node(params = {}) ⇒ Types::CreateNodeResponse
Create a Node in the specified Cluster.
-
#create_node_registration_script(params = {}) ⇒ Types::CreateNodeRegistrationScriptResponse
Create the Register Node script for all the nodes intended for a specific Cluster.
-
#create_partner_input(params = {}) ⇒ Types::CreatePartnerInputResponse
Create a partner input.
-
#create_sdi_source(params = {}) ⇒ Types::CreateSdiSourceResponse
Create an SdiSource for each video source that uses the SDI protocol.
-
#create_signal_map(params = {}) ⇒ Types::CreateSignalMapResponse
Initiates the creation of a new signal map.
-
#create_tags(params = {}) ⇒ Struct
Create tags for a resource.
-
#delete_channel(params = {}) ⇒ Types::DeleteChannelResponse
Starts deletion of channel.
-
#delete_channel_placement_group(params = {}) ⇒ Types::DeleteChannelPlacementGroupResponse
Delete the specified ChannelPlacementGroup that exists in the specified Cluster.
-
#delete_cloud_watch_alarm_template(params = {}) ⇒ Struct
Deletes a cloudwatch alarm template.
-
#delete_cloud_watch_alarm_template_group(params = {}) ⇒ Struct
Deletes a cloudwatch alarm template group.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Delete a Cluster.
-
#delete_event_bridge_rule_template(params = {}) ⇒ Struct
Deletes an eventbridge rule template.
-
#delete_event_bridge_rule_template_group(params = {}) ⇒ Struct
Deletes an eventbridge rule template group.
-
#delete_input(params = {}) ⇒ Struct
Deletes the input end point.
-
#delete_input_security_group(params = {}) ⇒ Struct
Deletes an Input Security Group.
-
#delete_multiplex(params = {}) ⇒ Types::DeleteMultiplexResponse
Delete a multiplex.
-
#delete_multiplex_program(params = {}) ⇒ Types::DeleteMultiplexProgramResponse
Delete a program from a multiplex.
-
#delete_network(params = {}) ⇒ Types::DeleteNetworkResponse
Delete a Network.
-
#delete_node(params = {}) ⇒ Types::DeleteNodeResponse
Delete a Node.
-
#delete_reservation(params = {}) ⇒ Types::DeleteReservationResponse
Delete an expired reservation.
-
#delete_schedule(params = {}) ⇒ Struct
Delete all schedule actions on a channel.
-
#delete_sdi_source(params = {}) ⇒ Types::DeleteSdiSourceResponse
Delete an SdiSource.
-
#delete_signal_map(params = {}) ⇒ Struct
Deletes the specified signal map.
-
#delete_tags(params = {}) ⇒ Struct
Removes tags for a resource.
-
#describe_account_configuration(params = {}) ⇒ Types::DescribeAccountConfigurationResponse
Describe account configuration.
-
#describe_channel(params = {}) ⇒ Types::DescribeChannelResponse
Gets details about a channel.
-
#describe_channel_placement_group(params = {}) ⇒ Types::DescribeChannelPlacementGroupResponse
Get details about a ChannelPlacementGroup.
-
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Get details about a Cluster.
-
#describe_input(params = {}) ⇒ Types::DescribeInputResponse
Produces details about an input.
-
#describe_input_device(params = {}) ⇒ Types::DescribeInputDeviceResponse
Gets the details for the input device.
-
#describe_input_device_thumbnail(params = {}) ⇒ Types::DescribeInputDeviceThumbnailResponse
Get the latest thumbnail data for the input device.
-
#describe_input_security_group(params = {}) ⇒ Types::DescribeInputSecurityGroupResponse
Produces a summary of an Input Security Group.
-
#describe_multiplex(params = {}) ⇒ Types::DescribeMultiplexResponse
Gets details about a multiplex.
-
#describe_multiplex_program(params = {}) ⇒ Types::DescribeMultiplexProgramResponse
Get the details for a program in a multiplex.
-
#describe_network(params = {}) ⇒ Types::DescribeNetworkResponse
Get details about a Network.
-
#describe_node(params = {}) ⇒ Types::DescribeNodeResponse
Get details about a Node in the specified Cluster.
-
#describe_offering(params = {}) ⇒ Types::DescribeOfferingResponse
Get details for an offering.
-
#describe_reservation(params = {}) ⇒ Types::DescribeReservationResponse
Get details for a reservation.
-
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Get a channel schedule.
-
#describe_sdi_source(params = {}) ⇒ Types::DescribeSdiSourceResponse
Gets details about a SdiSource.
-
#describe_thumbnails(params = {}) ⇒ Types::DescribeThumbnailsResponse
Describe the latest thumbnails data.
-
#get_cloud_watch_alarm_template(params = {}) ⇒ Types::GetCloudWatchAlarmTemplateResponse
Retrieves the specified cloudwatch alarm template.
-
#get_cloud_watch_alarm_template_group(params = {}) ⇒ Types::GetCloudWatchAlarmTemplateGroupResponse
Retrieves the specified cloudwatch alarm template group.
-
#get_event_bridge_rule_template(params = {}) ⇒ Types::GetEventBridgeRuleTemplateResponse
Retrieves the specified eventbridge rule template.
-
#get_event_bridge_rule_template_group(params = {}) ⇒ Types::GetEventBridgeRuleTemplateGroupResponse
Retrieves the specified eventbridge rule template group.
-
#get_signal_map(params = {}) ⇒ Types::GetSignalMapResponse
Retrieves the specified signal map.
-
#list_alerts(params = {}) ⇒ Types::ListAlertsResponse
List the alerts for a channel with optional filtering based on alert state.
-
#list_channel_placement_groups(params = {}) ⇒ Types::ListChannelPlacementGroupsResponse
Retrieve the list of ChannelPlacementGroups in the specified Cluster.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Produces list of channels that have been created.
-
#list_cloud_watch_alarm_template_groups(params = {}) ⇒ Types::ListCloudWatchAlarmTemplateGroupsResponse
Lists cloudwatch alarm template groups.
-
#list_cloud_watch_alarm_templates(params = {}) ⇒ Types::ListCloudWatchAlarmTemplatesResponse
Lists cloudwatch alarm templates.
-
#list_cluster_alerts(params = {}) ⇒ Types::ListClusterAlertsResponse
List the alerts for a cluster with optional filtering based on alert state.
-
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Retrieve the list of Clusters.
-
#list_event_bridge_rule_template_groups(params = {}) ⇒ Types::ListEventBridgeRuleTemplateGroupsResponse
Lists eventbridge rule template groups.
-
#list_event_bridge_rule_templates(params = {}) ⇒ Types::ListEventBridgeRuleTemplatesResponse
Lists eventbridge rule templates.
-
#list_input_device_transfers(params = {}) ⇒ Types::ListInputDeviceTransfersResponse
List input devices that are currently being transferred.
-
#list_input_devices(params = {}) ⇒ Types::ListInputDevicesResponse
List input devices.
-
#list_input_security_groups(params = {}) ⇒ Types::ListInputSecurityGroupsResponse
Produces a list of Input Security Groups for an account.
-
#list_inputs(params = {}) ⇒ Types::ListInputsResponse
Produces list of inputs that have been created.
-
#list_multiplex_alerts(params = {}) ⇒ Types::ListMultiplexAlertsResponse
List the alerts for a multiplex with optional filtering based on alert state.
-
#list_multiplex_programs(params = {}) ⇒ Types::ListMultiplexProgramsResponse
List the programs that currently exist for a specific multiplex.
-
#list_multiplexes(params = {}) ⇒ Types::ListMultiplexesResponse
Retrieve a list of the existing multiplexes.
-
#list_networks(params = {}) ⇒ Types::ListNetworksResponse
Retrieve the list of Networks.
-
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Retrieve the list of Nodes.
-
#list_offerings(params = {}) ⇒ Types::ListOfferingsResponse
List offerings available for purchase.
-
#list_reservations(params = {}) ⇒ Types::ListReservationsResponse
List purchased reservations.
-
#list_sdi_sources(params = {}) ⇒ Types::ListSdiSourcesResponse
List all the SdiSources in the AWS account.
-
#list_signal_maps(params = {}) ⇒ Types::ListSignalMapsResponse
Lists signal maps.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Produces list of tags that have been created for a resource.
-
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Retrieves an array of all the encoder engine versions that are available in this AWS account.
-
#purchase_offering(params = {}) ⇒ Types::PurchaseOfferingResponse
Purchase an offering and create a reservation.
-
#reboot_input_device(params = {}) ⇒ Struct
Send a reboot command to the specified input device.
-
#reject_input_device_transfer(params = {}) ⇒ Struct
Reject the transfer of the specified input device to your AWS account.
-
#restart_channel_pipelines(params = {}) ⇒ Types::RestartChannelPipelinesResponse
Restart pipelines in one channel that is currently running.
-
#start_channel(params = {}) ⇒ Types::StartChannelResponse
Starts an existing channel.
-
#start_delete_monitor_deployment(params = {}) ⇒ Types::StartDeleteMonitorDeploymentResponse
Initiates a deployment to delete the monitor of the specified signal map.
-
#start_input_device(params = {}) ⇒ Struct
Start an input device that is attached to a MediaConnect flow.
-
#start_input_device_maintenance_window(params = {}) ⇒ Struct
Start a maintenance window for the specified input device.
-
#start_monitor_deployment(params = {}) ⇒ Types::StartMonitorDeploymentResponse
Initiates a deployment to deploy the latest monitor of the specified signal map.
-
#start_multiplex(params = {}) ⇒ Types::StartMultiplexResponse
Start (run) the multiplex.
-
#start_update_signal_map(params = {}) ⇒ Types::StartUpdateSignalMapResponse
Initiates an update for the specified signal map.
-
#stop_channel(params = {}) ⇒ Types::StopChannelResponse
Stops a running channel.
-
#stop_input_device(params = {}) ⇒ Struct
Stop an input device that is attached to a MediaConnect flow.
-
#stop_multiplex(params = {}) ⇒ Types::StopMultiplexResponse
Stops a running multiplex.
-
#transfer_input_device(params = {}) ⇒ Struct
Start an input device transfer to another AWS account.
-
#update_account_configuration(params = {}) ⇒ Types::UpdateAccountConfigurationResponse
Update account configuration.
-
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel.
-
#update_channel_class(params = {}) ⇒ Types::UpdateChannelClassResponse
Changes the class of the channel.
-
#update_channel_placement_group(params = {}) ⇒ Types::UpdateChannelPlacementGroupResponse
Change the settings for a ChannelPlacementGroup.
-
#update_cloud_watch_alarm_template(params = {}) ⇒ Types::UpdateCloudWatchAlarmTemplateResponse
Updates the specified cloudwatch alarm template.
-
#update_cloud_watch_alarm_template_group(params = {}) ⇒ Types::UpdateCloudWatchAlarmTemplateGroupResponse
Updates the specified cloudwatch alarm template group.
-
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Change the settings for a Cluster.
-
#update_event_bridge_rule_template(params = {}) ⇒ Types::UpdateEventBridgeRuleTemplateResponse
Updates the specified eventbridge rule template.
-
#update_event_bridge_rule_template_group(params = {}) ⇒ Types::UpdateEventBridgeRuleTemplateGroupResponse
Updates the specified eventbridge rule template group.
-
#update_input(params = {}) ⇒ Types::UpdateInputResponse
Updates an input.
-
#update_input_device(params = {}) ⇒ Types::UpdateInputDeviceResponse
Updates the parameters for the input device.
-
#update_input_security_group(params = {}) ⇒ Types::UpdateInputSecurityGroupResponse
Update an Input Security Group's Whilelists.
-
#update_multiplex(params = {}) ⇒ Types::UpdateMultiplexResponse
Updates a multiplex.
-
#update_multiplex_program(params = {}) ⇒ Types::UpdateMultiplexProgramResponse
Update a program in a multiplex.
-
#update_network(params = {}) ⇒ Types::UpdateNetworkResponse
Change the settings for a Network.
-
#update_node(params = {}) ⇒ Types::UpdateNodeResponse
Change the settings for a Node.
-
#update_node_state(params = {}) ⇒ Types::UpdateNodeStateResponse
Update the state of a node.
-
#update_reservation(params = {}) ⇒ Types::UpdateReservationResponse
Update reservation.
-
#update_sdi_source(params = {}) ⇒ Types::UpdateSdiSourceResponse
Change some of the settings in an SdiSource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-medialive/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8285 8286 8287 |
# File 'lib/aws-sdk-medialive/client.rb', line 8285 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8288 8289 8290 |
# File 'lib/aws-sdk-medialive/client.rb', line 8288 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#accept_input_device_transfer(params = {}) ⇒ Struct
Accept an incoming input device transfer. The ownership of the device will transfer to your AWS account.
85 |
# File 'sig/client.rbs', line 85 def accept_input_device_transfer: ( |
#batch_delete(params = {}) ⇒ Types::BatchDeleteResponse
Starts delete of resources.
96 |
# File 'sig/client.rbs', line 96 def batch_delete: ( |
#batch_start(params = {}) ⇒ Types::BatchStartResponse
Starts existing resources
110 |
# File 'sig/client.rbs', line 110 def batch_start: ( |
#batch_stop(params = {}) ⇒ Types::BatchStopResponse
Stops running resources
122 |
# File 'sig/client.rbs', line 122 def batch_stop: ( |
#batch_update_schedule(params = {}) ⇒ Types::BatchUpdateScheduleResponse
Update a channel schedule
134 |
# File 'sig/client.rbs', line 134 def batch_update_schedule: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 8115 8116 8117 8118 8119 |
# File 'lib/aws-sdk-medialive/client.rb', line 8103 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MediaLive') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-medialive' context[:gem_version] = '1.197.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_input_device_transfer(params = {}) ⇒ Struct
Cancel an input device transfer that you have requested.
284 |
# File 'sig/client.rbs', line 284 def cancel_input_device_transfer: ( |
#claim_device(params = {}) ⇒ Struct
Send a request to claim an AWS Elemental device that you have purchased from a third-party vendor. After the request succeeds, you will own the device.
293 |
# File 'sig/client.rbs', line 293 def claim_device: ( |
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a new channel
303 |
# File 'sig/client.rbs', line 303 def create_channel: ( |
#create_channel_placement_group(params = {}) ⇒ Types::CreateChannelPlacementGroupResponse
Create a ChannelPlacementGroup in the specified Cluster. As part of the create operation, you specify the Nodes to attach the group to.After you create a ChannelPlacementGroup, you add Channels to the group (you do this by modifying the Channels to add them to a specific group). You now have an association of Channels to ChannelPlacementGroup, and ChannelPlacementGroup to Nodes. This association means that all the Channels in the group are able to run on any of the Nodes associated with the group.
1959 |
# File 'sig/client.rbs', line 1959 def create_channel_placement_group: ( |
#create_cloud_watch_alarm_template(params = {}) ⇒ Types::CreateCloudWatchAlarmTemplateResponse
Creates a cloudwatch alarm template to dynamically generate cloudwatch metric alarms on targeted resource types.
1438 |
# File 'sig/client.rbs', line 1438 def create_cloud_watch_alarm_template: ( |
#create_cloud_watch_alarm_template_group(params = {}) ⇒ Types::CreateCloudWatchAlarmTemplateGroupResponse
Creates a cloudwatch alarm template group to group your cloudwatch alarm templates and to attach to signal maps for dynamically creating alarms.
1467 |
# File 'sig/client.rbs', line 1467 def create_cloud_watch_alarm_template_group: ( |
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Create a new Cluster.
1980 |
# File 'sig/client.rbs', line 1980 def create_cluster: ( |
#create_event_bridge_rule_template(params = {}) ⇒ Types::CreateEventBridgeRuleTemplateResponse
Creates an eventbridge rule template to monitor events and send notifications to your targeted resources.
1489 |
# File 'sig/client.rbs', line 1489 def create_event_bridge_rule_template: ( |
#create_event_bridge_rule_template_group(params = {}) ⇒ Types::CreateEventBridgeRuleTemplateGroupResponse
Creates an eventbridge rule template group to group your eventbridge rule templates and to attach to signal maps for dynamically creating notification rules.
1515 |
# File 'sig/client.rbs', line 1515 def create_event_bridge_rule_template_group: ( |
#create_input(params = {}) ⇒ Types::CreateInputResponse
Create an input
354 |
# File 'sig/client.rbs', line 354 def create_input: ( |
#create_input_security_group(params = {}) ⇒ Types::CreateInputSecurityGroupResponse
Creates a Input Security Group
414 |
# File 'sig/client.rbs', line 414 def create_input_security_group: ( |
#create_multiplex(params = {}) ⇒ Types::CreateMultiplexResponse
Create a new multiplex.
429 |
# File 'sig/client.rbs', line 429 def create_multiplex: ( |
#create_multiplex_program(params = {}) ⇒ Types::CreateMultiplexProgramResponse
Create a new program in the multiplex.
448 |
# File 'sig/client.rbs', line 448 def create_multiplex_program: ( |
#create_network(params = {}) ⇒ Types::CreateNetworkResponse
Create as many Networks as you need. You will associate one or more Clusters with each Network.Each Network provides MediaLive Anywhere with required information about the network in your organization that you are using for video encoding using MediaLive.
2009 |
# File 'sig/client.rbs', line 2009 def create_network: ( |
#create_node(params = {}) ⇒ Types::CreateNodeResponse
Create a Node in the specified Cluster. You can also create Nodes using the CreateNodeRegistrationScript. Note that you can't move a Node to another Cluster.
2042 |
# File 'sig/client.rbs', line 2042 def create_node: ( |
#create_node_registration_script(params = {}) ⇒ Types::CreateNodeRegistrationScriptResponse
Create the Register Node script for all the nodes intended for a specific Cluster. You will then run the script on each hardware unit that is intended for that Cluster. The script creates a Node in the specified Cluster. It then binds the Node to this hardware unit, and activates the node hardware for use with MediaLive Anywhere.
2063 |
# File 'sig/client.rbs', line 2063 def create_node_registration_script: ( |
#create_partner_input(params = {}) ⇒ Types::CreatePartnerInputResponse
Create a partner input
461 |
# File 'sig/client.rbs', line 461 def create_partner_input: ( |
#create_sdi_source(params = {}) ⇒ Types::CreateSdiSourceResponse
Create an SdiSource for each video source that uses the SDI protocol. You will reference the SdiSource when you create an SDI input in MediaLive. You will also reference it in an SdiSourceMapping, in order to create a connection between the logical SdiSource and the physical SDI card and port that the physical SDI source uses.
2411 |
# File 'sig/client.rbs', line 2411 def create_sdi_source: ( |
#create_signal_map(params = {}) ⇒ Types::CreateSignalMapResponse
Initiates the creation of a new signal map. Will discover a new mediaResourceMap based on the provided discoveryEntryPointArn.
1545 |
# File 'sig/client.rbs', line 1545 def create_signal_map: ( |
#create_tags(params = {}) ⇒ Struct
Create tags for a resource
469 |
# File 'sig/client.rbs', line 469 def create_tags: ( |
#delete_channel(params = {}) ⇒ Types::DeleteChannelResponse
Starts deletion of channel. The associated outputs are also deleted.
502 |
# File 'sig/client.rbs', line 502 def delete_channel: ( |
#delete_channel_placement_group(params = {}) ⇒ Types::DeleteChannelPlacementGroupResponse
Delete the specified ChannelPlacementGroup that exists in the specified Cluster.
2091 |
# File 'sig/client.rbs', line 2091 def delete_channel_placement_group: ( |
#delete_cloud_watch_alarm_template(params = {}) ⇒ Struct
Deletes a cloudwatch alarm template.
1557 |
# File 'sig/client.rbs', line 1557 def delete_cloud_watch_alarm_template: ( |
#delete_cloud_watch_alarm_template_group(params = {}) ⇒ Struct
Deletes a cloudwatch alarm template group. You must detach this group from all signal maps and ensure its existing templates are moved to another group or deleted.
1563 |
# File 'sig/client.rbs', line 1563 def delete_cloud_watch_alarm_template_group: ( |
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Delete a Cluster. The Cluster must be idle.
2109 |
# File 'sig/client.rbs', line 2109 def delete_cluster: ( |
#delete_event_bridge_rule_template(params = {}) ⇒ Struct
Deletes an eventbridge rule template.
1569 |
# File 'sig/client.rbs', line 1569 def delete_event_bridge_rule_template: ( |
#delete_event_bridge_rule_template_group(params = {}) ⇒ Struct
Deletes an eventbridge rule template group. You must detach this group from all signal maps and ensure its existing templates are moved to another group or deleted.
1575 |
# File 'sig/client.rbs', line 1575 def delete_event_bridge_rule_template_group: ( |
#delete_input(params = {}) ⇒ Struct
Deletes the input end point
511 |
# File 'sig/client.rbs', line 511 def delete_input: ( |
#delete_input_security_group(params = {}) ⇒ Struct
Deletes an Input Security Group
520 |
# File 'sig/client.rbs', line 520 def delete_input_security_group: ( |
#delete_multiplex(params = {}) ⇒ Types::DeleteMultiplexResponse
Delete a multiplex. The multiplex must be idle.
539 |
# File 'sig/client.rbs', line 539 def delete_multiplex: ( |
#delete_multiplex_program(params = {}) ⇒ Types::DeleteMultiplexProgramResponse
Delete a program from a multiplex.
553 |
# File 'sig/client.rbs', line 553 def delete_multiplex_program: ( |
#delete_network(params = {}) ⇒ Types::DeleteNetworkResponse
Delete a Network. The Network must have no resources associated with it.
2125 |
# File 'sig/client.rbs', line 2125 def delete_network: ( |
#delete_node(params = {}) ⇒ Types::DeleteNodeResponse
Delete a Node. The Node must be IDLE.
2145 |
# File 'sig/client.rbs', line 2145 def delete_node: ( |
#delete_reservation(params = {}) ⇒ Types::DeleteReservationResponse
Delete an expired reservation.
582 |
# File 'sig/client.rbs', line 582 def delete_reservation: ( |
#delete_schedule(params = {}) ⇒ Struct
Delete all schedule actions on a channel.
591 |
# File 'sig/client.rbs', line 591 def delete_schedule: ( |
#delete_sdi_source(params = {}) ⇒ Types::DeleteSdiSourceResponse
Delete an SdiSource. The SdiSource must not be part of any SidSourceMapping and must not be attached to any input.
2425 |
# File 'sig/client.rbs', line 2425 def delete_sdi_source: ( |
#delete_signal_map(params = {}) ⇒ Struct
Deletes the specified signal map.
1581 |
# File 'sig/client.rbs', line 1581 def delete_signal_map: ( |
#delete_tags(params = {}) ⇒ Struct
Removes tags for a resource
597 |
# File 'sig/client.rbs', line 597 def delete_tags: ( |
#describe_account_configuration(params = {}) ⇒ Types::DescribeAccountConfigurationResponse
Describe account configuration
608 |
# File 'sig/client.rbs', line 608 def describe_account_configuration: ( |
#describe_channel(params = {}) ⇒ Types::DescribeChannelResponse
Gets details about a channel
The following waiters are defined for this operation (see #wait_until for detailed usage):
* channel_created
* channel_deleted
* channel_running
* channel_stopped
639 |
# File 'sig/client.rbs', line 639 def describe_channel: ( |
#describe_channel_placement_group(params = {}) ⇒ Types::DescribeChannelPlacementGroupResponse
Get details about a ChannelPlacementGroup.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* channel_placement_group_assigned
* channel_placement_group_deleted
* channel_placement_group_unassigned
2162 |
# File 'sig/client.rbs', line 2162 def describe_channel_placement_group: ( |
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Get details about a Cluster.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* cluster_created
* cluster_deleted
2180 |
# File 'sig/client.rbs', line 2180 def describe_cluster: ( |
#describe_input(params = {}) ⇒ Types::DescribeInputResponse
Produces details about an input
The following waiters are defined for this operation (see #wait_until for detailed usage):
* input_attached
* input_deleted
* input_detached
670 |
# File 'sig/client.rbs', line 670 def describe_input: ( |
#describe_input_device(params = {}) ⇒ Types::DescribeInputDeviceResponse
Gets the details for the input device
695 |
# File 'sig/client.rbs', line 695 def describe_input_device: ( |
#describe_input_device_thumbnail(params = {}) ⇒ Types::DescribeInputDeviceThumbnailResponse
Get the latest thumbnail data for the input device.
709 |
# File 'sig/client.rbs', line 709 def describe_input_device_thumbnail: ( |
#describe_input_security_group(params = {}) ⇒ Types::DescribeInputSecurityGroupResponse
Produces a summary of an Input Security Group
726 |
# File 'sig/client.rbs', line 726 def describe_input_security_group: ( |
#describe_multiplex(params = {}) ⇒ Types::DescribeMultiplexResponse
Gets details about a multiplex.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* multiplex_created
* multiplex_deleted
* multiplex_running
* multiplex_stopped
745 |
# File 'sig/client.rbs', line 745 def describe_multiplex: ( |
#describe_multiplex_program(params = {}) ⇒ Types::DescribeMultiplexProgramResponse
Get the details for a program in a multiplex.
759 |
# File 'sig/client.rbs', line 759 def describe_multiplex_program: ( |
#describe_network(params = {}) ⇒ Types::DescribeNetworkResponse
Get details about a Network.
2196 |
# File 'sig/client.rbs', line 2196 def describe_network: ( |
#describe_node(params = {}) ⇒ Types::DescribeNodeResponse
Get details about a Node in the specified Cluster.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* node_deregistered
* node_registered
2216 |
# File 'sig/client.rbs', line 2216 def describe_node: ( |
#describe_offering(params = {}) ⇒ Types::DescribeOfferingResponse
Get details for an offering.
780 |
# File 'sig/client.rbs', line 780 def describe_offering: ( |
#describe_reservation(params = {}) ⇒ Types::DescribeReservationResponse
Get details for a reservation.
808 |
# File 'sig/client.rbs', line 808 def describe_reservation: ( |
#describe_schedule(params = {}) ⇒ Types::DescribeScheduleResponse
Get a channel schedule
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
819 |
# File 'sig/client.rbs', line 819 def describe_schedule: ( |
#describe_sdi_source(params = {}) ⇒ Types::DescribeSdiSourceResponse
Gets details about a SdiSource.
2435 |
# File 'sig/client.rbs', line 2435 def describe_sdi_source: ( |
#describe_thumbnails(params = {}) ⇒ Types::DescribeThumbnailsResponse
Describe the latest thumbnails data.
831 |
# File 'sig/client.rbs', line 831 def describe_thumbnails: ( |
#get_cloud_watch_alarm_template(params = {}) ⇒ Types::GetCloudWatchAlarmTemplateResponse
Retrieves the specified cloudwatch alarm template.
1607 |
# File 'sig/client.rbs', line 1607 def get_cloud_watch_alarm_template: ( |
#get_cloud_watch_alarm_template_group(params = {}) ⇒ Types::GetCloudWatchAlarmTemplateGroupResponse
Retrieves the specified cloudwatch alarm template group.
1623 |
# File 'sig/client.rbs', line 1623 def get_cloud_watch_alarm_template_group: ( |
#get_event_bridge_rule_template(params = {}) ⇒ Types::GetEventBridgeRuleTemplateResponse
Retrieves the specified eventbridge rule template.
1642 |
# File 'sig/client.rbs', line 1642 def get_event_bridge_rule_template: ( |
#get_event_bridge_rule_template_group(params = {}) ⇒ Types::GetEventBridgeRuleTemplateGroupResponse
Retrieves the specified eventbridge rule template group.
1658 |
# File 'sig/client.rbs', line 1658 def get_event_bridge_rule_template_group: ( |
#get_signal_map(params = {}) ⇒ Types::GetSignalMapResponse
Retrieves the specified signal map.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* signal_map_created
* signal_map_monitor_deleted
* signal_map_monitor_deployed
* signal_map_updated
1685 |
# File 'sig/client.rbs', line 1685 def get_signal_map: ( |
#list_alerts(params = {}) ⇒ Types::ListAlertsResponse
List the alerts for a channel with optional filtering based on alert state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2471 |
# File 'sig/client.rbs', line 2471 def list_alerts: ( |
#list_channel_placement_groups(params = {}) ⇒ Types::ListChannelPlacementGroupsResponse
Retrieve the list of ChannelPlacementGroups in the specified Cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2228 |
# File 'sig/client.rbs', line 2228 def list_channel_placement_groups: ( |
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Produces list of channels that have been created
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
844 |
# File 'sig/client.rbs', line 844 def list_channels: ( |
#list_cloud_watch_alarm_template_groups(params = {}) ⇒ Types::ListCloudWatchAlarmTemplateGroupsResponse
Lists cloudwatch alarm template groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1696 |
# File 'sig/client.rbs', line 1696 def list_cloud_watch_alarm_template_groups: ( |
#list_cloud_watch_alarm_templates(params = {}) ⇒ Types::ListCloudWatchAlarmTemplatesResponse
Lists cloudwatch alarm templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1710 |
# File 'sig/client.rbs', line 1710 def list_cloud_watch_alarm_templates: ( |
#list_cluster_alerts(params = {}) ⇒ Types::ListClusterAlertsResponse
List the alerts for a cluster with optional filtering based on alert state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2485 |
# File 'sig/client.rbs', line 2485 def list_cluster_alerts: ( |
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Retrieve the list of Clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2241 |
# File 'sig/client.rbs', line 2241 def list_clusters: ( |
#list_event_bridge_rule_template_groups(params = {}) ⇒ Types::ListEventBridgeRuleTemplateGroupsResponse
Lists eventbridge rule template groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1725 |
# File 'sig/client.rbs', line 1725 def list_event_bridge_rule_template_groups: ( |
#list_event_bridge_rule_templates(params = {}) ⇒ Types::ListEventBridgeRuleTemplatesResponse
Lists eventbridge rule templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1738 |
# File 'sig/client.rbs', line 1738 def list_event_bridge_rule_templates: ( |
#list_input_device_transfers(params = {}) ⇒ Types::ListInputDeviceTransfersResponse
List input devices that are currently being transferred. List input devices that you are transferring from your AWS account or input devices that another AWS account is transferring to you.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
856 |
# File 'sig/client.rbs', line 856 def list_input_device_transfers: ( |
#list_input_devices(params = {}) ⇒ Types::ListInputDevicesResponse
List input devices
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
869 |
# File 'sig/client.rbs', line 869 def list_input_devices: ( |
#list_input_security_groups(params = {}) ⇒ Types::ListInputSecurityGroupsResponse
Produces a list of Input Security Groups for an account
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
881 |
# File 'sig/client.rbs', line 881 def list_input_security_groups: ( |
#list_inputs(params = {}) ⇒ Types::ListInputsResponse
Produces list of inputs that have been created
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
893 |
# File 'sig/client.rbs', line 893 def list_inputs: ( |
#list_multiplex_alerts(params = {}) ⇒ Types::ListMultiplexAlertsResponse
List the alerts for a multiplex with optional filtering based on alert state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2499 |
# File 'sig/client.rbs', line 2499 def list_multiplex_alerts: ( |
#list_multiplex_programs(params = {}) ⇒ Types::ListMultiplexProgramsResponse
List the programs that currently exist for a specific multiplex.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
905 |
# File 'sig/client.rbs', line 905 def list_multiplex_programs: ( |
#list_multiplexes(params = {}) ⇒ Types::ListMultiplexesResponse
Retrieve a list of the existing multiplexes.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
918 |
# File 'sig/client.rbs', line 918 def list_multiplexes: ( |
#list_networks(params = {}) ⇒ Types::ListNetworksResponse
Retrieve the list of Networks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2253 |
# File 'sig/client.rbs', line 2253 def list_networks: ( |
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Retrieve the list of Nodes.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2265 |
# File 'sig/client.rbs', line 2265 def list_nodes: ( |
#list_offerings(params = {}) ⇒ Types::ListOfferingsResponse
List offerings available for purchase.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
930 |
# File 'sig/client.rbs', line 930 def list_offerings: ( |
#list_reservations(params = {}) ⇒ Types::ListReservationsResponse
List purchased reservations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
952 |
# File 'sig/client.rbs', line 952 def list_reservations: ( |
#list_sdi_sources(params = {}) ⇒ Types::ListSdiSourcesResponse
List all the SdiSources in the AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2446 |
# File 'sig/client.rbs', line 2446 def list_sdi_sources: ( |
#list_signal_maps(params = {}) ⇒ Types::ListSignalMapsResponse
Lists signal maps.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1752 |
# File 'sig/client.rbs', line 1752 def list_signal_maps: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Produces list of tags that have been created for a resource
971 |
# File 'sig/client.rbs', line 971 def list_tags_for_resource: ( |
#list_versions(params = {}) ⇒ Types::ListVersionsResponse
Retrieves an array of all the encoder engine versions that are available in this AWS account.
2402 |
# File 'sig/client.rbs', line 2402 def list_versions: ( |
#purchase_offering(params = {}) ⇒ Types::PurchaseOfferingResponse
Purchase an offering and create a reservation.
981 |
# File 'sig/client.rbs', line 981 def purchase_offering: ( |
#reboot_input_device(params = {}) ⇒ Struct
Send a reboot command to the specified input device. The device will begin rebooting within a few seconds of sending the command. When the reboot is complete, the device’s connection status will change to connected.
999 |
# File 'sig/client.rbs', line 999 def reboot_input_device: ( |
#reject_input_device_transfer(params = {}) ⇒ Struct
Reject the transfer of the specified input device to your AWS account.
1009 |
# File 'sig/client.rbs', line 1009 def reject_input_device_transfer: ( |
#restart_channel_pipelines(params = {}) ⇒ Types::RestartChannelPipelinesResponse
Restart pipelines in one channel that is currently running.
1411 |
# File 'sig/client.rbs', line 1411 def restart_channel_pipelines: ( |
#start_channel(params = {}) ⇒ Types::StartChannelResponse
Starts an existing channel
1041 |
# File 'sig/client.rbs', line 1041 def start_channel: ( |
#start_delete_monitor_deployment(params = {}) ⇒ Types::StartDeleteMonitorDeploymentResponse
Initiates a deployment to delete the monitor of the specified signal map.
1782 |
# File 'sig/client.rbs', line 1782 def start_delete_monitor_deployment: ( |
#start_input_device(params = {}) ⇒ Struct
Start an input device that is attached to a MediaConnect flow. (There is no need to start a device that is attached to a MediaLive input; MediaLive starts the device when the channel starts.)
1050 |
# File 'sig/client.rbs', line 1050 def start_input_device: ( |
#start_input_device_maintenance_window(params = {}) ⇒ Struct
Start a maintenance window for the specified input device. Starting a maintenance window will give the device up to two hours to install software. If the device was streaming prior to the maintenance, it will resume streaming when the software is fully installed. Devices automatically install updates while they are powered on and their MediaLive channels are stopped. A maintenance window allows you to update a device without having to stop MediaLive channels that use the device. The device must remain powered on and connected to the internet for the duration of the maintenance.
1059 |
# File 'sig/client.rbs', line 1059 def start_input_device_maintenance_window: ( |
#start_monitor_deployment(params = {}) ⇒ Types::StartMonitorDeploymentResponse
Initiates a deployment to deploy the latest monitor of the specified signal map.
1809 |
# File 'sig/client.rbs', line 1809 def start_monitor_deployment: ( |
#start_multiplex(params = {}) ⇒ Types::StartMultiplexResponse
Start (run) the multiplex. Starting the multiplex does not start the channels. You must explicitly start each channel.
1078 |
# File 'sig/client.rbs', line 1078 def start_multiplex: ( |
#start_update_signal_map(params = {}) ⇒ Types::StartUpdateSignalMapResponse
Initiates an update for the specified signal map. Will discover a new signal map if a changed discoveryEntryPointArn is provided.
1837 |
# File 'sig/client.rbs', line 1837 def start_update_signal_map: ( |
#stop_channel(params = {}) ⇒ Types::StopChannelResponse
Stops a running channel
1110 |
# File 'sig/client.rbs', line 1110 def stop_channel: ( |
#stop_input_device(params = {}) ⇒ Struct
Stop an input device that is attached to a MediaConnect flow. (There is no need to stop a device that is attached to a MediaLive input; MediaLive automatically stops the device when the channel stops.)
1119 |
# File 'sig/client.rbs', line 1119 def stop_input_device: ( |
#stop_multiplex(params = {}) ⇒ Types::StopMultiplexResponse
Stops a running multiplex. If the multiplex isn't running, this action has no effect.
1138 |
# File 'sig/client.rbs', line 1138 def stop_multiplex: ( |
#transfer_input_device(params = {}) ⇒ Struct
Start an input device transfer to another AWS account. After you make the request, the other account must accept or reject the transfer.
1147 |
# File 'sig/client.rbs', line 1147 def transfer_input_device: ( |
#update_account_configuration(params = {}) ⇒ Types::UpdateAccountConfigurationResponse
Update account configuration
1160 |
# File 'sig/client.rbs', line 1160 def update_account_configuration: ( |
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel.
1172 |
# File 'sig/client.rbs', line 1172 def update_channel: ( |
#update_channel_class(params = {}) ⇒ Types::UpdateChannelClassResponse
Changes the class of the channel.
1219 |
# File 'sig/client.rbs', line 1219 def update_channel_class: ( |
#update_channel_placement_group(params = {}) ⇒ Types::UpdateChannelPlacementGroupResponse
Change the settings for a ChannelPlacementGroup.
2283 |
# File 'sig/client.rbs', line 2283 def update_channel_placement_group: ( |
#update_cloud_watch_alarm_template(params = {}) ⇒ Types::UpdateCloudWatchAlarmTemplateResponse
Updates the specified cloudwatch alarm template.
1869 |
# File 'sig/client.rbs', line 1869 def update_cloud_watch_alarm_template: ( |
#update_cloud_watch_alarm_template_group(params = {}) ⇒ Types::UpdateCloudWatchAlarmTemplateGroupResponse
Updates the specified cloudwatch alarm template group.
1897 |
# File 'sig/client.rbs', line 1897 def update_cloud_watch_alarm_template_group: ( |
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Change the settings for a Cluster.
2302 |
# File 'sig/client.rbs', line 2302 def update_cluster: ( |
#update_event_bridge_rule_template(params = {}) ⇒ Types::UpdateEventBridgeRuleTemplateResponse
Updates the specified eventbridge rule template.
1917 |
# File 'sig/client.rbs', line 1917 def update_event_bridge_rule_template: ( |
#update_event_bridge_rule_template_group(params = {}) ⇒ Types::UpdateEventBridgeRuleTemplateGroupResponse
Updates the specified eventbridge rule template group.
1942 |
# File 'sig/client.rbs', line 1942 def update_event_bridge_rule_template_group: ( |
#update_input(params = {}) ⇒ Types::UpdateInputResponse
Updates an input.
1233 |
# File 'sig/client.rbs', line 1233 def update_input: ( |
#update_input_device(params = {}) ⇒ Types::UpdateInputDeviceResponse
Updates the parameters for the input device.
1295 |
# File 'sig/client.rbs', line 1295 def update_input_device: ( |
#update_input_security_group(params = {}) ⇒ Types::UpdateInputSecurityGroupResponse
Update an Input Security Group's Whilelists.
1309 |
# File 'sig/client.rbs', line 1309 def update_input_security_group: ( |
#update_multiplex(params = {}) ⇒ Types::UpdateMultiplexResponse
Updates a multiplex.
1325 |
# File 'sig/client.rbs', line 1325 def update_multiplex: ( |
#update_multiplex_program(params = {}) ⇒ Types::UpdateMultiplexProgramResponse
Update a program in a multiplex.
1361 |
# File 'sig/client.rbs', line 1361 def update_multiplex_program: ( |
#update_network(params = {}) ⇒ Types::UpdateNetworkResponse
Change the settings for a Network.
2328 |
# File 'sig/client.rbs', line 2328 def update_network: ( |
#update_node(params = {}) ⇒ Types::UpdateNodeResponse
Change the settings for a Node.
2360 |
# File 'sig/client.rbs', line 2360 def update_node: ( |
#update_node_state(params = {}) ⇒ Types::UpdateNodeStateResponse
Update the state of a node.
2390 |
# File 'sig/client.rbs', line 2390 def update_node_state: ( |
#update_reservation(params = {}) ⇒ Types::UpdateReservationResponse
Update reservation.
1373 |
# File 'sig/client.rbs', line 1373 def update_reservation: ( |
#update_sdi_source(params = {}) ⇒ Types::UpdateSdiSourceResponse
Change some of the settings in an SdiSource.
2457 |
# File 'sig/client.rbs', line 2457 def update_sdi_source: ( |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| channel_created | #describe_channel | 3 | 5 |
| channel_deleted | #describe_channel | 5 | 84 |
| channel_placement_group_assigned | #describe_channel_placement_group | 3 | 5 |
| channel_placement_group_deleted | #describe_channel_placement_group | 5 | 20 |
| channel_placement_group_unassigned | #describe_channel_placement_group | 5 | 20 |
| channel_running | #describe_channel | 5 | 120 |
| channel_stopped | #describe_channel | 5 | 60 |
| cluster_created | #describe_cluster | 3 | 5 |
| cluster_deleted | #describe_cluster | 5 | 20 |
| input_attached | #describe_input | 5 | 20 |
| input_deleted | #describe_input | 5 | 20 |
| input_detached | #describe_input | 5 | 84 |
| multiplex_created | #describe_multiplex | 3 | 5 |
| multiplex_deleted | #describe_multiplex | 5 | 20 |
| multiplex_running | #describe_multiplex | 5 | 120 |
| multiplex_stopped | #describe_multiplex | 5 | 28 |
| node_deregistered | #describe_node | 5 | 20 |
| node_registered | #describe_node | 3 | 5 |
| signal_map_created | #get_signal_map | 5 | 60 |
| signal_map_monitor_deleted | #get_signal_map | 5 | 120 |
| signal_map_monitor_deployed | #get_signal_map | 5 | 120 |
| signal_map_updated | #get_signal_map | 5 | 60 |
2508 |
# File 'sig/client.rbs', line 2508 def wait_until: (:channel_created waiter_name, |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8238 8239 8240 |
# File 'lib/aws-sdk-medialive/client.rb', line 8238 def waiter_names waiters.keys end |