Class: Aws::MediaLive::Types::AudioFeedInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Maps an audio selector in the channel to a feed input on the associated Elemental Inference feed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_selector_nameString

The name of the audio selector in the channel that will be sent to the Elemental Inference feed input.

Returns:

  • (String)


23153
23154
23155
23156
23157
23158
# File 'lib/aws-sdk-medialive/types.rb', line 23153

class AudioFeedInput < Struct.new(
  :audio_selector_name,
  :feed_input)
  SENSITIVE = []
  include Aws::Structure
end

#feed_inputString

The name of the feed input on the Elemental Inference feed that will receive the audio from the specified audio selector.

Returns:

  • (String)


23153
23154
23155
23156
23157
23158
# File 'lib/aws-sdk-medialive/types.rb', line 23153

class AudioFeedInput < Struct.new(
  :audio_selector_name,
  :feed_input)
  SENSITIVE = []
  include Aws::Structure
end