Class: Aws::MediaLive::Types::AudioPid

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Represents a single PID value for audio selection with optional pre-mixer settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dolby_e_decodeTypes::AudioDolbyEDecode

Configure decoding options for Dolby E streams - these should be Dolby E frames carried in PCM streams tagged with SMPTE-337. When using the ‘pids’ array, if this field is not specified and Dolby E content is present, the decoder will extract the specified program. To maintain legacy behavior (allPrograms), explicitly set programSelection to “allChannels”.



23244
23245
23246
23247
23248
23249
23250
# File 'lib/aws-sdk-medialive/types.rb', line 23244

class AudioPid < Struct.new(
  :dolby_e_decode,
  :pid,
  :premix_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pidInteger

PID value from within a source.

Returns:

  • (Integer)


23244
23245
23246
23247
23248
23249
23250
# File 'lib/aws-sdk-medialive/types.rb', line 23244

class AudioPid < Struct.new(
  :dolby_e_decode,
  :pid,
  :premix_settings)
  SENSITIVE = []
  include Aws::Structure
end

#premix_settingsTypes::AudioPreMixerSettings

Optional audio pre-mixer settings for this PID. When specified, allows per-PID audio processing including channel remixing, gain adjustment, and loudness normalization before interleaving.



23244
23245
23246
23247
23248
23249
23250
# File 'lib/aws-sdk-medialive/types.rb', line 23244

class AudioPid < Struct.new(
  :dolby_e_decode,
  :pid,
  :premix_settings)
  SENSITIVE = []
  include Aws::Structure
end