Class: Aws::MediaLive::Types::BlackoutSlate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Blackout Slate

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#blackout_slate_imageTypes::InputLocation

Blackout slate image to be used. Leave empty for solid black. Only bmp and png images are supported.



1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-medialive/types.rb', line 1356

class BlackoutSlate < Struct.new(
  :blackout_slate_image,
  :network_end_blackout,
  :network_end_blackout_image,
  :network_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#network_end_blackoutString

Setting to enabled causes the encoder to blackout the video, audio, and captions, and raise the “Network Blackout Image” slate when an SCTE104/35 Network End Segmentation Descriptor is encountered. The blackout will be lifted when the Network Start Segmentation Descriptor is encountered. The Network End and Network Start descriptors must contain a network ID that matches the value entered in “Network ID”.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-medialive/types.rb', line 1356

class BlackoutSlate < Struct.new(
  :blackout_slate_image,
  :network_end_blackout,
  :network_end_blackout_image,
  :network_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#network_end_blackout_imageTypes::InputLocation

Path to local file to use as Network End Blackout image. Image will be scaled to fill the entire output raster.



1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-medialive/types.rb', line 1356

class BlackoutSlate < Struct.new(
  :blackout_slate_image,
  :network_end_blackout,
  :network_end_blackout_image,
  :network_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

Provides Network ID that matches EIDR ID format (e.g., “10.XXXX/XXXX-XXXX-XXXX-XXXX-XXXX-C”).

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-medialive/types.rb', line 1356

class BlackoutSlate < Struct.new(
  :blackout_slate_image,
  :network_end_blackout,
  :network_end_blackout_image,
  :network_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

When set to enabled, causes video, audio and captions to be blanked when indicated by program metadata.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-medialive/types.rb', line 1356

class BlackoutSlate < Struct.new(
  :blackout_slate_image,
  :network_end_blackout,
  :network_end_blackout_image,
  :network_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end