Class: Aws::MediaLive::Types::CaptionSelector
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CaptionSelector
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Caption Selector
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#language_code ⇒ String
When specified this field indicates the three letter language code of the caption track to extract from the source.
-
#name ⇒ String
Name identifier for a caption selector.
-
#selector_settings ⇒ Types::CaptionSelectorSettings
Caption selector settings.
Instance Attribute Details
#language_code ⇒ String
When specified this field indicates the three letter language code of the caption track to extract from the source.
1779 1780 1781 1782 1783 1784 1785 |
# File 'lib/aws-sdk-medialive/types.rb', line 1779 class CaptionSelector < Struct.new( :language_code, :name, :selector_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name identifier for a caption selector. This name is used to associate this caption selector with one or more caption descriptions. Names must be unique within an event.
1779 1780 1781 1782 1783 1784 1785 |
# File 'lib/aws-sdk-medialive/types.rb', line 1779 class CaptionSelector < Struct.new( :language_code, :name, :selector_settings) SENSITIVE = [] include Aws::Structure end |
#selector_settings ⇒ Types::CaptionSelectorSettings
Caption selector settings.
1779 1780 1781 1782 1783 1784 1785 |
# File 'lib/aws-sdk-medialive/types.rb', line 1779 class CaptionSelector < Struct.new( :language_code, :name, :selector_settings) SENSITIVE = [] include Aws::Structure end |