Class: Aws::MediaLive::Types::Channel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::DescribeAnywhereSettings

Anywhere settings for this channel.



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The unique arn of the channel.

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification

Specification of CDI inputs for this channel



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_classString

The class for this channel. STANDARD for a channel with two pipelines or SINGLE_PIPELINE for a channel with one pipeline.

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionResponse

Requested engine version for this channel.



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

A list of IDs for all the Input Security Groups attached to the channel.

Returns:

  • (Array<String>)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

A list of destinations of the channel. For UDP outputs, there is one destination per output. For other types (HLS, for example), there is one destination per packager.

Returns:



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#egress_endpointsArray<Types::ChannelEgressEndpoint>

The endpoints where outgoing connections initiate from

Returns:



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

Encoder Settings



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique id of the channel.

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::DescribeInferenceSettings

Include this setting to include Elemental Inference features in this channel.



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

List of input attachments for channel.

Returns:



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification

Specification of network and file inputs for this channel



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::DescribeLinkedChannelSettings

Linked Channel Settings for this channel.



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level being written to CloudWatch Logs.

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceStatus

Maintenance settings for this channel.



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the channel. (user-mutable)

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_detailsArray<Types::PipelineDetail>

Runtime details for the pipelines of a running channel.

Returns:



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipelines_running_countInteger

The number of currently healthy pipelines.

Returns:

  • (Integer)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the role assumed when running the Channel.

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Returns:

  • (String)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of key-value pairs.

Returns:

  • (Hash<String,String>)


1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vpcTypes::VpcOutputSettingsDescription

Settings for VPC output



1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
# File 'lib/aws-sdk-medialive/types.rb', line 1947

class Channel < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end