Class: Aws::MediaLive::Types::ChannelAlert
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::ChannelAlert
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
An alert on a channel
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alert_type ⇒ String
The type of the alert.
- #cleared_timestamp ⇒ Time
-
#id ⇒ String
The unique ID for this alert instance.
-
#message ⇒ String
The user facing alert message which can have more context.
-
#pipeline_id ⇒ String
The ID of the pipeline this alert is associated with.
- #set_timestamp ⇒ Time
-
#state ⇒ String
The state of the alert.
Instance Attribute Details
#alert_type ⇒ String
The type of the alert
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 |
# File 'lib/aws-sdk-medialive/types.rb', line 22354 class ChannelAlert < Struct.new( :alert_type, :cleared_timestamp, :id, :message, :pipeline_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#cleared_timestamp ⇒ Time
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 |
# File 'lib/aws-sdk-medialive/types.rb', line 22354 class ChannelAlert < Struct.new( :alert_type, :cleared_timestamp, :id, :message, :pipeline_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID for this alert instance
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 |
# File 'lib/aws-sdk-medialive/types.rb', line 22354 class ChannelAlert < Struct.new( :alert_type, :cleared_timestamp, :id, :message, :pipeline_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The user facing alert message which can have more context
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 |
# File 'lib/aws-sdk-medialive/types.rb', line 22354 class ChannelAlert < Struct.new( :alert_type, :cleared_timestamp, :id, :message, :pipeline_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#pipeline_id ⇒ String
The ID of the pipeline this alert is associated with
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 |
# File 'lib/aws-sdk-medialive/types.rb', line 22354 class ChannelAlert < Struct.new( :alert_type, :cleared_timestamp, :id, :message, :pipeline_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#set_timestamp ⇒ Time
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 |
# File 'lib/aws-sdk-medialive/types.rb', line 22354 class ChannelAlert < Struct.new( :alert_type, :cleared_timestamp, :id, :message, :pipeline_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the alert
22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 |
# File 'lib/aws-sdk-medialive/types.rb', line 22354 class ChannelAlert < Struct.new( :alert_type, :cleared_timestamp, :id, :message, :pipeline_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |