Class: Aws::MediaLive::Types::ChannelSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::DescribeAnywhereSettings

AnywhereSettings settings for this channel.



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The unique arn of the channel.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification

Specification of CDI inputs for this channel



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_classString

The class for this channel. STANDARD for a channel with two pipelines or SINGLE_PIPELINE for a channel with one pipeline.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionResponse

The engine version that you requested for this channel.



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

A list of IDs for all the Input Security Groups attached to the channel.

Returns:

  • (Array<String>)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

A list of destinations of the channel. For UDP outputs, there is one destination per output. For other types (HLS, for example), there is one destination per packager.

Returns:



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#egress_endpointsArray<Types::ChannelEgressEndpoint>

The endpoints where outgoing connections initiate from

Returns:



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique id of the channel.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::DescribeInferenceSettings

Include this setting to include Elemental Inference features in this channel.



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

List of input attachments for channel.

Returns:



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification

Specification of network and file inputs for this channel



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::DescribeLinkedChannelSettings

Linked Channel Settings for this channel.



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level being written to CloudWatch Logs.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceStatus

Maintenance settings for this channel.



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the channel. (user-mutable)

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipelines_running_countInteger

The number of currently healthy pipelines.

Returns:

  • (Integer)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the role assumed when running the Channel.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of key-value pairs.

Returns:

  • (Hash<String,String>)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#used_channel_engine_versionsArray<Types::ChannelEngineVersionResponse>

The engine version that the running pipelines are using.



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vpcTypes::VpcOutputSettingsDescription

Settings for any VPC outputs.



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-medialive/types.rb', line 2098

class ChannelSummary < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :used_channel_engine_versions,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end