Class: Aws::MediaLive::Types::ClusterAlert

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

An alert on a cluster

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alert_typeString

The type of the alert

Returns:

  • (String)


22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
# File 'lib/aws-sdk-medialive/types.rb', line 22166

class ClusterAlert < Struct.new(
  :alert_type,
  :channel_id,
  :cleared_timestamp,
  :id,
  :message,
  :node_id,
  :set_timestamp,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#channel_idString

The ID of the channel this alert is associated with

Returns:

  • (String)


22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
# File 'lib/aws-sdk-medialive/types.rb', line 22166

class ClusterAlert < Struct.new(
  :alert_type,
  :channel_id,
  :cleared_timestamp,
  :id,
  :message,
  :node_id,
  :set_timestamp,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#cleared_timestampTime

Returns:

  • (Time)


22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
# File 'lib/aws-sdk-medialive/types.rb', line 22166

class ClusterAlert < Struct.new(
  :alert_type,
  :channel_id,
  :cleared_timestamp,
  :id,
  :message,
  :node_id,
  :set_timestamp,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The further subtype of this alert

Returns:

  • (String)


22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
# File 'lib/aws-sdk-medialive/types.rb', line 22166

class ClusterAlert < Struct.new(
  :alert_type,
  :channel_id,
  :cleared_timestamp,
  :id,
  :message,
  :node_id,
  :set_timestamp,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The user facing alert message which can have more context

Returns:

  • (String)


22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
# File 'lib/aws-sdk-medialive/types.rb', line 22166

class ClusterAlert < Struct.new(
  :alert_type,
  :channel_id,
  :cleared_timestamp,
  :id,
  :message,
  :node_id,
  :set_timestamp,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#node_idString

The ID of the node this alert is associated with

Returns:

  • (String)


22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
# File 'lib/aws-sdk-medialive/types.rb', line 22166

class ClusterAlert < Struct.new(
  :alert_type,
  :channel_id,
  :cleared_timestamp,
  :id,
  :message,
  :node_id,
  :set_timestamp,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#set_timestampTime

Returns:

  • (Time)


22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
# File 'lib/aws-sdk-medialive/types.rb', line 22166

class ClusterAlert < Struct.new(
  :alert_type,
  :channel_id,
  :cleared_timestamp,
  :id,
  :message,
  :node_id,
  :set_timestamp,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the alert

Returns:

  • (String)


22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
# File 'lib/aws-sdk-medialive/types.rb', line 22166

class ClusterAlert < Struct.new(
  :alert_type,
  :channel_id,
  :cleared_timestamp,
  :id,
  :message,
  :node_id,
  :set_timestamp,
  :state)
  SENSITIVE = []
  include Aws::Structure
end