Class: Aws::MediaLive::Types::ClusterNetworkSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Used in DescribeClusterResult, DescribeClusterSummary, UpdateClusterResult.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_routeString

The network interface that is the default route for traffic to and from the node. MediaLive Anywhere uses this default when the destination for the traffic isn’t covered by the route table for any of the networks. Specify the value of the appropriate logicalInterfaceName parameter that you create in the interfaceMappings.

Returns:

  • (String)


18799
18800
18801
18802
18803
18804
# File 'lib/aws-sdk-medialive/types.rb', line 18799

class ClusterNetworkSettings < Struct.new(
  :default_route,
  :interface_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#interface_mappingsArray<Types::InterfaceMapping>

An array of interfaceMapping objects for this Cluster. Each mapping logically connects one interface on the nodes with one Network. You need only one mapping for each interface because all the Nodes share the mapping.

Returns:



18799
18800
18801
18802
18803
18804
# File 'lib/aws-sdk-medialive/types.rb', line 18799

class ClusterNetworkSettings < Struct.new(
  :default_route,
  :interface_mappings)
  SENSITIVE = []
  include Aws::Structure
end