Class: Aws::MediaLive::Types::CmafIngestGroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CmafIngestGroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Cmaf Ingest Group Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_destinations ⇒ Array<Types::AdditionalDestinations>
Optional an array of additional destinational HTTP destinations for the OutputGroup outputs.
-
#caption_language_mappings ⇒ Array<Types::CmafIngestCaptionLanguageMapping>
An array that identifies the languages in the four caption channels in the embedded captions.
-
#destination ⇒ Types::OutputLocationRef
A HTTP destination for the tracks.
-
#id_3_behavior ⇒ String
Set to ENABLED to enable ID3 metadata insertion.
-
#id_3_name_modifier ⇒ String
Change the modifier that MediaLive automatically adds to the Streams() name that identifies an ID3 track.
-
#klv_behavior ⇒ String
If set to passthrough, passes any KLV data from the input source to this output.
-
#klv_name_modifier ⇒ String
Change the modifier that MediaLive automatically adds to the Streams() name that identifies a KLV track.
-
#nielsen_id_3_behavior ⇒ String
If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.
-
#nielsen_id_3_name_modifier ⇒ String
Change the modifier that MediaLive automatically adds to the Streams() name that identifies a Nielsen ID3 track.
-
#scte_35_name_modifier ⇒ String
Change the modifier that MediaLive automatically adds to the Streams() name for a SCTE 35 track.
-
#scte_35_type ⇒ String
SCTE-35 insertion type.
-
#segment_length ⇒ Integer
The nominal duration of segments.
-
#segment_length_units ⇒ String
Time unit for segment length parameter.
-
#send_delay_ms ⇒ Integer
Number of milliseconds to delay the output from the second pipeline.
-
#timed_metadata_id_3_frame ⇒ String
Set to none if you don't want to insert a timecode in the output.
-
#timed_metadata_id_3_period ⇒ Integer
If you set up to insert a timecode in the output, specify the frequency for the frame, in seconds.
-
#timed_metadata_passthrough ⇒ String
Set to enabled to pass through ID3 metadata from the input sources.
-
#watermarking_settings ⇒ Types::CmafIngestWatermarkingSettings
Specifies the type of watermarking technology to use.
Instance Attribute Details
#additional_destinations ⇒ Array<Types::AdditionalDestinations>
Optional an array of additional destinational HTTP destinations for the OutputGroup outputs
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#caption_language_mappings ⇒ Array<Types::CmafIngestCaptionLanguageMapping>
An array that identifies the languages in the four caption channels in the embedded captions.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#destination ⇒ Types::OutputLocationRef
A HTTP destination for the tracks
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#id_3_behavior ⇒ String
Set to ENABLED to enable ID3 metadata insertion. To include metadata, you configure other parameters in the output group, or you add an ID3 action to the channel schedule.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#id_3_name_modifier ⇒ String
Change the modifier that MediaLive automatically adds to the Streams() name that identifies an ID3 track. The default is "id3", which means the default name will be Streams(id3.cmfm). Any string you enter here will replace the "id3" string.\nThe modifier can only contain: numbers, letters, plus (+), minus (-), underscore (_) and period (.) and has a maximum length of 100 characters.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#klv_behavior ⇒ String
If set to passthrough, passes any KLV data from the input source to this output.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#klv_name_modifier ⇒ String
Change the modifier that MediaLive automatically adds to the Streams() name that identifies a KLV track. The default is "klv", which means the default name will be Streams(klv.cmfm). Any string you enter here will replace the "klv" string.\nThe modifier can only contain: numbers, letters, plus (+), minus (-), underscore (_) and period (.) and has a maximum length of 100 characters.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#nielsen_id_3_behavior ⇒ String
If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#nielsen_id_3_name_modifier ⇒ String
Change the modifier that MediaLive automatically adds to the Streams() name that identifies a Nielsen ID3 track. The default is "nid3", which means the default name will be Streams(nid3.cmfm). Any string you enter here will replace the "nid3" string.\nThe modifier can only contain: numbers, letters, plus (+), minus (-), underscore (_) and period (.) and has a maximum length of 100 characters.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#scte_35_name_modifier ⇒ String
Change the modifier that MediaLive automatically adds to the Streams() name for a SCTE 35 track. The default is "scte", which means the default name will be Streams(scte.cmfm). Any string you enter here will replace the "scte" string.\nThe modifier can only contain: numbers, letters, plus (+), minus (-), underscore (_) and period (.) and has a maximum length of 100 characters.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#scte_35_type ⇒ String
SCTE-35 insertion type. Option "none" indicates that a SCTE-35 marker will not be inserted, nor will an IDR be inserted at the SCTE-35 cue point, nor will the segment be segmented. Option "scte35WithoutIdr" indicates that a SCTE-35 marker will be inserted to indicate the cue point, but MediaLive will not insert an IDR on that frame nor will it introduce a new segment boundary there if it wasn't already going to be one (this option is required for use with downstream multiview bitstream stitching workflows). Option "scte35WithoutSegmentation" indicates that a SCTE-35 marker will be inserted to indicate the cue point, and an IDR will be inserted on that frame so that a downstream re-packager might split the segment there, but MediaLive itself will not introduce a new segment boundary there.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#segment_length ⇒ Integer
The nominal duration of segments. The units are specified in SegmentLengthUnits. The segments will end on the next keyframe after the specified duration, so the actual segment length might be longer, and it might be a fraction of the units.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#segment_length_units ⇒ String
Time unit for segment length parameter.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#send_delay_ms ⇒ Integer
Number of milliseconds to delay the output from the second pipeline.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_id_3_frame ⇒ String
Set to none if you don't want to insert a timecode in the output. Otherwise choose the frame type for the timecode.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_id_3_period ⇒ Integer
If you set up to insert a timecode in the output, specify the frequency for the frame, in seconds.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_passthrough ⇒ String
Set to enabled to pass through ID3 metadata from the input sources.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |
#watermarking_settings ⇒ Types::CmafIngestWatermarkingSettings
Specifies the type of watermarking technology to use.
14590 14591 14592 14593 14594 14595 14596 14597 14598 14599 14600 14601 14602 14603 14604 14605 14606 14607 14608 14609 14610 14611 |
# File 'lib/aws-sdk-medialive/types.rb', line 14590 class CmafIngestGroupSettings < Struct.new( :destination, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :send_delay_ms, :klv_behavior, :klv_name_modifier, :nielsen_id_3_name_modifier, :scte_35_name_modifier, :id_3_behavior, :id_3_name_modifier, :caption_language_mappings, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations, :watermarking_settings) SENSITIVE = [] include Aws::Structure end |