Class: Aws::MediaLive::Types::CreateCloudWatchAlarmTemplateGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateCloudWatchAlarmTemplateGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #description ⇒ String
- #name ⇒ String
-
#request_id ⇒ String
A suitable default value is auto-generated. You should normally not need to pass this option.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
Instance Attribute Details
#description ⇒ String
14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-medialive/types.rb', line 14769 class CreateCloudWatchAlarmTemplateGroupRequest < Struct.new( :description, :name, :tags, :request_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-medialive/types.rb', line 14769 class CreateCloudWatchAlarmTemplateGroupRequest < Struct.new( :description, :name, :tags, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
A suitable default value is auto-generated. You should normally not need to pass this option.
14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-medialive/types.rb', line 14769 class CreateCloudWatchAlarmTemplateGroupRequest < Struct.new( :description, :name, :tags, :request_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
14769 14770 14771 14772 14773 14774 14775 14776 |
# File 'lib/aws-sdk-medialive/types.rb', line 14769 class CreateCloudWatchAlarmTemplateGroupRequest < Struct.new( :description, :name, :tags, :request_id) SENSITIVE = [] include Aws::Structure end |