Class: Aws::MediaLive::Types::CreateCloudWatchAlarmTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateCloudWatchAlarmTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
- #datapoints_to_alarm ⇒ Integer
- #description ⇒ String
- #evaluation_periods ⇒ Integer
- #group_identifier ⇒ String
- #metric_name ⇒ String
- #name ⇒ String
- #period ⇒ Integer
-
#request_id ⇒ String
A suitable default value is auto-generated. You should normally not need to pass this option.
-
#statistic ⇒ String
The statistic to apply to the alarm's metric data.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
-
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
- #threshold ⇒ Float
-
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm's condition.
Instance Attribute Details
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#datapoints_to_alarm ⇒ Integer
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#evaluation_periods ⇒ Integer
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#group_identifier ⇒ String
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
A suitable default value is auto-generated. You should normally not need to pass this option.
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic to apply to the alarm's metric data.
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm's condition.
14991 14992 14993 14994 14995 14996 14997 14998 14999 15000 15001 15002 15003 15004 15005 15006 15007 15008 |
# File 'lib/aws-sdk-medialive/types.rb', line 14991 class CreateCloudWatchAlarmTemplateRequest < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |