Class: Aws::MediaLive::Types::CreateCloudWatchAlarmTemplateRequestContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateCloudWatchAlarmTemplateRequestContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
-
#datapoints_to_alarm ⇒ Integer
The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
-
#description ⇒ String
A resource's optional description.
-
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
-
#group_identifier ⇒ String
A cloudwatch alarm template group's identifier.
-
#metric_name ⇒ String
The name of the metric associated with the alarm.
-
#name ⇒ String
A resource's name.
-
#period ⇒ Integer
The period, in seconds, over which the specified statistic is applied.
-
#request_id ⇒ String
An ID that you assign to a create request.
-
#statistic ⇒ String
The statistic to apply to the alarm's metric data.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
-
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
-
#threshold ⇒ Float
The threshold value to compare with the specified statistic.
-
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm's condition.
Instance Attribute Details
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#datapoints_to_alarm ⇒ Integer
The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A resource's optional description.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#group_identifier ⇒ String
A cloudwatch alarm template group's identifier. Can be either be its id or current name.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric associated with the alarm. Must be compatible with targetResourceType.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A resource's name. Names must be unique within the scope of a resource type in a specific region.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The period, in seconds, over which the specified statistic is applied.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
An ID that you assign to a create request. This ID ensures idempotency when creating resources.A suitable default value is auto-generated. You should normally not need to pass this option.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic to apply to the alarm's metric data.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
The threshold value to compare with the specified statistic.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm's condition.
15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 15090 15091 15092 15093 15094 15095 |
# File 'lib/aws-sdk-medialive/types.rb', line 15078 class CreateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data, :request_id) SENSITIVE = [] include Aws::Structure end |