Class: Aws::MediaLive::Types::CreateClusterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Used in the CreateCluster operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_typeString

Specify a type. All the Nodes that you later add to this Cluster must be this type of hardware. One Cluster instance can’t contain different hardware types. You won’t be able to change this parameter after you create the Cluster.

Returns:

  • (String)


19079
19080
19081
19082
19083
19084
19085
19086
19087
19088
# File 'lib/aws-sdk-medialive/types.rb', line 19079

class CreateClusterRequest < Struct.new(
  :cluster_type,
  :instance_role_arn,
  :name,
  :network_settings,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_role_arnString

The ARN of the IAM role for the Node in this Cluster. The role must include all the operations that you expect these Node to perform. If necessary, create a role in IAM, then attach it here.

Returns:

  • (String)


19079
19080
19081
19082
19083
19084
19085
19086
19087
19088
# File 'lib/aws-sdk-medialive/types.rb', line 19079

class CreateClusterRequest < Struct.new(
  :cluster_type,
  :instance_role_arn,
  :name,
  :network_settings,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Specify a name that is unique in the AWS account. We recommend that you assign a name that hints at the types of Nodes in the Cluster. Names are case-sensitive.

Returns:

  • (String)


19079
19080
19081
19082
19083
19084
19085
19086
19087
19088
# File 'lib/aws-sdk-medialive/types.rb', line 19079

class CreateClusterRequest < Struct.new(
  :cluster_type,
  :instance_role_arn,
  :name,
  :network_settings,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#network_settingsTypes::ClusterNetworkSettingsCreateRequest

Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.



19079
19080
19081
19082
19083
19084
19085
19086
19087
19088
# File 'lib/aws-sdk-medialive/types.rb', line 19079

class CreateClusterRequest < Struct.new(
  :cluster_type,
  :instance_role_arn,
  :name,
  :network_settings,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The unique ID of the request.**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


19079
19080
19081
19082
19083
19084
19085
19086
19087
19088
# File 'lib/aws-sdk-medialive/types.rb', line 19079

class CreateClusterRequest < Struct.new(
  :cluster_type,
  :instance_role_arn,
  :name,
  :network_settings,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of key-value pairs.

Returns:

  • (Hash<String,String>)


19079
19080
19081
19082
19083
19084
19085
19086
19087
19088
# File 'lib/aws-sdk-medialive/types.rb', line 19079

class CreateClusterRequest < Struct.new(
  :cluster_type,
  :instance_role_arn,
  :name,
  :network_settings,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end