Class: Aws::MediaLive::Types::CreateNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in the CreateNetwork operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ip_pools ⇒ Array<Types::IpPoolCreateRequest>
An array of IpPoolCreateRequests that identify a collection of IP addresses in your network that you want to reserve for use in MediaLive Anywhere.
-
#name ⇒ String
Specify a name that is unique in the AWS account.
-
#request_id ⇒ String
An ID that you assign to a create request.
-
#routes ⇒ Array<Types::RouteCreateRequest>
An array of routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
-
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
Instance Attribute Details
#ip_pools ⇒ Array<Types::IpPoolCreateRequest>
An array of IpPoolCreateRequests that identify a collection of IP addresses in your network that you want to reserve for use in MediaLive Anywhere. MediaLiveAnywhere uses these IP addresses for Push inputs (in both Bridge and NATnetworks) and for output destinations (only in Bridge networks). EachIpPoolUpdateRequest specifies one CIDR block.
19124 19125 19126 19127 19128 19129 19130 19131 19132 |
# File 'lib/aws-sdk-medialive/types.rb', line 19124 class CreateNetworkRequest < Struct.new( :ip_pools, :name, :request_id, :routes, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specify a name that is unique in the AWS account. We recommend that you assign a name that hints at the type of traffic on the network. Names are case-sensitive.
19124 19125 19126 19127 19128 19129 19130 19131 19132 |
# File 'lib/aws-sdk-medialive/types.rb', line 19124 class CreateNetworkRequest < Struct.new( :ip_pools, :name, :request_id, :routes, :tags) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
An ID that you assign to a create request. This ID ensures idempotency when creating resources.**A suitable default value is auto-generated.** You should normally not need to pass this option.
19124 19125 19126 19127 19128 19129 19130 19131 19132 |
# File 'lib/aws-sdk-medialive/types.rb', line 19124 class CreateNetworkRequest < Struct.new( :ip_pools, :name, :request_id, :routes, :tags) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::RouteCreateRequest>
An array of routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
19124 19125 19126 19127 19128 19129 19130 19131 19132 |
# File 'lib/aws-sdk-medialive/types.rb', line 19124 class CreateNetworkRequest < Struct.new( :ip_pools, :name, :request_id, :routes, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
19124 19125 19126 19127 19128 19129 19130 19131 19132 |
# File 'lib/aws-sdk-medialive/types.rb', line 19124 class CreateNetworkRequest < Struct.new( :ip_pools, :name, :request_id, :routes, :tags) SENSITIVE = [] include Aws::Structure end |