Class: Aws::MediaLive::Types::DescribeChannelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::DescribeAnywhereSettings

Elemental anywhere settings



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_classString

A standard channel has two encoding pipelines and a single pipeline channel only has one.

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionResponse



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

Returns:

  • (Array<String>)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

Returns:



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#egress_endpointsArray<Types::ChannelEgressEndpoint>

Returns:



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

Encoder Settings



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::DescribeInferenceSettings

Configures Elemental Inference features in a channel.



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

Returns:



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::DescribeLinkedChannelSettings

Linked channel configuration details



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level the user wants for their channel.

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceStatus



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_detailsArray<Types::PipelineDetail>

Returns:



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipelines_running_countInteger

Returns:

  • (Integer)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Returns:

  • (String)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Returns:

  • (Hash<String,String>)


3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vpcTypes::VpcOutputSettingsDescription

The properties for a private VPC Output



3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/aws-sdk-medialive/types.rb', line 3444

class DescribeChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end