Class: Aws::MediaLive::Types::DescribeClusterSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DescribeClusterSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in ListClustersResult.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of this Cluster.
-
#channel_ids ⇒ Array<String>
An array of the IDs of the Channels that are associated with this Cluster.
-
#cluster_type ⇒ String
The hardware type for the Cluster.
-
#id ⇒ String
The ID of the Cluster.
-
#instance_role_arn ⇒ String
The ARN of the IAM role for the Node in this Cluster.
-
#name ⇒ String
The name that you specified for the Cluster.
-
#network_settings ⇒ Types::ClusterNetworkSettings
Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.
-
#state ⇒ String
The current state of the Cluster.
Instance Attribute Details
#arn ⇒ String
The ARN of this Cluster. It is automatically assigned when the Cluster is created.
20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-medialive/types.rb', line 20049 class DescribeClusterSummary < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#channel_ids ⇒ Array<String>
An array of the IDs of the Channels that are associated with this Cluster. One Channel is associated with the Cluster as follows: A Channel belongs to a ChannelPlacementGroup. A ChannelPlacementGroup is attached to a Node. A Node belongs to a Cluster.
20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-medialive/types.rb', line 20049 class DescribeClusterSummary < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#cluster_type ⇒ String
The hardware type for the Cluster.
20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-medialive/types.rb', line 20049 class DescribeClusterSummary < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the Cluster. Unique in the AWS account. The ID is the resource-id portion of the ARN.
20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-medialive/types.rb', line 20049 class DescribeClusterSummary < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#instance_role_arn ⇒ String
The ARN of the IAM role for the Node in this Cluster. Any Nodes that are associated with this Cluster assume this role. The role gives permissions to the operations that you expect these Node to perform.
20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-medialive/types.rb', line 20049 class DescribeClusterSummary < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you specified for the Cluster.
20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-medialive/types.rb', line 20049 class DescribeClusterSummary < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#network_settings ⇒ Types::ClusterNetworkSettings
Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.
20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-medialive/types.rb', line 20049 class DescribeClusterSummary < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Cluster.
20049 20050 20051 20052 20053 20054 20055 20056 20057 20058 20059 20060 |
# File 'lib/aws-sdk-medialive/types.rb', line 20049 class DescribeClusterSummary < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |