Class: Aws::MediaLive::Types::DescribeInferenceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DescribeInferenceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Configures Elemental Inference features in a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_feed_inputs ⇒ Array<Types::AudioFeedInput>
A list of audio feed inputs that map audio selectors in the channel to feed inputs on the associated Elemental Inference feed.
-
#enrichment_methods ⇒ Array<String>
The set of Contextual Metadata Enrichment methods enabled for this channel.
-
#feed_arn ⇒ String
The ARN of the feed resource that is associated with this channel.
Instance Attribute Details
#audio_feed_inputs ⇒ Array<Types::AudioFeedInput>
A list of audio feed inputs that map audio selectors in the channel to feed inputs on the associated Elemental Inference feed.
23190 23191 23192 23193 23194 23195 23196 |
# File 'lib/aws-sdk-medialive/types.rb', line 23190 class DescribeInferenceSettings < Struct.new( :feed_arn, :audio_feed_inputs, :enrichment_methods) SENSITIVE = [] include Aws::Structure end |
#enrichment_methods ⇒ Array<String>
The set of Contextual Metadata Enrichment methods enabled for this channel. Each method represents a specific way the channel uses the inference feed to augment its output with contextual metadata.
23190 23191 23192 23193 23194 23195 23196 |
# File 'lib/aws-sdk-medialive/types.rb', line 23190 class DescribeInferenceSettings < Struct.new( :feed_arn, :audio_feed_inputs, :enrichment_methods) SENSITIVE = [] include Aws::Structure end |
#feed_arn ⇒ String
The ARN of the feed resource that is associated with this channel. The feed is a resource in the Elemental Inference service.
23190 23191 23192 23193 23194 23195 23196 |
# File 'lib/aws-sdk-medialive/types.rb', line 23190 class DescribeInferenceSettings < Struct.new( :feed_arn, :audio_feed_inputs, :enrichment_methods) SENSITIVE = [] include Aws::Structure end |