Class: Aws::MediaLive::Types::DescribeInputDeviceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#connection_stateString

The state of the connection between the input device and AWS.

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#device_settings_sync_stateString

The status of the action to synchronize the device configuration. If you change the configuration of the input device (for example, the maximum bitrate), MediaLive sends the new data to the device. The device might not update itself immediately. SYNCED means the device has updated its configuration. SYNCING means that it has not updated its configuration.

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#device_update_statusString

The status of software on the input device.

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#hd_device_settingsTypes::InputDeviceHdSettings

Settings that describe the active source from the input device, and the video characteristics of that source.



3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#mac_addressString

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#medialive_input_arnsArray<String>

Returns:

  • (Array<String>)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#network_settingsTypes::InputDeviceNetworkSettings

The network settings for the input device.



3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#output_typeString

The output attachment type of the input device.

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#serial_numberString

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Returns:

  • (Hash<String,String>)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the input device. For an AWS Elemental Link device that outputs resolutions up to 1080, choose “HD”.

Returns:

  • (String)


3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#uhd_device_settingsTypes::InputDeviceUhdSettings

Settings that describe the active source from the input device, and the video characteristics of that source.



3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
# File 'lib/aws-sdk-medialive/types.rb', line 3505

class DescribeInputDeviceResponse < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end