Class: Aws::MediaLive::Types::DescribeInputResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#attached_channelsArray<String>

Returns:

  • (Array<String>)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::InputDestination>

Returns:



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_classString

A standard input has two sources and a single pipeline input only has one.

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_devicesArray<Types::InputDeviceSettings>

Returns:



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_network_locationString

With the introduction of MediaLive Anywhere, a MediaLive input can now exist in two different places: AWS or inside an on-premises datacenter. By default all inputs will continue to be AWS inputs.

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_partner_idsArray<String>

Returns:

  • (Array<String>)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_source_typeString

There are two types of input sources, static and dynamic. If an input source is dynamic you can change the source url of the input dynamically using an input switch action. Currently, two input types support a dynamic url at this time, MP4_FILE and TS_FILE. By default all input sources are static.

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#media_connect_flowsArray<Types::MediaConnectFlow>

Returns:



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#multicast_settingsTypes::MulticastSettings

Settings for a Multicast input. Contains a list of multicast Urls and optional source ip addresses.



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#router_settingsTypes::RouterInputSettings

The settings for a MediaConnect Router Input.



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#sdi_sourcesArray<String>

SDI Sources for this Input.

Returns:

  • (Array<String>)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

Returns:

  • (Array<String>)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#smpte_2110_receiver_group_settingsTypes::Smpte2110ReceiverGroupSettings

Configures the sources for the SMPTE 2110 Receiver Group input.



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::InputSource>

Returns:



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#srt_settingsTypes::SrtSettings

The configured settings for SRT inputs (caller and listener).

Returns:



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Returns:

  • (Hash<String,String>)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The different types of inputs that AWS Elemental MediaLive supports.

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
# File 'lib/aws-sdk-medialive/types.rb', line 3714

class DescribeInputResponse < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end