Class: Aws::MediaLive::Types::DescribeNetworkSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DescribeNetworkSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in ListNetworksResult.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of this Network.
- #associated_cluster_ids ⇒ Array<String>
-
#id ⇒ String
The ID of the Network.
-
#ip_pools ⇒ Array<Types::IpPool>
An array of IpPools in your organization's network that identify a collection of IP addresses in your organization's network that are reserved for use in MediaLive Anywhere.
-
#name ⇒ String
The name that you specified for this Network.
-
#routes ⇒ Array<Types::Route>
An array of routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
-
#state ⇒ String
The current state of the Network.
Instance Attribute Details
#arn ⇒ String
The ARN of this Network. It is automatically assigned when the Network is created.
20203 20204 20205 20206 20207 20208 20209 20210 20211 20212 20213 |
# File 'lib/aws-sdk-medialive/types.rb', line 20203 class DescribeNetworkSummary < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#associated_cluster_ids ⇒ Array<String>
20203 20204 20205 20206 20207 20208 20209 20210 20211 20212 20213 |
# File 'lib/aws-sdk-medialive/types.rb', line 20203 class DescribeNetworkSummary < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the Network. Unique in the AWS account. The ID is the resource-id portion of the ARN.
20203 20204 20205 20206 20207 20208 20209 20210 20211 20212 20213 |
# File 'lib/aws-sdk-medialive/types.rb', line 20203 class DescribeNetworkSummary < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#ip_pools ⇒ Array<Types::IpPool>
An array of IpPools in your organization's network that identify a collection of IP addresses in your organization's network that are reserved for use in MediaLive Anywhere. MediaLive Anywhere uses these IP addresses for Push inputs (in both Bridge and NAT networks) and for output destinations (only in Bridge networks). Each IpPool specifies one CIDR block.
20203 20204 20205 20206 20207 20208 20209 20210 20211 20212 20213 |
# File 'lib/aws-sdk-medialive/types.rb', line 20203 class DescribeNetworkSummary < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you specified for this Network.
20203 20204 20205 20206 20207 20208 20209 20210 20211 20212 20213 |
# File 'lib/aws-sdk-medialive/types.rb', line 20203 class DescribeNetworkSummary < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::Route>
An array of routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
20203 20204 20205 20206 20207 20208 20209 20210 20211 20212 20213 |
# File 'lib/aws-sdk-medialive/types.rb', line 20203 class DescribeNetworkSummary < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Network. Only MediaLive Anywhere can change the state.
20203 20204 20205 20206 20207 20208 20209 20210 20211 20212 20213 |
# File 'lib/aws-sdk-medialive/types.rb', line 20203 class DescribeNetworkSummary < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |