Class: Aws::MediaLive::Types::DescribeNodeResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DescribeNodeResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Contains the response for CreateNode, DescribeNode, DeleteNode, UpdateNode
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Node.
-
#channel_placement_groups ⇒ Array<String>
An array of IDs.
-
#cluster_id ⇒ String
The ID of the Cluster that the Node belongs to.
-
#connection_state ⇒ String
The current connection state of the Node.
-
#id ⇒ String
The unique ID of the Node.
-
#instance_arn ⇒ String
The ARN of the EC2 instance hosting the Node.
-
#name ⇒ String
The name that you specified for the Node.
-
#node_interface_mappings ⇒ Array<Types::NodeInterfaceMapping>
An array of interface mappings for the Node.
-
#role ⇒ String
The initial role current role of the Node in the Cluster.
-
#sdi_source_mappings ⇒ Array<Types::SdiSourceMapping>
An array of SDI source mappings.
-
#state ⇒ String
The current state of the Node.
Instance Attribute Details
#arn ⇒ String
The ARN of the Node. It is automatically assigned when the Node is created.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#channel_placement_groups ⇒ Array<String>
An array of IDs. Each ID is one ChannelPlacementGroup that is associated with this Node. Empty if the Node is not yet associated with any groups.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#cluster_id ⇒ String
The ID of the Cluster that the Node belongs to.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#connection_state ⇒ String
The current connection state of the Node.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID of the Node. Unique in the Cluster. The ID is the resource-id portion of the ARN.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the EC2 instance hosting the Node.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you specified for the Node.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#node_interface_mappings ⇒ Array<Types::NodeInterfaceMapping>
An array of interface mappings for the Node. Each mapping logically connects one physical interface on the node hardware with one logical interface name. This mapping associates a node interface with a network. The association works as follows: Node physicalInterfaceName > Node logicalInterfaceName = Cluster logicalInterfaceName > networkId.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The initial role current role of the Node in the Cluster. ACTIVE means the Node is available for encoding. BACKUP means the Node is a redundant Node and might get used if an ACTIVE Node fails.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#sdi_source_mappings ⇒ Array<Types::SdiSourceMapping>
An array of SDI source mappings. Each mapping connects one logical SdiSource to the physical SDI card and port that the physical SDI source uses.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Node.
20247 20248 20249 20250 20251 20252 20253 20254 20255 20256 20257 20258 20259 20260 20261 |
# File 'lib/aws-sdk-medialive/types.rb', line 20247 class DescribeNodeResult < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |