Class: Aws::MediaLive::Types::DescribeNodeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DescribeNodeSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Node.
-
#channel_placement_groups ⇒ Array<String>
An array of IDs.
-
#cluster_id ⇒ String
The ID of the Cluster that the Node belongs to.
-
#connection_state ⇒ String
The current connection state of the Node.
-
#id ⇒ String
The unique ID of the Node.
-
#instance_arn ⇒ String
The EC2 ARN of the Instance associated with the Node.
-
#managed_instance_id ⇒ String
At the routing layer will get it from the callerId/context for use with bring your own device.
-
#name ⇒ String
The name that you specified for the Node.
-
#node_interface_mappings ⇒ Array<Types::NodeInterfaceMapping>
An array of interface mappings for the Node.
-
#role ⇒ String
The initial role current role of the Node in the Cluster.
-
#sdi_source_mappings ⇒ Array<Types::SdiSourceMapping>
An array of SDI source mappings.
-
#state ⇒ String
The current state of the Node.
Instance Attribute Details
#arn ⇒ String
The ARN of the Node. It is automatically assigned when the Node is created.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#channel_placement_groups ⇒ Array<String>
An array of IDs. Each ID is one ChannelPlacementGroup that is associated with this Node. Empty if the Node is not yet associated with any groups.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#cluster_id ⇒ String
The ID of the Cluster that the Node belongs to.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#connection_state ⇒ String
The current connection state of the Node.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID of the Node. Unique in the Cluster. The ID is the resource-id portion of the ARN.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The EC2 ARN of the Instance associated with the Node.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#managed_instance_id ⇒ String
At the routing layer will get it from the callerId/context for use with bring your own device.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you specified for the Node.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#node_interface_mappings ⇒ Array<Types::NodeInterfaceMapping>
An array of interface mappings for the Node. Each mapping logically connects one physical interface on the node hardware with one logical interface name. This mapping associates a node interface with a network. The association works as follows: Node physicalInterfaceName > Node logicalInterfaceName = Cluster logicalInterfaceName > networkId.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The initial role current role of the Node in the Cluster. ACTIVE means the Node is available for encoding. BACKUP means the Node is a redundant Node and might get used if an ACTIVE Node fails.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#sdi_source_mappings ⇒ Array<Types::SdiSourceMapping>
An array of SDI source mappings. Each mapping connects one logical SdiSource to the physical SDI card and port that the physical SDI source uses.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Node.
20322 20323 20324 20325 20326 20327 20328 20329 20330 20331 20332 20333 20334 20335 20336 20337 |
# File 'lib/aws-sdk-medialive/types.rb', line 20322 class DescribeNodeSummary < Struct.new( :arn, :channel_placement_groups, :cluster_id, :connection_state, :id, :instance_arn, :managed_instance_id, :name, :node_interface_mappings, :role, :state, :sdi_source_mappings) SENSITIVE = [] include Aws::Structure end |