Class: Aws::MediaLive::Types::DvbSdtSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DvbSdtSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
DVB Service Description Table (SDT)
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#output_sdt ⇒ String
Selects method of inserting SDT information into output stream.
-
#rep_interval ⇒ Integer
The number of milliseconds between instances of this table in the output transport stream.
-
#service_name ⇒ String
The service name placed in the serviceDescriptor in the Service Description Table.
-
#service_provider_name ⇒ String
The service provider name placed in the serviceDescriptor in the Service Description Table.
Instance Attribute Details
#output_sdt ⇒ String
Selects method of inserting SDT information into output stream. The sdtFollow setting copies SDT information from input stream to output stream. The sdtFollowIfPresent setting copies SDT information from input stream to output stream if SDT information is present in the input, otherwise it will fall back on the user-defined values. The sdtManual setting means user will enter the SDT information. The sdtNone setting means output stream will not contain SDT information.
4085 4086 4087 4088 4089 4090 4091 4092 |
# File 'lib/aws-sdk-medialive/types.rb', line 4085 class DvbSdtSettings < Struct.new( :output_sdt, :rep_interval, :service_name, :service_provider_name) SENSITIVE = [] include Aws::Structure end |
#rep_interval ⇒ Integer
The number of milliseconds between instances of this table in the output transport stream.
4085 4086 4087 4088 4089 4090 4091 4092 |
# File 'lib/aws-sdk-medialive/types.rb', line 4085 class DvbSdtSettings < Struct.new( :output_sdt, :rep_interval, :service_name, :service_provider_name) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The service name placed in the serviceDescriptor in the Service Description Table. Maximum length is 256 characters.
4085 4086 4087 4088 4089 4090 4091 4092 |
# File 'lib/aws-sdk-medialive/types.rb', line 4085 class DvbSdtSettings < Struct.new( :output_sdt, :rep_interval, :service_name, :service_provider_name) SENSITIVE = [] include Aws::Structure end |
#service_provider_name ⇒ String
The service provider name placed in the serviceDescriptor in the Service Description Table. Maximum length is 256 characters.
4085 4086 4087 4088 4089 4090 4091 4092 |
# File 'lib/aws-sdk-medialive/types.rb', line 4085 class DvbSdtSettings < Struct.new( :output_sdt, :rep_interval, :service_name, :service_provider_name) SENSITIVE = [] include Aws::Structure end |