Class: Aws::MediaLive::Types::Eac3AtmosSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Eac3 Atmos Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bitrateFloat

Average bitrate in bits/second. Valid bitrates depend on the coding mode.

Returns:

  • (Float)


4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
# File 'lib/aws-sdk-medialive/types.rb', line 4408

class Eac3AtmosSettings < Struct.new(
  :bitrate,
  :coding_mode,
  :dialnorm,
  :drc_line,
  :drc_rf,
  :height_trim,
  :surround_trim)
  SENSITIVE = []
  include Aws::Structure
end

#coding_modeString

Dolby Digital Plus with Dolby Atmos coding mode. Determines number of channels.

Returns:

  • (String)


4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
# File 'lib/aws-sdk-medialive/types.rb', line 4408

class Eac3AtmosSettings < Struct.new(
  :bitrate,
  :coding_mode,
  :dialnorm,
  :drc_line,
  :drc_rf,
  :height_trim,
  :surround_trim)
  SENSITIVE = []
  include Aws::Structure
end

#dialnormInteger

Sets the dialnorm for the output. Default 23.

Returns:

  • (Integer)


4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
# File 'lib/aws-sdk-medialive/types.rb', line 4408

class Eac3AtmosSettings < Struct.new(
  :bitrate,
  :coding_mode,
  :dialnorm,
  :drc_line,
  :drc_rf,
  :height_trim,
  :surround_trim)
  SENSITIVE = []
  include Aws::Structure
end

#drc_lineString

Sets the Dolby dynamic range compression profile.

Returns:

  • (String)


4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
# File 'lib/aws-sdk-medialive/types.rb', line 4408

class Eac3AtmosSettings < Struct.new(
  :bitrate,
  :coding_mode,
  :dialnorm,
  :drc_line,
  :drc_rf,
  :height_trim,
  :surround_trim)
  SENSITIVE = []
  include Aws::Structure
end

#drc_rfString

Sets the profile for heavy Dolby dynamic range compression, ensures that the instantaneous signal peaks do not exceed specified levels.

Returns:

  • (String)


4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
# File 'lib/aws-sdk-medialive/types.rb', line 4408

class Eac3AtmosSettings < Struct.new(
  :bitrate,
  :coding_mode,
  :dialnorm,
  :drc_line,
  :drc_rf,
  :height_trim,
  :surround_trim)
  SENSITIVE = []
  include Aws::Structure
end

#height_trimFloat

Height dimensional trim. Sets the maximum amount to attenuate the height channels when the downstream player isn??t configured to handle Dolby Digital Plus with Dolby Atmos and must remix the channels.

Returns:

  • (Float)


4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
# File 'lib/aws-sdk-medialive/types.rb', line 4408

class Eac3AtmosSettings < Struct.new(
  :bitrate,
  :coding_mode,
  :dialnorm,
  :drc_line,
  :drc_rf,
  :height_trim,
  :surround_trim)
  SENSITIVE = []
  include Aws::Structure
end

#surround_trimFloat

Surround dimensional trim. Sets the maximum amount to attenuate the surround channels when the downstream player isn’t configured to handle Dolby Digital Plus with Dolby Atmos and must remix the channels.

Returns:

  • (Float)


4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
# File 'lib/aws-sdk-medialive/types.rb', line 4408

class Eac3AtmosSettings < Struct.new(
  :bitrate,
  :coding_mode,
  :dialnorm,
  :drc_line,
  :drc_rf,
  :height_trim,
  :surround_trim)
  SENSITIVE = []
  include Aws::Structure
end