Class: Aws::MediaLive::Types::EmbeddedSourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::EmbeddedSourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Embedded Source Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#convert_608_to_708 ⇒ String
If upconvert, 608 data is both passed through via the “608 compatibility bytes” fields of the 708 wrapper as well as translated into 708.
-
#scte_20_detection ⇒ String
Set to “auto” to handle streams with intermittent and/or non-aligned SCTE-20 and Embedded captions.
-
#source_608_channel_number ⇒ Integer
Specifies the 608/708 channel number within the video track from which to extract captions.
-
#source_608_track_number ⇒ Integer
This field is unused and deprecated.
Instance Attribute Details
#convert_608_to_708 ⇒ String
If upconvert, 608 data is both passed through via the “608 compatibility bytes” fields of the 708 wrapper as well as translated into 708. 708 data present in the source content will be discarded.
4653 4654 4655 4656 4657 4658 4659 4660 |
# File 'lib/aws-sdk-medialive/types.rb', line 4653 class EmbeddedSourceSettings < Struct.new( :convert_608_to_708, :scte_20_detection, :source_608_channel_number, :source_608_track_number) SENSITIVE = [] include Aws::Structure end |
#scte_20_detection ⇒ String
Set to “auto” to handle streams with intermittent and/or non-aligned SCTE-20 and Embedded captions.
4653 4654 4655 4656 4657 4658 4659 4660 |
# File 'lib/aws-sdk-medialive/types.rb', line 4653 class EmbeddedSourceSettings < Struct.new( :convert_608_to_708, :scte_20_detection, :source_608_channel_number, :source_608_track_number) SENSITIVE = [] include Aws::Structure end |
#source_608_channel_number ⇒ Integer
Specifies the 608/708 channel number within the video track from which to extract captions. Unused for passthrough.
4653 4654 4655 4656 4657 4658 4659 4660 |
# File 'lib/aws-sdk-medialive/types.rb', line 4653 class EmbeddedSourceSettings < Struct.new( :convert_608_to_708, :scte_20_detection, :source_608_channel_number, :source_608_track_number) SENSITIVE = [] include Aws::Structure end |
#source_608_track_number ⇒ Integer
This field is unused and deprecated.
4653 4654 4655 4656 4657 4658 4659 4660 |
# File 'lib/aws-sdk-medialive/types.rb', line 4653 class EmbeddedSourceSettings < Struct.new( :convert_608_to_708, :scte_20_detection, :source_608_channel_number, :source_608_track_number) SENSITIVE = [] include Aws::Structure end |