Class: Aws::MediaLive::Types::FecOutputSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::FecOutputSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Fec Output Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_depth ⇒ Integer
Parameter D from SMPTE 2022-1.
-
#include_fec ⇒ String
Enables column only or column and row based FEC.
-
#row_length ⇒ Integer
Parameter L from SMPTE 2022-1.
Instance Attribute Details
#column_depth ⇒ Integer
Parameter D from SMPTE 2022-1. The height of the FEC protection matrix. The number of transport stream packets per column error correction packet. Must be between 4 and 20, inclusive.
4913 4914 4915 4916 4917 4918 4919 |
# File 'lib/aws-sdk-medialive/types.rb', line 4913 class FecOutputSettings < Struct.new( :column_depth, :include_fec, :row_length) SENSITIVE = [] include Aws::Structure end |
#include_fec ⇒ String
Enables column only or column and row based FEC
4913 4914 4915 4916 4917 4918 4919 |
# File 'lib/aws-sdk-medialive/types.rb', line 4913 class FecOutputSettings < Struct.new( :column_depth, :include_fec, :row_length) SENSITIVE = [] include Aws::Structure end |
#row_length ⇒ Integer
Parameter L from SMPTE 2022-1. The width of the FEC protection matrix. Must be between 1 and 20, inclusive. If only Column FEC is used, then larger values increase robustness. If Row FEC is used, then this is the number of transport stream packets per row error correction packet, and the value must be between 4 and 20, inclusive, if includeFec is columnAndRow. If includeFec is column, this value must be 1 to 20, inclusive.
4913 4914 4915 4916 4917 4918 4919 |
# File 'lib/aws-sdk-medialive/types.rb', line 4913 class FecOutputSettings < Struct.new( :column_depth, :include_fec, :row_length) SENSITIVE = [] include Aws::Structure end |