Class: Aws::MediaLive::Types::FrameCaptureOutputSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Frame Capture Output Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#name_modifierString

Required if the output group contains more than one output. This modifier forms part of the output file name.

Returns:

  • (String)


5098
5099
5100
5101
5102
# File 'lib/aws-sdk-medialive/types.rb', line 5098

class FrameCaptureOutputSettings < Struct.new(
  :name_modifier)
  SENSITIVE = []
  include Aws::Structure
end