Class: Aws::MediaLive::Types::Hdr10Settings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::Hdr10Settings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Hdr10 Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_cll ⇒ Integer
Maximum Content Light Level An integer metadata value defining the maximum light level, in nits, of any single pixel within an encoded HDR video stream or file.
-
#max_fall ⇒ Integer
Maximum Frame Average Light Level An integer metadata value defining the maximum average light level, in nits, for any single frame within an encoded HDR video stream or file.
Instance Attribute Details
#max_cll ⇒ Integer
Maximum Content Light Level An integer metadata value defining the maximum light level, in nits, of any single pixel within an encoded HDR video stream or file.
6029 6030 6031 6032 6033 6034 |
# File 'lib/aws-sdk-medialive/types.rb', line 6029 class Hdr10Settings < Struct.new( :max_cll, :max_fall) SENSITIVE = [] include Aws::Structure end |
#max_fall ⇒ Integer
Maximum Frame Average Light Level An integer metadata value defining the maximum average light level, in nits, for any single frame within an encoded HDR video stream or file.
6029 6030 6031 6032 6033 6034 |
# File 'lib/aws-sdk-medialive/types.rb', line 6029 class Hdr10Settings < Struct.new( :max_cll, :max_fall) SENSITIVE = [] include Aws::Structure end |