Class: Aws::MediaLive::Types::HlsAkamaiSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Hls Akamai Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_retry_intervalInteger

Number of seconds to wait before retrying connection to the CDN if the connection is lost.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
# File 'lib/aws-sdk-medialive/types.rb', line 6075

class HlsAkamaiSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :http_transfer_mode,
  :num_retries,
  :restart_delay,
  :salt,
  :token)
  SENSITIVE = []
  include Aws::Structure
end

#filecache_durationInteger

Size in seconds of file cache for streaming outputs.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
# File 'lib/aws-sdk-medialive/types.rb', line 6075

class HlsAkamaiSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :http_transfer_mode,
  :num_retries,
  :restart_delay,
  :salt,
  :token)
  SENSITIVE = []
  include Aws::Structure
end

#http_transfer_modeString

Specify whether or not to use chunked transfer encoding to Akamai. User should contact Akamai to enable this feature.

Returns:

  • (String)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
# File 'lib/aws-sdk-medialive/types.rb', line 6075

class HlsAkamaiSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :http_transfer_mode,
  :num_retries,
  :restart_delay,
  :salt,
  :token)
  SENSITIVE = []
  include Aws::Structure
end

#num_retriesInteger

Number of retry attempts that will be made before the Live Event is put into an error state. Applies only if the CDN destination URI begins with "s3" or "mediastore". For other URIs, the value is always 3.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
# File 'lib/aws-sdk-medialive/types.rb', line 6075

class HlsAkamaiSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :http_transfer_mode,
  :num_retries,
  :restart_delay,
  :salt,
  :token)
  SENSITIVE = []
  include Aws::Structure
end

#restart_delayInteger

If a streaming output fails, number of seconds to wait until a restart is initiated. A value of 0 means never restart.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
# File 'lib/aws-sdk-medialive/types.rb', line 6075

class HlsAkamaiSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :http_transfer_mode,
  :num_retries,
  :restart_delay,
  :salt,
  :token)
  SENSITIVE = []
  include Aws::Structure
end

#saltString

Salt for authenticated Akamai.

Returns:

  • (String)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
# File 'lib/aws-sdk-medialive/types.rb', line 6075

class HlsAkamaiSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :http_transfer_mode,
  :num_retries,
  :restart_delay,
  :salt,
  :token)
  SENSITIVE = []
  include Aws::Structure
end

#tokenString

Token parameter for authenticated akamai. If not specified, _gda_ is used.

Returns:

  • (String)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
# File 'lib/aws-sdk-medialive/types.rb', line 6075

class HlsAkamaiSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :http_transfer_mode,
  :num_retries,
  :restart_delay,
  :salt,
  :token)
  SENSITIVE = []
  include Aws::Structure
end