Class: Aws::MediaLive::Types::HlsBasicPutSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Hls Basic Put Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_retry_intervalInteger

Number of seconds to wait before retrying connection to the CDN if the connection is lost.

Returns:

  • (Integer)


6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-medialive/types.rb', line 6049

class HlsBasicPutSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end

#filecache_durationInteger

Size in seconds of file cache for streaming outputs.

Returns:

  • (Integer)


6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-medialive/types.rb', line 6049

class HlsBasicPutSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end

#num_retriesInteger

Number of retry attempts that will be made before the Live Event is put into an error state. Applies only if the CDN destination URI begins with “s3” or “mediastore”. For other URIs, the value is always 3.

Returns:

  • (Integer)


6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-medialive/types.rb', line 6049

class HlsBasicPutSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end

#restart_delayInteger

If a streaming output fails, number of seconds to wait until a restart is initiated. A value of 0 means never restart.

Returns:

  • (Integer)


6049
6050
6051
6052
6053
6054
6055
6056
# File 'lib/aws-sdk-medialive/types.rb', line 6049

class HlsBasicPutSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end