Class: Aws::MediaLive::Types::HlsMediaStoreSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::HlsMediaStoreSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Hls Media Store Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_retry_interval ⇒ Integer
Number of seconds to wait before retrying connection to the CDN if the connection is lost.
-
#filecache_duration ⇒ Integer
Size in seconds of file cache for streaming outputs.
-
#media_store_storage_class ⇒ String
When set to temporal, output files are stored in non-persistent memory for faster reading and writing.
-
#num_retries ⇒ Integer
Number of retry attempts that will be made before the Live Event is put into an error state.
-
#restart_delay ⇒ Integer
If a streaming output fails, number of seconds to wait until a restart is initiated.
Instance Attribute Details
#connection_retry_interval ⇒ Integer
Number of seconds to wait before retrying connection to the CDN if the connection is lost.
6536 6537 6538 6539 6540 6541 6542 6543 6544 |
# File 'lib/aws-sdk-medialive/types.rb', line 6536 class HlsMediaStoreSettings < Struct.new( :connection_retry_interval, :filecache_duration, :media_store_storage_class, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#filecache_duration ⇒ Integer
Size in seconds of file cache for streaming outputs.
6536 6537 6538 6539 6540 6541 6542 6543 6544 |
# File 'lib/aws-sdk-medialive/types.rb', line 6536 class HlsMediaStoreSettings < Struct.new( :connection_retry_interval, :filecache_duration, :media_store_storage_class, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#media_store_storage_class ⇒ String
When set to temporal, output files are stored in non-persistent memory for faster reading and writing.
6536 6537 6538 6539 6540 6541 6542 6543 6544 |
# File 'lib/aws-sdk-medialive/types.rb', line 6536 class HlsMediaStoreSettings < Struct.new( :connection_retry_interval, :filecache_duration, :media_store_storage_class, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#num_retries ⇒ Integer
Number of retry attempts that will be made before the Live Event is put into an error state. Applies only if the CDN destination URI begins with “s3” or “mediastore”. For other URIs, the value is always 3.
6536 6537 6538 6539 6540 6541 6542 6543 6544 |
# File 'lib/aws-sdk-medialive/types.rb', line 6536 class HlsMediaStoreSettings < Struct.new( :connection_retry_interval, :filecache_duration, :media_store_storage_class, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#restart_delay ⇒ Integer
If a streaming output fails, number of seconds to wait until a restart is initiated. A value of 0 means never restart.
6536 6537 6538 6539 6540 6541 6542 6543 6544 |
# File 'lib/aws-sdk-medialive/types.rb', line 6536 class HlsMediaStoreSettings < Struct.new( :connection_retry_interval, :filecache_duration, :media_store_storage_class, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |