Class: Aws::MediaLive::Types::HlsOutputSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::HlsOutputSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Hls Output Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#h265_packaging_type ⇒ String
Only applicable when this output is referencing an H.265 video description.
-
#hls_settings ⇒ Types::HlsSettings
Settings regarding the underlying stream.
-
#name_modifier ⇒ String
String concatenated to the end of the destination filename.
-
#segment_modifier ⇒ String
String concatenated to end of segment filenames.
Instance Attribute Details
#h265_packaging_type ⇒ String
Only applicable when this output is referencing an H.265 video description. Specifies whether MP4 segments should be packaged as HEV1 or HVC1.
6633 6634 6635 6636 6637 6638 6639 6640 |
# File 'lib/aws-sdk-medialive/types.rb', line 6633 class HlsOutputSettings < Struct.new( :h265_packaging_type, :hls_settings, :name_modifier, :segment_modifier) SENSITIVE = [] include Aws::Structure end |
#hls_settings ⇒ Types::HlsSettings
Settings regarding the underlying stream. These settings are different for audio-only outputs.
6633 6634 6635 6636 6637 6638 6639 6640 |
# File 'lib/aws-sdk-medialive/types.rb', line 6633 class HlsOutputSettings < Struct.new( :h265_packaging_type, :hls_settings, :name_modifier, :segment_modifier) SENSITIVE = [] include Aws::Structure end |
#name_modifier ⇒ String
String concatenated to the end of the destination filename. Accepts \"Format Identifiers\":#formatIdentifierParameters.
6633 6634 6635 6636 6637 6638 6639 6640 |
# File 'lib/aws-sdk-medialive/types.rb', line 6633 class HlsOutputSettings < Struct.new( :h265_packaging_type, :hls_settings, :name_modifier, :segment_modifier) SENSITIVE = [] include Aws::Structure end |
#segment_modifier ⇒ String
String concatenated to end of segment filenames.
6633 6634 6635 6636 6637 6638 6639 6640 |
# File 'lib/aws-sdk-medialive/types.rb', line 6633 class HlsOutputSettings < Struct.new( :h265_packaging_type, :hls_settings, :name_modifier, :segment_modifier) SENSITIVE = [] include Aws::Structure end |