Class: Aws::MediaLive::Types::InferenceSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Configures Elemental Inference features in a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_feed_inputsArray<Types::AudioFeedInput>

A list of audio feed inputs that map audio selectors in the channel to feed inputs on the associated Elemental Inference feed.

Returns:



23220
23221
23222
23223
23224
23225
23226
# File 'lib/aws-sdk-medialive/types.rb', line 23220

class InferenceSettings < Struct.new(
  :feed_arn,
  :audio_feed_inputs,
  :enrichment_methods)
  SENSITIVE = []
  include Aws::Structure
end

#enrichment_methodsArray<String>

The set of Contextual Metadata Enrichment methods enabled for this channel. Each method represents a specific way the channel will use the inference feed to augment its output with contextual metadata. An empty array (or omitting the field) disables enrichment. Order is not significant; duplicate values are not permitted.

Returns:

  • (Array<String>)


23220
23221
23222
23223
23224
23225
23226
# File 'lib/aws-sdk-medialive/types.rb', line 23220

class InferenceSettings < Struct.new(
  :feed_arn,
  :audio_feed_inputs,
  :enrichment_methods)
  SENSITIVE = []
  include Aws::Structure
end

#feed_arnString

The ARN of the feed resource that is associated with this channel. The feed is a resource in the Elemental Inference service.

Returns:

  • (String)


23220
23221
23222
23223
23224
23225
23226
# File 'lib/aws-sdk-medialive/types.rb', line 23220

class InferenceSettings < Struct.new(
  :feed_arn,
  :audio_feed_inputs,
  :enrichment_methods)
  SENSITIVE = []
  include Aws::Structure
end