Class: Aws::MediaLive::Types::Input

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Unique ARN of the input (generated, immutable).

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#attached_channelsArray<String>

A list of channel IDs that that input is attached to (currently an input can only be attached to one channel).

Returns:

  • (Array<String>)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::InputDestination>

A list of the destinations of the input (PUSH-type).

Returns:



6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The generated ID of the input (unique for user account, immutable).

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_classString

STANDARD - MediaLive expects two sources to be connected to this input. If the channel is also STANDARD, both sources will be ingested. If the channel is SINGLE_PIPELINE, only the first source will be ingested; the second source will always be ignored, even if the first source fails. SINGLE_PIPELINE - You can connect only one source to this input. If the ChannelClass is also SINGLE_PIPELINE, this value is valid. If the ChannelClass is STANDARD, this value is not valid because the channel requires two sources in the input.

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_devicesArray<Types::InputDeviceSettings>

Settings for the input devices.

Returns:



6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_network_locationString

The location of this input. AWS, for an input existing in the AWS Cloud, On-Prem for an input in a customer network.

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_partner_idsArray<String>

A list of IDs for all Inputs which are partners of this one.

Returns:

  • (Array<String>)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_source_typeString

Certain pull input sources can be dynamic, meaning that they can have their URL’s dynamically changes during input switch actions. Presently, this functionality only works with MP4_FILE and TS_FILE inputs.

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#media_connect_flowsArray<Types::MediaConnectFlow>

A list of MediaConnect Flows for this input.

Returns:



6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#multicast_settingsTypes::MulticastSettings

Multicast Input settings.



6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The user-assigned name (This is a mutable value).

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the role this input assumes during and after creation.

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#router_settingsTypes::RouterInputSettings

Information about any MediaConnect router association with this input.



6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#sdi_sourcesArray<String>

SDI Sources for this Input.

Returns:

  • (Array<String>)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

A list of IDs for all the Input Security Groups attached to the input.

Returns:

  • (Array<String>)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#smpte_2110_receiver_group_settingsTypes::Smpte2110ReceiverGroupSettings

Include this parameter if the input is a SMPTE 2110 input, to identify the stream sources for this input.



6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::InputSource>

A list of the sources of the input (PULL-type).

Returns:



6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#srt_settingsTypes::SrtSettings

The settings associated with an SRT input.

Returns:



6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of key-value pairs.

Returns:

  • (Hash<String,String>)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The different types of inputs that AWS Elemental MediaLive supports.

Returns:

  • (String)


6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
6753
6754
6755
6756
6757
# File 'lib/aws-sdk-medialive/types.rb', line 6732

class Input < Struct.new(
  :arn,
  :attached_channels,
  :destinations,
  :id,
  :input_class,
  :input_devices,
  :input_partner_ids,
  :input_source_type,
  :media_connect_flows,
  :name,
  :role_arn,
  :security_groups,
  :sources,
  :state,
  :tags,
  :type,
  :srt_settings,
  :input_network_location,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :router_settings)
  SENSITIVE = []
  include Aws::Structure
end