Class: Aws::MediaLive::Types::InputDevice

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

An input device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The unique ARN of the input device.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone associated with this input device.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#connection_stateString

The state of the connection between the input device and AWS.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#device_settings_sync_stateString

The status of the action to synchronize the device configuration. If you change the configuration of the input device (for example, the maximum bitrate), MediaLive sends the new data to the device. The device might not update itself immediately. SYNCED means the device has updated its configuration. SYNCING means that it has not updated its configuration.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#device_update_statusString

The status of software on the input device.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#hd_device_settingsTypes::InputDeviceHdSettings

Settings that describe an input device that is type HD.



7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique ID of the input device.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#mac_addressString

The network MAC address of the input device.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#medialive_input_arnsArray<String>

An array of the ARNs for the MediaLive inputs attached to the device. Returned only if the outputType is MEDIALIVE_INPUT.

Returns:

  • (Array<String>)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name that you specify for the input device.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#network_settingsTypes::InputDeviceNetworkSettings

The network settings for the input device.



7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#output_typeString

The output attachment type of the input device. Specifies MEDIACONNECT_FLOW if this device is the source for a MediaConnect flow. Specifies MEDIALIVE_INPUT if this device is the source for a MediaLive input.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#serial_numberString

The unique serial number of the input device.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of key-value pairs.

Returns:

  • (Hash<String,String>)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the input device.

Returns:

  • (String)


7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end

#uhd_device_settingsTypes::InputDeviceUhdSettings

Settings that describe an input device that is type UHD.



7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
7095
7096
7097
7098
# File 'lib/aws-sdk-medialive/types.rb', line 7079

class InputDevice < Struct.new(
  :arn,
  :connection_state,
  :device_settings_sync_state,
  :device_update_status,
  :hd_device_settings,
  :id,
  :mac_address,
  :name,
  :network_settings,
  :serial_number,
  :type,
  :uhd_device_settings,
  :tags,
  :availability_zone,
  :medialive_input_arns,
  :output_type)
  SENSITIVE = []
  include Aws::Structure
end