Class: Aws::MediaLive::Types::InputDeviceHdSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::InputDeviceHdSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Settings that describe the active source from the input device, and the video characteristics of that source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_input ⇒ String
If you specified Auto as the configured input, specifies which of the sources is currently active (SDI or HDMI).
-
#configured_input ⇒ String
The source at the input device that is currently active.
-
#device_state ⇒ String
The state of the input device.
-
#framerate ⇒ Float
The frame rate of the video source.
-
#height ⇒ Integer
The height of the video source, in pixels.
-
#latency_ms ⇒ Integer
The Link device’s buffer size (latency) in milliseconds (ms).
-
#max_bitrate ⇒ Integer
The current maximum bitrate for ingesting this source, in bits per second.
-
#scan_type ⇒ String
The scan type of the video source.
-
#width ⇒ Integer
The width of the video source, in pixels.
Instance Attribute Details
#active_input ⇒ String
If you specified Auto as the configured input, specifies which of the sources is currently active (SDI or HDMI).
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |
#configured_input ⇒ String
The source at the input device that is currently active. You can specify this source.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |
#device_state ⇒ String
The state of the input device.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |
#framerate ⇒ Float
The frame rate of the video source.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |
#height ⇒ Integer
The height of the video source, in pixels.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |
#latency_ms ⇒ Integer
The Link device’s buffer size (latency) in milliseconds (ms). You can specify this value.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |
#max_bitrate ⇒ Integer
The current maximum bitrate for ingesting this source, in bits per second. You can specify this maximum.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |
#scan_type ⇒ String
The scan type of the video source.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |
#width ⇒ Integer
The width of the video source, in pixels.
7267 7268 7269 7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 |
# File 'lib/aws-sdk-medialive/types.rb', line 7267 class InputDeviceHdSettings < Struct.new( :active_input, :configured_input, :device_state, :framerate, :height, :max_bitrate, :scan_type, :width, :latency_ms) SENSITIVE = [] include Aws::Structure end |