Class: Aws::MediaLive::Types::InputDeviceMediaConnectConfigurableSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Parameters required to attach a MediaConnect flow to the device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_arnString

The ARN of the MediaConnect flow to attach this device to.

Returns:

  • (String)


7323
7324
7325
7326
7327
7328
7329
7330
# File 'lib/aws-sdk-medialive/types.rb', line 7323

class InputDeviceMediaConnectConfigurableSettings < Struct.new(
  :flow_arn,
  :role_arn,
  :secret_arn,
  :source_name)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN for the role that MediaLive assumes to access the attached flow and secret. For more information about how to create this role, see the MediaLive user guide.

Returns:

  • (String)


7323
7324
7325
7326
7327
7328
7329
7330
# File 'lib/aws-sdk-medialive/types.rb', line 7323

class InputDeviceMediaConnectConfigurableSettings < Struct.new(
  :flow_arn,
  :role_arn,
  :secret_arn,
  :source_name)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The ARN for the secret that holds the encryption key to encrypt the content output by the device.

Returns:

  • (String)


7323
7324
7325
7326
7327
7328
7329
7330
# File 'lib/aws-sdk-medialive/types.rb', line 7323

class InputDeviceMediaConnectConfigurableSettings < Struct.new(
  :flow_arn,
  :role_arn,
  :secret_arn,
  :source_name)
  SENSITIVE = []
  include Aws::Structure
end

#source_nameString

The name of the MediaConnect Flow source to stream to.

Returns:

  • (String)


7323
7324
7325
7326
7327
7328
7329
7330
# File 'lib/aws-sdk-medialive/types.rb', line 7323

class InputDeviceMediaConnectConfigurableSettings < Struct.new(
  :flow_arn,
  :role_arn,
  :secret_arn,
  :source_name)
  SENSITIVE = []
  include Aws::Structure
end