Class: Aws::MediaLive::Types::InputDeviceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::InputDeviceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Details of the input device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The unique ARN of the input device.
-
#availability_zone ⇒ String
The Availability Zone associated with this input device.
-
#connection_state ⇒ String
The state of the connection between the input device and AWS.
-
#device_settings_sync_state ⇒ String
The status of the action to synchronize the device configuration.
-
#device_update_status ⇒ String
The status of software on the input device.
-
#hd_device_settings ⇒ Types::InputDeviceHdSettings
Settings that describe an input device that is type HD.
-
#id ⇒ String
The unique ID of the input device.
-
#mac_address ⇒ String
The network MAC address of the input device.
-
#medialive_input_arns ⇒ Array<String>
An array of the ARNs for the MediaLive inputs attached to the device.
-
#name ⇒ String
A name that you specify for the input device.
-
#network_settings ⇒ Types::InputDeviceNetworkSettings
Network settings for the input device.
-
#output_type ⇒ String
The output attachment type of the input device.
-
#serial_number ⇒ String
The unique serial number of the input device.
-
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
-
#type ⇒ String
The type of the input device.
-
#uhd_device_settings ⇒ Types::InputDeviceUhdSettings
Settings that describe an input device that is type UHD.
Instance Attribute Details
#arn ⇒ String
The unique ARN of the input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone associated with this input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#connection_state ⇒ String
The state of the connection between the input device and AWS.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#device_settings_sync_state ⇒ String
The status of the action to synchronize the device configuration. If you change the configuration of the input device (for example, the maximum bitrate), MediaLive sends the new data to the device. The device might not update itself immediately. SYNCED means the device has updated its configuration. SYNCING means that it has not updated its configuration.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#device_update_status ⇒ String
The status of software on the input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#hd_device_settings ⇒ Types::InputDeviceHdSettings
Settings that describe an input device that is type HD.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID of the input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#mac_address ⇒ String
The network MAC address of the input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#medialive_input_arns ⇒ Array<String>
An array of the ARNs for the MediaLive inputs attached to the device. Returned only if the outputType is MEDIALIVE_INPUT.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name that you specify for the input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#network_settings ⇒ Types::InputDeviceNetworkSettings
Network settings for the input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#output_type ⇒ String
The output attachment type of the input device. Specifies MEDIACONNECT_FLOW if this device is the source for a MediaConnect flow. Specifies MEDIALIVE_INPUT if this device is the source for a MediaLive input.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#serial_number ⇒ String
The unique serial number of the input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the input device.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#uhd_device_settings ⇒ Types::InputDeviceUhdSettings
Settings that describe an input device that is type UHD.
7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 |
# File 'lib/aws-sdk-medialive/types.rb', line 7484 class InputDeviceSummary < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |