Class: Aws::MediaLive::Types::InputSecurityGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::InputSecurityGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
An Input Security Group
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Unique ARN of Input Security Group.
-
#channels ⇒ Array<String>
The list of channels currently using this Input Security Group as their channel security group.
-
#id ⇒ String
The Id of the Input Security Group.
-
#inputs ⇒ Array<String>
The list of inputs currently using this Input Security Group.
-
#state ⇒ String
The current state of the Input Security Group.
-
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
-
#whitelist_rules ⇒ Array<Types::InputWhitelistRule>
Whitelist rules and their sync status.
Instance Attribute Details
#arn ⇒ String
Unique ARN of Input Security Group
7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 |
# File 'lib/aws-sdk-medialive/types.rb', line 7700 class InputSecurityGroup < Struct.new( :arn, :id, :inputs, :state, :tags, :whitelist_rules, :channels) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Array<String>
The list of channels currently using this Input Security Group as their channel security group.
7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 |
# File 'lib/aws-sdk-medialive/types.rb', line 7700 class InputSecurityGroup < Struct.new( :arn, :id, :inputs, :state, :tags, :whitelist_rules, :channels) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The Id of the Input Security Group
7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 |
# File 'lib/aws-sdk-medialive/types.rb', line 7700 class InputSecurityGroup < Struct.new( :arn, :id, :inputs, :state, :tags, :whitelist_rules, :channels) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The list of inputs currently using this Input Security Group.
7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 |
# File 'lib/aws-sdk-medialive/types.rb', line 7700 class InputSecurityGroup < Struct.new( :arn, :id, :inputs, :state, :tags, :whitelist_rules, :channels) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Input Security Group.
7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 |
# File 'lib/aws-sdk-medialive/types.rb', line 7700 class InputSecurityGroup < Struct.new( :arn, :id, :inputs, :state, :tags, :whitelist_rules, :channels) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 |
# File 'lib/aws-sdk-medialive/types.rb', line 7700 class InputSecurityGroup < Struct.new( :arn, :id, :inputs, :state, :tags, :whitelist_rules, :channels) SENSITIVE = [] include Aws::Structure end |
#whitelist_rules ⇒ Array<Types::InputWhitelistRule>
Whitelist rules and their sync status
7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 |
# File 'lib/aws-sdk-medialive/types.rb', line 7700 class InputSecurityGroup < Struct.new( :arn, :id, :inputs, :state, :tags, :whitelist_rules, :channels) SENSITIVE = [] include Aws::Structure end |