Class: Aws::MediaLive::Types::InputVpcRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::InputVpcRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Settings for a private VPC Input. When this property is specified, the input destination addresses will be created in a VPC rather than with public Internet addresses. This property requires setting the roleArn property on Input creation. Not compatible with the inputSecurityGroups property.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group_ids ⇒ Array<String>
A list of up to 5 EC2 VPC security group IDs to attach to the Input VPC network interfaces.
-
#subnet_ids ⇒ Array<String>
A list of 2 VPC subnet IDs from the same VPC.
Instance Attribute Details
#security_group_ids ⇒ Array<String>
A list of up to 5 EC2 VPC security group IDs to attach to the Input VPC network interfaces. Requires subnetIds. If none are specified then the VPC default security group will be used.
7932 7933 7934 7935 7936 7937 |
# File 'lib/aws-sdk-medialive/types.rb', line 7932 class InputVpcRequest < Struct.new( :security_group_ids, :subnet_ids) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
A list of 2 VPC subnet IDs from the same VPC. Subnet IDs must be mapped to two unique availability zones (AZ).
7932 7933 7934 7935 7936 7937 |
# File 'lib/aws-sdk-medialive/types.rb', line 7932 class InputVpcRequest < Struct.new( :security_group_ids, :subnet_ids) SENSITIVE = [] include Aws::Structure end |