Class: Aws::MediaLive::Types::LinkedChannelSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::LinkedChannelSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Configuration for linked channel relationships
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#follower_channel_settings ⇒ Types::FollowerChannelSettings
Settings for a follower channel in a linked pair.
-
#primary_channel_settings ⇒ Types::PrimaryChannelSettings
Settings for a primary (leader) channel in a linked pair.
Instance Attribute Details
#follower_channel_settings ⇒ Types::FollowerChannelSettings
Settings for a follower channel in a linked pair
22595 22596 22597 22598 22599 22600 |
# File 'lib/aws-sdk-medialive/types.rb', line 22595 class LinkedChannelSettings < Struct.new( :follower_channel_settings, :primary_channel_settings) SENSITIVE = [] include Aws::Structure end |
#primary_channel_settings ⇒ Types::PrimaryChannelSettings
Settings for a primary (leader) channel in a linked pair
22595 22596 22597 22598 22599 22600 |
# File 'lib/aws-sdk-medialive/types.rb', line 22595 class LinkedChannelSettings < Struct.new( :follower_channel_settings, :primary_channel_settings) SENSITIVE = [] include Aws::Structure end |