Class: Aws::MediaLive::Types::MediaPackageOutputDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::MediaPackageOutputDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
MediaPackage Output Destination Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_endpoint_id ⇒ String
Endpoint 1 or 2 of the channel in MediaPackageV2.
-
#channel_group ⇒ String
Name of the channel group in MediaPackageV2.
-
#channel_id ⇒ String
ID of the channel in MediaPackage that is the destination for this output group.
-
#channel_name ⇒ String
Name of the channel in MediaPackageV2.
-
#media_package_region_name ⇒ String
Region the channel group and channel are located in for MediaPackageV2.
Instance Attribute Details
#channel_endpoint_id ⇒ String
Endpoint 1 or 2 of the channel in MediaPackageV2. Only use if you are sending CMAF Ingest output to a CMAF ingest endpoint on a MediaPackage channel that uses MediaPackage v2.
9217 9218 9219 9220 9221 9222 9223 9224 9225 |
# File 'lib/aws-sdk-medialive/types.rb', line 9217 class MediaPackageOutputDestinationSettings < Struct.new( :channel_id, :channel_group, :channel_name, :channel_endpoint_id, :media_package_region_name) SENSITIVE = [] include Aws::Structure end |
#channel_group ⇒ String
Name of the channel group in MediaPackageV2. Only use if you are sending CMAF Ingest output to a CMAF ingest endpoint on a MediaPackage channel that uses MediaPackage v2.
9217 9218 9219 9220 9221 9222 9223 9224 9225 |
# File 'lib/aws-sdk-medialive/types.rb', line 9217 class MediaPackageOutputDestinationSettings < Struct.new( :channel_id, :channel_group, :channel_name, :channel_endpoint_id, :media_package_region_name) SENSITIVE = [] include Aws::Structure end |
#channel_id ⇒ String
ID of the channel in MediaPackage that is the destination for this output group. You do not need to specify the individual inputs in MediaPackage; MediaLive will handle the connection of the two MediaLive pipelines to the two MediaPackage inputs. The MediaPackage channel and MediaLive channel must be in the same region.
9217 9218 9219 9220 9221 9222 9223 9224 9225 |
# File 'lib/aws-sdk-medialive/types.rb', line 9217 class MediaPackageOutputDestinationSettings < Struct.new( :channel_id, :channel_group, :channel_name, :channel_endpoint_id, :media_package_region_name) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
Name of the channel in MediaPackageV2. Only use if you are sending CMAF Ingest output to a CMAF ingest endpoint on a MediaPackage channel that uses MediaPackage v2.
9217 9218 9219 9220 9221 9222 9223 9224 9225 |
# File 'lib/aws-sdk-medialive/types.rb', line 9217 class MediaPackageOutputDestinationSettings < Struct.new( :channel_id, :channel_group, :channel_name, :channel_endpoint_id, :media_package_region_name) SENSITIVE = [] include Aws::Structure end |
#media_package_region_name ⇒ String
Region the channel group and channel are located in for MediaPackageV2. Only use if you are sending CMAF Ingest output to a CMAF ingest endpoint on a MediaPackage channel that uses MediaPackage v2.
9217 9218 9219 9220 9221 9222 9223 9224 9225 |
# File 'lib/aws-sdk-medialive/types.rb', line 9217 class MediaPackageOutputDestinationSettings < Struct.new( :channel_id, :channel_group, :channel_name, :channel_endpoint_id, :media_package_region_name) SENSITIVE = [] include Aws::Structure end |