Class: Aws::MediaLive::Types::MediaPackageV2GroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::MediaPackageV2GroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Media Package V2 Group Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_destinations ⇒ Array<Types::MediaPackageAdditionalDestinations>
Optional an array of additional destinational HTTP destinations for the OutputGroup outputs.
-
#caption_language_mappings ⇒ Array<Types::CaptionLanguageMapping>
Mapping of up to 4 caption channels to caption languages.
-
#id_3_behavior ⇒ String
Set to ENABLED to enable ID3 metadata insertion.
-
#klv_behavior ⇒ String
If set to passthrough, passes any KLV data from the input source to this output.
-
#nielsen_id_3_behavior ⇒ String
If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.
-
#scte_35_type ⇒ String
SCTE-35 insertion type.
-
#segment_length ⇒ Integer
The nominal duration of segments.
-
#segment_length_units ⇒ String
Time unit for segment length parameter.
-
#timed_metadata_id_3_frame ⇒ String
Set to none if you don't want to insert a timecode in the output.
-
#timed_metadata_id_3_period ⇒ Integer
If you set up to insert a timecode in the output, specify the frequency for the frame, in seconds.
-
#timed_metadata_passthrough ⇒ String
Set to enabled to pass through ID3 metadata from the input sources.
Instance Attribute Details
#additional_destinations ⇒ Array<Types::MediaPackageAdditionalDestinations>
Optional an array of additional destinational HTTP destinations for the OutputGroup outputs
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#caption_language_mappings ⇒ Array<Types::CaptionLanguageMapping>
Mapping of up to 4 caption channels to caption languages.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#id_3_behavior ⇒ String
Set to ENABLED to enable ID3 metadata insertion. To include metadata, you configure other parameters in the output group, or you add an ID3 action to the channel schedule.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#klv_behavior ⇒ String
If set to passthrough, passes any KLV data from the input source to this output.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#nielsen_id_3_behavior ⇒ String
If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#scte_35_type ⇒ String
SCTE-35 insertion type. Option "none" indicates that a SCTE-35 marker will not be inserted, nor will an IDR be inserted at the SCTE-35 cue point, nor will the segment be segmented. Option "scte35WithoutIdr" indicates that a SCTE-35 marker will be inserted to indicate the cue point, but MediaLive will not insert an IDR on that frame nor will it introduce a new segment boundary there if it wasn't already going to be one (this option is required for use with downstream multiview bitstream stitching workflows). Option "scte35WithoutSegmentation" indicates that a SCTE-35 marker will be inserted to indicate the cue point, and an IDR will be inserted on that frame so that a downstream re-packager might split the segment there, but MediaLive itself will not introduce a new segment boundary there.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#segment_length ⇒ Integer
The nominal duration of segments. The units are specified in SegmentLengthUnits. The segments will end on the next keyframe after the specified duration, so the actual segment length might be longer, and it might be a fraction of the units.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#segment_length_units ⇒ String
Time unit for segment length parameter.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_id_3_frame ⇒ String
Set to none if you don't want to insert a timecode in the output. Otherwise choose the frame type for the timecode.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_id_3_period ⇒ Integer
If you set up to insert a timecode in the output, specify the frequency for the frame, in seconds.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_passthrough ⇒ String
Set to enabled to pass through ID3 metadata from the input sources.
22406 22407 22408 22409 22410 22411 22412 22413 22414 22415 22416 22417 22418 22419 22420 |
# File 'lib/aws-sdk-medialive/types.rb', line 22406 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |