Class: Aws::MediaLive::Types::MultiplexM2tsSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::MultiplexM2tsSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Multiplex M2ts Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#absent_input_audio_behavior ⇒ String
When set to drop, output audio streams will be removed from the program if the selected input audio stream is removed from the input.
-
#arib ⇒ String
When set to enabled, uses ARIB-compliant field muxing and removes video descriptor.
-
#audio_buffer_model ⇒ String
When set to dvb, uses DVB buffer model for Dolby Digital audio.
-
#audio_frames_per_pes ⇒ Integer
The number of audio frames to insert for each PES packet.
-
#audio_stream_type ⇒ String
When set to atsc, uses stream type = 0x81 for AC3 and stream type = 0x87 for EAC3.
-
#cc_descriptor ⇒ String
When set to enabled, generates captionServiceDescriptor in PMT.
-
#ebif ⇒ String
If set to passthrough, passes any EBIF data from the input source to this output.
-
#es_rate_in_pes ⇒ String
Include or exclude the ES Rate field in the PES header.
-
#klv ⇒ String
If set to passthrough, passes any KLV data from the input source to this output.
-
#nielsen_id_3_behavior ⇒ String
If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.
-
#pcr_control ⇒ String
When set to pcrEveryPesPacket, a Program Clock Reference value is inserted for every Packetized Elementary Stream (PES) header.
-
#pcr_period ⇒ Integer
Maximum time in milliseconds between Program Clock Reference (PCRs) inserted into the transport stream.
-
#scte_35_control ⇒ String
SCTE-35 control.
-
#scte_35_preroll_pullup_milliseconds ⇒ Float
Defines the amount SCTE-35 preroll will be increased (in milliseconds) on the output.
Instance Attribute Details
#absent_input_audio_behavior ⇒ String
When set to drop, output audio streams will be removed from the program if the selected input audio stream is removed from the input. This allows the output audio configuration to dynamically change based on input configuration. If this is set to encodeSilence, all output audio streams will output encoded silence when not connected to an active input stream.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#arib ⇒ String
When set to enabled, uses ARIB-compliant field muxing and removes video descriptor.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#audio_buffer_model ⇒ String
When set to dvb, uses DVB buffer model for Dolby Digital audio. When set to atsc, the ATSC model is used.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#audio_frames_per_pes ⇒ Integer
The number of audio frames to insert for each PES packet.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#audio_stream_type ⇒ String
When set to atsc, uses stream type = 0x81 for AC3 and stream type = 0x87 for EAC3. When set to dvb, uses stream type = 0x06.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#cc_descriptor ⇒ String
When set to enabled, generates captionServiceDescriptor in PMT.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#ebif ⇒ String
If set to passthrough, passes any EBIF data from the input source to this output.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#es_rate_in_pes ⇒ String
Include or exclude the ES Rate field in the PES header.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#klv ⇒ String
If set to passthrough, passes any KLV data from the input source to this output.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#nielsen_id_3_behavior ⇒ String
If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#pcr_control ⇒ String
When set to pcrEveryPesPacket, a Program Clock Reference value is inserted for every Packetized Elementary Stream (PES) header. This parameter is effective only when the PCR PID is the same as the video or audio elementary stream.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#pcr_period ⇒ Integer
Maximum time in milliseconds between Program Clock Reference (PCRs) inserted into the transport stream.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#scte_35_control ⇒ String
SCTE-35 control. Option "none" indicates that a SCTE-35 marker will not be inserted, nor will an IDR be inserted at the SCTE-35 cue point, nor will the segment be segmented. Option "scte35WithoutIdr" indicates that a SCTE-35 marker will be inserted to indicate the cue point, but MediaLive will not insert an IDR on that frame nor will it introduce a new segment boundary there if it wasn't already going to be one (this option is required for use with downstream multiview bitstream stitching workflows). Option "passthrough" indicates that a SCTE-35 marker will be inserted to indicate the cue point, and an IDR will be inserted on that frame, and MediaLive itself will introduce a new segment boundary there.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |
#scte_35_preroll_pullup_milliseconds ⇒ Float
Defines the amount SCTE-35 preroll will be increased (in milliseconds) on the output. Preroll is the amount of time between the presence of a SCTE-35 indication in a transport stream and the PTS of the video frame it references. Zero means don't add pullup (it doesn't mean set the preroll to zero). Negative pullup is not supported, which means that you can't make the preroll shorter. Be aware that latency in the output will increase by the pullup amount.
21781 21782 21783 21784 21785 21786 21787 21788 21789 21790 21791 21792 21793 21794 21795 21796 21797 21798 |
# File 'lib/aws-sdk-medialive/types.rb', line 21781 class MultiplexM2tsSettings < Struct.new( :absent_input_audio_behavior, :arib, :audio_buffer_model, :audio_frames_per_pes, :audio_stream_type, :cc_descriptor, :ebif, :es_rate_in_pes, :klv, :nielsen_id_3_behavior, :pcr_control, :pcr_period, :scte_35_control, :scte_35_preroll_pullup_milliseconds) SENSITIVE = [] include Aws::Structure end |