Class: Aws::MediaLive::Types::MultiplexProgram
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::MultiplexProgram
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
The multiplex program object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The MediaLive channel associated with the program.
-
#multiplex_program_settings ⇒ Types::MultiplexProgramSettings
The settings for this multiplex program.
-
#packet_identifiers_map ⇒ Types::MultiplexProgramPacketIdentifiersMap
The packet identifier map for this multiplex program.
-
#pipeline_details ⇒ Array<Types::MultiplexProgramPipelineDetail>
Contains information about the current sources for the specified program in the specified multiplex.
-
#program_name ⇒ String
The name of the multiplex program.
Instance Attribute Details
#channel_id ⇒ String
The MediaLive channel associated with the program.
9814 9815 9816 9817 9818 9819 9820 9821 9822 |
# File 'lib/aws-sdk-medialive/types.rb', line 9814 class MultiplexProgram < Struct.new( :channel_id, :multiplex_program_settings, :packet_identifiers_map, :pipeline_details, :program_name) SENSITIVE = [] include Aws::Structure end |
#multiplex_program_settings ⇒ Types::MultiplexProgramSettings
The settings for this multiplex program.
9814 9815 9816 9817 9818 9819 9820 9821 9822 |
# File 'lib/aws-sdk-medialive/types.rb', line 9814 class MultiplexProgram < Struct.new( :channel_id, :multiplex_program_settings, :packet_identifiers_map, :pipeline_details, :program_name) SENSITIVE = [] include Aws::Structure end |
#packet_identifiers_map ⇒ Types::MultiplexProgramPacketIdentifiersMap
The packet identifier map for this multiplex program.
9814 9815 9816 9817 9818 9819 9820 9821 9822 |
# File 'lib/aws-sdk-medialive/types.rb', line 9814 class MultiplexProgram < Struct.new( :channel_id, :multiplex_program_settings, :packet_identifiers_map, :pipeline_details, :program_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_details ⇒ Array<Types::MultiplexProgramPipelineDetail>
Contains information about the current sources for the specified program in the specified multiplex. Keep in mind that each multiplex pipeline connects to both pipelines in a given source channel (the channel identified by the program). But only one of those channel pipelines is ever active at one time.
9814 9815 9816 9817 9818 9819 9820 9821 9822 |
# File 'lib/aws-sdk-medialive/types.rb', line 9814 class MultiplexProgram < Struct.new( :channel_id, :multiplex_program_settings, :packet_identifiers_map, :pipeline_details, :program_name) SENSITIVE = [] include Aws::Structure end |
#program_name ⇒ String
The name of the multiplex program.
9814 9815 9816 9817 9818 9819 9820 9821 9822 |
# File 'lib/aws-sdk-medialive/types.rb', line 9814 class MultiplexProgram < Struct.new( :channel_id, :multiplex_program_settings, :packet_identifiers_map, :pipeline_details, :program_name) SENSITIVE = [] include Aws::Structure end |