Class: Aws::MediaLive::Types::MultiplexProgramChannelDestinationSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Multiplex Program Input Destination Settings for outputting a Channel to a Multiplex

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#multiplex_idString

The ID of the Multiplex that the encoder is providing output to. You do not need to specify the individual inputs to the Multiplex; MediaLive will handle the connection of the two MediaLive pipelines to the two Multiplex instances. The Multiplex must be in the same region as the Channel.



9842
9843
9844
9845
9846
9847
# File 'lib/aws-sdk-medialive/types.rb', line 9842

class MultiplexProgramChannelDestinationSettings < Struct.new(
  :multiplex_id,
  :program_name)
  SENSITIVE = []
  include Aws::Structure
end

#program_nameString

The program name of the Multiplex program that the encoder is providing output to.



9842
9843
9844
9845
9846
9847
# File 'lib/aws-sdk-medialive/types.rb', line 9842

class MultiplexProgramChannelDestinationSettings < Struct.new(
  :multiplex_id,
  :program_name)
  SENSITIVE = []
  include Aws::Structure
end