Class: Aws::MediaLive::Types::NetworkInputSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::NetworkInputSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Network source to transcode. Must be accessible to the Elemental Live node that is running the live event through a network connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hls_input_settings ⇒ Types::HlsInputSettings
Specifies HLS input settings when the uri is for a HLS manifest.
-
#multicast_input_settings ⇒ Types::MulticastInputSettings
Specifies multicast input settings when the uri is for a multicast event.
-
#server_validation ⇒ String
Check HTTPS server certificates.
Instance Attribute Details
#hls_input_settings ⇒ Types::HlsInputSettings
Specifies HLS input settings when the uri is for a HLS manifest.
10227 10228 10229 10230 10231 10232 10233 |
# File 'lib/aws-sdk-medialive/types.rb', line 10227 class NetworkInputSettings < Struct.new( :hls_input_settings, :server_validation, :multicast_input_settings) SENSITIVE = [] include Aws::Structure end |
#multicast_input_settings ⇒ Types::MulticastInputSettings
Specifies multicast input settings when the uri is for a multicast event.
10227 10228 10229 10230 10231 10232 10233 |
# File 'lib/aws-sdk-medialive/types.rb', line 10227 class NetworkInputSettings < Struct.new( :hls_input_settings, :server_validation, :multicast_input_settings) SENSITIVE = [] include Aws::Structure end |
#server_validation ⇒ String
Check HTTPS server certificates. When set to checkCryptographyOnly, cryptography in the certificate will be checked, but not the server’s name. Certain subdomains (notably S3 buckets that use dots in the bucket name) do not strictly match the corresponding certificate’s wildcard pattern and would otherwise cause the event to error. This setting is ignored for protocols that do not use https.
10227 10228 10229 10230 10231 10232 10233 |
# File 'lib/aws-sdk-medialive/types.rb', line 10227 class NetworkInputSettings < Struct.new( :hls_input_settings, :server_validation, :multicast_input_settings) SENSITIVE = [] include Aws::Structure end |