Class: Aws::MediaLive::Types::NielsenWatermarksSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Nielsen Watermarks Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nielsen_cbet_settingsTypes::NielsenCBET

Complete these fields only if you want to insert watermarks of type Nielsen CBET

Returns:



10338
10339
10340
10341
10342
10343
10344
10345
# File 'lib/aws-sdk-medialive/types.rb', line 10338

class NielsenWatermarksSettings < Struct.new(
  :nielsen_cbet_settings,
  :nielsen_distribution_type,
  :nielsen_naes_ii_nw_settings,
  :nielsen_nw_only_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nielsen_distribution_typeString

Choose the distribution types that you want to assign to the watermarks: - PROGRAM_CONTENT - FINAL_DISTRIBUTOR

Returns:

  • (String)


10338
10339
10340
10341
10342
10343
10344
10345
# File 'lib/aws-sdk-medialive/types.rb', line 10338

class NielsenWatermarksSettings < Struct.new(
  :nielsen_cbet_settings,
  :nielsen_distribution_type,
  :nielsen_naes_ii_nw_settings,
  :nielsen_nw_only_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nielsen_naes_ii_nw_settingsTypes::NielsenNaesIiNw

Complete these fields only if you want to insert watermarks of type Nielsen NAES II (N2) and Nielsen NAES VI (NW).



10338
10339
10340
10341
10342
10343
10344
10345
# File 'lib/aws-sdk-medialive/types.rb', line 10338

class NielsenWatermarksSettings < Struct.new(
  :nielsen_cbet_settings,
  :nielsen_distribution_type,
  :nielsen_naes_ii_nw_settings,
  :nielsen_nw_only_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nielsen_nw_only_settingsTypes::NielsenNwOnly

Complete these fields only if you want to insert watermarks of type Nielsen NAES VI (NW) only, without inserting NAES II (N2) watermarks.



10338
10339
10340
10341
10342
10343
10344
10345
# File 'lib/aws-sdk-medialive/types.rb', line 10338

class NielsenWatermarksSettings < Struct.new(
  :nielsen_cbet_settings,
  :nielsen_distribution_type,
  :nielsen_naes_ii_nw_settings,
  :nielsen_nw_only_settings)
  SENSITIVE = []
  include Aws::Structure
end