Class: Aws::MediaLive::Types::PipelineDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::PipelineDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Runtime details of a pipeline when a channel is running.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_input_attachment_name ⇒ String
The name of the active input attachment currently being ingested by this pipeline.
-
#active_input_switch_action_name ⇒ String
The name of the input switch schedule action that occurred most recently and that resulted in the switch to the current input attachment for this pipeline.
-
#active_motion_graphics_action_name ⇒ String
The name of the motion graphics activate action that occurred most recently and that resulted in the current graphics URI for this pipeline.
-
#active_motion_graphics_uri ⇒ String
The current URI being used for HTML5 motion graphics for this pipeline.
-
#channel_engine_version ⇒ Types::ChannelEngineVersionResponse
Current engine version of the encoder for this pipeline.
-
#media_connect_router_output_connection_map ⇒ Hash<String,Types::MediaConnectRouterOutputConnection>
A map of output names to the MediaConnect Router connection for this pipeline.
-
#pipeline_id ⇒ String
Pipeline ID.
Instance Attribute Details
#active_input_attachment_name ⇒ String
The name of the active input attachment currently being ingested by this pipeline.
10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 10802 |
# File 'lib/aws-sdk-medialive/types.rb', line 10792 class PipelineDetail < Struct.new( :active_input_attachment_name, :active_input_switch_action_name, :active_motion_graphics_action_name, :active_motion_graphics_uri, :pipeline_id, :channel_engine_version, :media_connect_router_output_connection_map) SENSITIVE = [] include Aws::Structure end |
#active_input_switch_action_name ⇒ String
The name of the input switch schedule action that occurred most recently and that resulted in the switch to the current input attachment for this pipeline.
10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 10802 |
# File 'lib/aws-sdk-medialive/types.rb', line 10792 class PipelineDetail < Struct.new( :active_input_attachment_name, :active_input_switch_action_name, :active_motion_graphics_action_name, :active_motion_graphics_uri, :pipeline_id, :channel_engine_version, :media_connect_router_output_connection_map) SENSITIVE = [] include Aws::Structure end |
#active_motion_graphics_action_name ⇒ String
The name of the motion graphics activate action that occurred most recently and that resulted in the current graphics URI for this pipeline.
10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 10802 |
# File 'lib/aws-sdk-medialive/types.rb', line 10792 class PipelineDetail < Struct.new( :active_input_attachment_name, :active_input_switch_action_name, :active_motion_graphics_action_name, :active_motion_graphics_uri, :pipeline_id, :channel_engine_version, :media_connect_router_output_connection_map) SENSITIVE = [] include Aws::Structure end |
#active_motion_graphics_uri ⇒ String
The current URI being used for HTML5 motion graphics for this pipeline.
10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 10802 |
# File 'lib/aws-sdk-medialive/types.rb', line 10792 class PipelineDetail < Struct.new( :active_input_attachment_name, :active_input_switch_action_name, :active_motion_graphics_action_name, :active_motion_graphics_uri, :pipeline_id, :channel_engine_version, :media_connect_router_output_connection_map) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionResponse
Current engine version of the encoder for this pipeline.
10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 10802 |
# File 'lib/aws-sdk-medialive/types.rb', line 10792 class PipelineDetail < Struct.new( :active_input_attachment_name, :active_input_switch_action_name, :active_motion_graphics_action_name, :active_motion_graphics_uri, :pipeline_id, :channel_engine_version, :media_connect_router_output_connection_map) SENSITIVE = [] include Aws::Structure end |
#media_connect_router_output_connection_map ⇒ Hash<String,Types::MediaConnectRouterOutputConnection>
A map of output names to the MediaConnect Router connection for this pipeline. Only present for channels with MediaConnect Router outputs.
10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 10802 |
# File 'lib/aws-sdk-medialive/types.rb', line 10792 class PipelineDetail < Struct.new( :active_input_attachment_name, :active_input_switch_action_name, :active_motion_graphics_action_name, :active_motion_graphics_uri, :pipeline_id, :channel_engine_version, :media_connect_router_output_connection_map) SENSITIVE = [] include Aws::Structure end |
#pipeline_id ⇒ String
Pipeline ID
10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 10802 |
# File 'lib/aws-sdk-medialive/types.rb', line 10792 class PipelineDetail < Struct.new( :active_input_attachment_name, :active_input_switch_action_name, :active_motion_graphics_action_name, :active_motion_graphics_uri, :pipeline_id, :channel_engine_version, :media_connect_router_output_connection_map) SENSITIVE = [] include Aws::Structure end |