Class: Aws::MediaLive::Types::PipelineLockingSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Pipeline Locking Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#pipeline_locking_methodString

The method to use to lock the video frames in the pipelines. sourceTimecode (default): Use the timecode in the source. videoAlignment: Lock frames that the encoder identifies as having matching content. If videoAlignment is selected, existing timecodes will not be used for any locking decisions.

Returns:

  • (String)


10650
10651
10652
10653
10654
# File 'lib/aws-sdk-medialive/types.rb', line 10650

class PipelineLockingSettings < Struct.new(
  :pipeline_locking_method)
  SENSITIVE = []
  include Aws::Structure
end