Class: Aws::MediaLive::Types::PurchaseOffering

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

PurchaseOffering request

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#countInteger

Number of resources



10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
# File 'lib/aws-sdk-medialive/types.rb', line 10896

class PurchaseOffering < Struct.new(
  :count,
  :name,
  :renewal_settings,
  :request_id,
  :start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name for the new reservation



10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
# File 'lib/aws-sdk-medialive/types.rb', line 10896

class PurchaseOffering < Struct.new(
  :count,
  :name,
  :renewal_settings,
  :request_id,
  :start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#renewal_settingsTypes::RenewalSettings

Renewal settings for the reservation



10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
# File 'lib/aws-sdk-medialive/types.rb', line 10896

class PurchaseOffering < Struct.new(
  :count,
  :name,
  :renewal_settings,
  :request_id,
  :start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

Unique request ID to be specified. This is needed to prevent retries from creating multiple resources.A suitable default value is auto-generated. You should normally not need to pass this option.



10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
# File 'lib/aws-sdk-medialive/types.rb', line 10896

class PurchaseOffering < Struct.new(
  :count,
  :name,
  :renewal_settings,
  :request_id,
  :start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#startString

Requested reservation start time (UTC) in ISO-8601 format. The specified time must be between the first day of the current month and one year from now. If no value is given, the default is now.



10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
# File 'lib/aws-sdk-medialive/types.rb', line 10896

class PurchaseOffering < Struct.new(
  :count,
  :name,
  :renewal_settings,
  :request_id,
  :start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of key-value pairs



10896
10897
10898
10899
10900
10901
10902
10903
10904
10905
# File 'lib/aws-sdk-medialive/types.rb', line 10896

class PurchaseOffering < Struct.new(
  :count,
  :name,
  :renewal_settings,
  :request_id,
  :start,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end