Class: Aws::MediaLive::Types::RouterInputSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

The settings for a MediaConnect Router Input.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destinationsArray<Types::RouterDestination>

MediaConnect Router destinations associated with the MediaLive Input.

Returns:



22451
22452
22453
22454
22455
22456
22457
# File 'lib/aws-sdk-medialive/types.rb', line 22451

class RouterInputSettings < Struct.new(
  :destinations,
  :encryption_type,
  :secret_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_typeString

Encryption configuration for MediaConnect router. When using SECRETS_MANAGER encryption, you must provide the ARN of the secret used to encrypt data in transit. When using AUTOMATIC encryption, a service-managed secret will be used instead.

Returns:

  • (String)


22451
22452
22453
22454
22455
22456
22457
# File 'lib/aws-sdk-medialive/types.rb', line 22451

class RouterInputSettings < Struct.new(
  :destinations,
  :encryption_type,
  :secret_arn)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

ARN of the secret used to encrypt this input.

Returns:

  • (String)


22451
22452
22453
22454
22455
22456
22457
# File 'lib/aws-sdk-medialive/types.rb', line 22451

class RouterInputSettings < Struct.new(
  :destinations,
  :encryption_type,
  :secret_arn)
  SENSITIVE = []
  include Aws::Structure
end