Class: Aws::MediaLive::Types::Scte20SourceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::Scte20SourceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Scte20 Source Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#convert_608_to_708 ⇒ String
If upconvert, 608 data is both passed through via the “608 compatibility bytes” fields of the 708 wrapper as well as translated into 708.
-
#source_608_channel_number ⇒ Integer
Specifies the 608/708 channel number within the video track from which to extract captions.
Instance Attribute Details
#convert_608_to_708 ⇒ String
If upconvert, 608 data is both passed through via the “608 compatibility bytes” fields of the 708 wrapper as well as translated into 708. 708 data present in the source content will be discarded.
11502 11503 11504 11505 11506 11507 |
# File 'lib/aws-sdk-medialive/types.rb', line 11502 class Scte20SourceSettings < Struct.new( :convert_608_to_708, :source_608_channel_number) SENSITIVE = [] include Aws::Structure end |
#source_608_channel_number ⇒ Integer
Specifies the 608/708 channel number within the video track from which to extract captions. Unused for passthrough.
11502 11503 11504 11505 11506 11507 |
# File 'lib/aws-sdk-medialive/types.rb', line 11502 class Scte20SourceSettings < Struct.new( :convert_608_to_708, :source_608_channel_number) SENSITIVE = [] include Aws::Structure end |