Class: Aws::MediaLive::Types::Scte35SegmentationDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::Scte35SegmentationDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Corresponds to SCTE-35 segmentation_descriptor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delivery_restrictions ⇒ Types::Scte35DeliveryRestrictions
Holds the four SCTE-35 delivery restriction parameters.
-
#segment_num ⇒ Integer
Corresponds to SCTE-35 segment_num.
-
#segmentation_cancel_indicator ⇒ String
Corresponds to SCTE-35 segmentation_event_cancel_indicator.
-
#segmentation_duration ⇒ Integer
Corresponds to SCTE-35 segmentation_duration.
-
#segmentation_event_id ⇒ Integer
Corresponds to SCTE-35 segmentation_event_id.
-
#segmentation_type_id ⇒ Integer
Corresponds to SCTE-35 segmentation_type_id.
-
#segmentation_upid ⇒ String
Corresponds to SCTE-35 segmentation_upid.
-
#segmentation_upid_type ⇒ Integer
Corresponds to SCTE-35 segmentation_upid_type.
-
#segments_expected ⇒ Integer
Corresponds to SCTE-35 segments_expected.
-
#sub_segment_num ⇒ Integer
Corresponds to SCTE-35 sub_segment_num.
-
#sub_segments_expected ⇒ Integer
Corresponds to SCTE-35 sub_segments_expected.
Instance Attribute Details
#delivery_restrictions ⇒ Types::Scte35DeliveryRestrictions
Holds the four SCTE-35 delivery restriction parameters.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#segment_num ⇒ Integer
Corresponds to SCTE-35 segment_num. A value that is valid for the specified segmentation_type_id.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#segmentation_cancel_indicator ⇒ String
Corresponds to SCTE-35 segmentation_event_cancel_indicator.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#segmentation_duration ⇒ Integer
Corresponds to SCTE-35 segmentation_duration. Optional. The duration for the time_signal, in 90 KHz ticks. To convert seconds to ticks, multiple the seconds by 90,000. Enter time in 90 KHz clock ticks. If you do not enter a duration, the time_signal will continue until you insert a cancellation message.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#segmentation_event_id ⇒ Integer
Corresponds to SCTE-35 segmentation_event_id.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#segmentation_type_id ⇒ Integer
Corresponds to SCTE-35 segmentation_type_id. One of the segmentation_type_id values listed in the SCTE-35 specification. On the console, enter the ID in decimal (for example, “52”). In the CLI, API, or an SDK, enter the ID in hex (for example, “0x34”) or decimal (for example, “52”).
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#segmentation_upid ⇒ String
Corresponds to SCTE-35 segmentation_upid. Enter a string containing the hexadecimal representation of the characters that make up the SCTE-35 segmentation_upid value. Must contain an even number of hex characters. Do not include spaces between each hex pair. For example, the ASCII “ADS Information” becomes hex “41445320496e666f726d6174696f6e.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#segmentation_upid_type ⇒ Integer
Corresponds to SCTE-35 segmentation_upid_type. On the console, enter one of the types listed in the SCTE-35 specification, converted to a decimal. For example, “0x0C” hex from the specification is “12” in decimal. In the CLI, API, or an SDK, enter one of the types listed in the SCTE-35 specification, in either hex (for example, “0x0C” ) or in decimal (for example, “12”).
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#segments_expected ⇒ Integer
Corresponds to SCTE-35 segments_expected. A value that is valid for the specified segmentation_type_id.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#sub_segment_num ⇒ Integer
Corresponds to SCTE-35 sub_segment_num. A value that is valid for the specified segmentation_type_id.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |
#sub_segments_expected ⇒ Integer
Corresponds to SCTE-35 sub_segments_expected. A value that is valid for the specified segmentation_type_id.
11712 11713 11714 11715 11716 11717 11718 11719 11720 11721 11722 11723 11724 11725 11726 |
# File 'lib/aws-sdk-medialive/types.rb', line 11712 class Scte35SegmentationDescriptor < Struct.new( :delivery_restrictions, :segment_num, :segmentation_cancel_indicator, :segmentation_duration, :segmentation_event_id, :segmentation_type_id, :segmentation_upid, :segmentation_upid_type, :segments_expected, :sub_segment_num, :sub_segments_expected) SENSITIVE = [] include Aws::Structure end |