Class: Aws::MediaLive::Types::SdiSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::SdiSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in CreateSdiSourceResponse, DeleteSdiSourceResponse, DescribeSdiSourceResponse, ListSdiSourcesResponse, UpdateSdiSourceResponse
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of this SdiSource.
-
#id ⇒ String
The ID of the SdiSource.
-
#inputs ⇒ Array<String>
The list of inputs that are currently using this SDI source.
-
#mode ⇒ String
Applies only if the type is QUAD.
-
#name ⇒ String
The name of the SdiSource.
-
#state ⇒ String
Specifies whether the SDI source is attached to an SDI input (IN_USE) or not (IDLE).
-
#type ⇒ String
Used in SdiSource, CreateSdiSourceRequest, UpdateSdiSourceRequest.
Instance Attribute Details
#arn ⇒ String
The ARN of this SdiSource. It is automatically assigned when the SdiSource is created.
22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 |
# File 'lib/aws-sdk-medialive/types.rb', line 22029 class SdiSource < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the SdiSource. Unique in the AWS account.The ID is the resource-id portion of the ARN.
22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 |
# File 'lib/aws-sdk-medialive/types.rb', line 22029 class SdiSource < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The list of inputs that are currently using this SDI source. This list will be empty if the SdiSource has just been deleted.
22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 |
# File 'lib/aws-sdk-medialive/types.rb', line 22029 class SdiSource < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Applies only if the type is QUAD. The mode for handling the quad-link signal QUADRANT or INTERLEAVE.
22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 |
# File 'lib/aws-sdk-medialive/types.rb', line 22029 class SdiSource < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SdiSource.
22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 |
# File 'lib/aws-sdk-medialive/types.rb', line 22029 class SdiSource < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Specifies whether the SDI source is attached to an SDI input (IN_USE) or not (IDLE).
22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 |
# File 'lib/aws-sdk-medialive/types.rb', line 22029 class SdiSource < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Used in SdiSource, CreateSdiSourceRequest, UpdateSdiSourceRequest.
22029 22030 22031 22032 22033 22034 22035 22036 22037 22038 22039 |
# File 'lib/aws-sdk-medialive/types.rb', line 22029 class SdiSource < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |