Class: Aws::MediaLive::Types::SmartSubtitleSourceSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Smart Subtitle Source Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#caption_synchronization_modeString

Controls whether MediaLive delays video to synchronize captions with audio and video output.

Returns:

  • (String)


23174
23175
23176
23177
23178
23179
# File 'lib/aws-sdk-medialive/types.rb', line 23174

class SmartSubtitleSourceSettings < Struct.new(
  :caption_synchronization_mode,
  :inference_feed_output)
  SENSITIVE = []
  include Aws::Structure
end

#inference_feed_outputString

The name of the Elemental Inference feed output that supplies subtitle input into this caption selector.

Returns:

  • (String)


23174
23175
23176
23177
23178
23179
# File 'lib/aws-sdk-medialive/types.rb', line 23174

class SmartSubtitleSourceSettings < Struct.new(
  :caption_synchronization_mode,
  :inference_feed_output)
  SENSITIVE = []
  include Aws::Structure
end