Class: Aws::MediaLive::Types::Smpte2110ReceiverGroupSdpSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::Smpte2110ReceiverGroupSdpSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Information about the SDP files that describe the SMPTE 2110 streams that go into one SMPTE 2110 receiver group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ancillary_sdps ⇒ Array<Types::InputSdpLocation>
A list of InputSdpLocations.
-
#audio_sdps ⇒ Array<Types::InputSdpLocation>
A list of InputSdpLocations.
-
#video_sdp ⇒ Types::InputSdpLocation
The InputSdpLocation that specifies the SDP file and index for the single video SMPTE 2110 stream for this 2110 input.
Instance Attribute Details
#ancillary_sdps ⇒ Array<Types::InputSdpLocation>
A list of InputSdpLocations. Each item in the list specifies the SDP file and index for one ancillary SMPTE 2110 stream. Each stream encapsulates one captions stream (out of any number you can include) or the single SCTE 35 stream that you can include.
21794 21795 21796 21797 21798 21799 21800 |
# File 'lib/aws-sdk-medialive/types.rb', line 21794 class Smpte2110ReceiverGroupSdpSettings < Struct.new( :ancillary_sdps, :audio_sdps, :video_sdp) SENSITIVE = [] include Aws::Structure end |
#audio_sdps ⇒ Array<Types::InputSdpLocation>
A list of InputSdpLocations. Each item in the list specifies the SDP file and index for one audio SMPTE 2110 stream.
21794 21795 21796 21797 21798 21799 21800 |
# File 'lib/aws-sdk-medialive/types.rb', line 21794 class Smpte2110ReceiverGroupSdpSettings < Struct.new( :ancillary_sdps, :audio_sdps, :video_sdp) SENSITIVE = [] include Aws::Structure end |
#video_sdp ⇒ Types::InputSdpLocation
The InputSdpLocation that specifies the SDP file and index for the single video SMPTE 2110 stream for this 2110 input.
21794 21795 21796 21797 21798 21799 21800 |
# File 'lib/aws-sdk-medialive/types.rb', line 21794 class Smpte2110ReceiverGroupSdpSettings < Struct.new( :ancillary_sdps, :audio_sdps, :video_sdp) SENSITIVE = [] include Aws::Structure end |