Class: Aws::MediaLive::Types::SpecialRouterSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::SpecialRouterSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
When using MediaConnect Router as the source of a MediaLive input there’s a special handoff that occurs when a router output is created. This group of settings is set on your behalf by the MediaConnect Router service using this set of settings. This setting object can only by used by that service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#router_arn ⇒ String
This is the arn of the MediaConnect Router resource being associated with the MediaLive Input.
Instance Attribute Details
#router_arn ⇒ String
This is the arn of the MediaConnect Router resource being associated with the MediaLive Input.
22735 22736 22737 22738 22739 |
# File 'lib/aws-sdk-medialive/types.rb', line 22735 class SpecialRouterSettings < Struct.new( :router_arn) SENSITIVE = [] include Aws::Structure end |