Class: Aws::MediaLive::Types::SrtCallerSource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

The configuration for a source that uses SRT as the connection protocol. In terms of establishing the connection, MediaLive is always caller and the upstream system is always the listener. In terms of transmission of the source content, MediaLive is always the receiver and the upstream system is always the sender.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#decryptionTypes::SrtCallerDecryption

The decryption settings for the SRT caller source. Present only if the source has decryption enabled.



18483
18484
18485
18486
18487
18488
18489
18490
18491
# File 'lib/aws-sdk-medialive/types.rb', line 18483

class SrtCallerSource < Struct.new(
  :decryption,
  :minimum_latency,
  :srt_listener_address,
  :srt_listener_port,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_latencyInteger

The preferred latency (in milliseconds) for implementing packet loss and recovery. Packet recovery is a key feature of SRT.

Returns:

  • (Integer)


18483
18484
18485
18486
18487
18488
18489
18490
18491
# File 'lib/aws-sdk-medialive/types.rb', line 18483

class SrtCallerSource < Struct.new(
  :decryption,
  :minimum_latency,
  :srt_listener_address,
  :srt_listener_port,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#srt_listener_addressString

The IP address at the upstream system (the listener) that MediaLive (the caller) connects to.

Returns:

  • (String)


18483
18484
18485
18486
18487
18488
18489
18490
18491
# File 'lib/aws-sdk-medialive/types.rb', line 18483

class SrtCallerSource < Struct.new(
  :decryption,
  :minimum_latency,
  :srt_listener_address,
  :srt_listener_port,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#srt_listener_portString

The port at the upstream system (the listener) that MediaLive (the caller) connects to.

Returns:

  • (String)


18483
18484
18485
18486
18487
18488
18489
18490
18491
# File 'lib/aws-sdk-medialive/types.rb', line 18483

class SrtCallerSource < Struct.new(
  :decryption,
  :minimum_latency,
  :srt_listener_address,
  :srt_listener_port,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

The stream ID, if the upstream system uses this identifier.

Returns:

  • (String)


18483
18484
18485
18486
18487
18488
18489
18490
18491
# File 'lib/aws-sdk-medialive/types.rb', line 18483

class SrtCallerSource < Struct.new(
  :decryption,
  :minimum_latency,
  :srt_listener_address,
  :srt_listener_port,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end