Class: Aws::MediaLive::Types::SrtGroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::SrtGroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Srt Group Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_loss_action ⇒ String
Specifies behavior of last resort when input video is lost, and no more backup inputs are available.
Instance Attribute Details
#input_loss_action ⇒ String
Specifies behavior of last resort when input video is lost, and no more backup inputs are available. When dropTs is selected the entire transport stream will stop being emitted. When dropProgram is selected the program can be dropped from the transport stream (and replaced with null packets to meet the TS bitrate requirement). Or, when emitProgram is chosen the transport stream will continue to be produced normally with repeat frames, black frames, or slate frames substituted for the absent input video.
21004 21005 21006 21007 21008 |
# File 'lib/aws-sdk-medialive/types.rb', line 21004 class SrtGroupSettings < Struct.new( :input_loss_action) SENSITIVE = [] include Aws::Structure end |