Class: Aws::MediaLive::Types::StartDeleteMonitorDeploymentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::StartDeleteMonitorDeploymentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #arn ⇒ String
- #cloud_watch_alarm_template_group_ids ⇒ Array<String>
- #created_at ⇒ Time
- #description ⇒ String
- #discovery_entry_point_arn ⇒ String
- #error_message ⇒ String
- #event_bridge_rule_template_group_ids ⇒ Array<String>
-
#failed_media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an incomplete AWS media workflow as a graph.
- #id ⇒ String
- #last_discovered_at ⇒ Time
-
#last_successful_monitor_deployment ⇒ Types::SuccessfulMonitorDeployment
Represents the latest successful monitor deployment of a signal map.
-
#media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an AWS media workflow as a graph.
- #modified_at ⇒ Time
- #monitor_changes_pending_deployment ⇒ Boolean
-
#monitor_deployment ⇒ Types::MonitorDeployment
Represents the latest monitor deployment of a signal map.
- #name ⇒ String
-
#status ⇒ String
A signal map's current status which is dependent on its lifecycle actions or associated jobs.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
Instance Attribute Details
#arn ⇒ String
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#cloud_watch_alarm_template_group_ids ⇒ Array<String>
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#discovery_entry_point_arn ⇒ String
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#event_bridge_rule_template_group_ids ⇒ Array<String>
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#failed_media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an incomplete AWS media workflow as a graph.
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#last_discovered_at ⇒ Time
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#last_successful_monitor_deployment ⇒ Types::SuccessfulMonitorDeployment
Represents the latest successful monitor deployment of a signal map.
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an AWS media workflow as a graph.
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_changes_pending_deployment ⇒ Boolean
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_deployment ⇒ Types::MonitorDeployment
Represents the latest monitor deployment of a signal map.
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A signal map's current status which is dependent on its lifecycle actions or associated jobs.
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
17232 17233 17234 17235 17236 17237 17238 17239 17240 17241 17242 17243 17244 17245 17246 17247 17248 17249 17250 17251 17252 17253 |
# File 'lib/aws-sdk-medialive/types.rb', line 17232 class StartDeleteMonitorDeploymentResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |