Class: Aws::MediaLive::Types::StaticImageOutputActivateScheduleActionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::StaticImageOutputActivateScheduleActionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Settings for the action to activate a static image.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
The duration in milliseconds for the image to remain on the video.
-
#fade_in ⇒ Integer
The time in milliseconds for the image to fade in.
-
#fade_out ⇒ Integer
Applies only if a duration is specified.
-
#height ⇒ Integer
The height of the image when inserted into the video, in pixels.
-
#image ⇒ Types::InputLocation
The location and filename of the image file to overlay on the video.
-
#image_x ⇒ Integer
Placement of the left edge of the overlay relative to the left edge of the video frame, in pixels.
-
#image_y ⇒ Integer
Placement of the top edge of the overlay relative to the top edge of the video frame, in pixels.
-
#layer ⇒ Integer
The number of the layer, 0 to 7.
-
#opacity ⇒ Integer
Opacity of image where 0 is transparent and 100 is fully opaque.
-
#output_names ⇒ Array<String>
The name(s) of the output(s) the activation should apply to.
-
#width ⇒ Integer
The width of the image when inserted into the video, in pixels.
Instance Attribute Details
#duration ⇒ Integer
The duration in milliseconds for the image to remain on the video. If omitted or set to 0 the duration is unlimited and the image will remain until it is explicitly deactivated.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#fade_in ⇒ Integer
The time in milliseconds for the image to fade in. The fade-in starts at the start time of the overlay. Default is 0 (no fade-in).
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#fade_out ⇒ Integer
Applies only if a duration is specified. The time in milliseconds for the image to fade out. The fade-out starts when the duration time is hit, so it effectively extends the duration. Default is 0 (no fade-out).
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#height ⇒ Integer
The height of the image when inserted into the video, in pixels. The overlay will be scaled up or down to the specified height. Leave blank to use the native height of the overlay.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#image ⇒ Types::InputLocation
The location and filename of the image file to overlay on the video. The file must be a 32-bit BMP, PNG, or TGA file, and must not be larger (in pixels) than the input video.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#image_x ⇒ Integer
Placement of the left edge of the overlay relative to the left edge of the video frame, in pixels. 0 (the default) is the left edge of the frame. If the placement causes the overlay to extend beyond the right edge of the underlying video, then the overlay is cropped on the right.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#image_y ⇒ Integer
Placement of the top edge of the overlay relative to the top edge of the video frame, in pixels. 0 (the default) is the top edge of the frame. If the placement causes the overlay to extend beyond the bottom edge of the underlying video, then the overlay is cropped on the bottom.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#layer ⇒ Integer
The number of the layer, 0 to 7. There are 8 layers that can be overlaid on the video, each layer with a different image. The layers are in Z order, which means that overlays with higher values of layer are inserted on top of overlays with lower values of layer. Default is 0.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#opacity ⇒ Integer
Opacity of image where 0 is transparent and 100 is fully opaque. Default is 100.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#output_names ⇒ Array<String>
The name(s) of the output(s) the activation should apply to.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |
#width ⇒ Integer
The width of the image when inserted into the video, in pixels. The overlay will be scaled up or down to the specified width. Leave blank to use the native width of the overlay.
12138 12139 12140 12141 12142 12143 12144 12145 12146 12147 12148 12149 12150 12151 12152 |
# File 'lib/aws-sdk-medialive/types.rb', line 12138 class StaticImageOutputActivateScheduleActionSettings < Struct.new( :duration, :fade_in, :fade_out, :height, :image, :image_x, :image_y, :layer, :opacity, :output_names, :width) SENSITIVE = [] include Aws::Structure end |