Class: Aws::MediaLive::Types::StopTimecode

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Settings to identify the end of the clip.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_frame_clipping_behaviorString

If you specify a StopTimecode in an input (in order to clip the file), you can specify if you want the clip to exclude (the default) or include the frame specified by the timecode.

Returns:

  • (String)


12532
12533
12534
12535
12536
12537
# File 'lib/aws-sdk-medialive/types.rb', line 12532

class StopTimecode < Struct.new(
  :last_frame_clipping_behavior,
  :timecode)
  SENSITIVE = []
  include Aws::Structure
end

#timecodeString

The timecode for the frame where you want to stop the clip. Optional; if not specified, the clip continues to the end of the file. Enter the timecode as HH:MM:SS:FF or HH:MM:SS;FF.

Returns:

  • (String)


12532
12533
12534
12535
12536
12537
# File 'lib/aws-sdk-medialive/types.rb', line 12532

class StopTimecode < Struct.new(
  :last_frame_clipping_behavior,
  :timecode)
  SENSITIVE = []
  include Aws::Structure
end