Class: Aws::MediaLive::Types::TextCaptionPositionSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Text Caption Position Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#y_position_percentageInteger

Specifies the vertical position of the top edge of the caption relative to the top of the output as a percentage. A value of 0 places the caption at the top of the output and 100 at the bottom.

Returns:



23674
23675
23676
23677
23678
# File 'lib/aws-sdk-medialive/types.rb', line 23674

class TextCaptionPositionSettings < Struct.new(
  :y_position_percentage)
  SENSITIVE = []
  include Aws::Structure
end