Class: Aws::MediaLive::Types::TimecodeConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Timecode Config

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sourceString

Identifies the source for the timecode that will be associated with the events outputs. -Embedded (embedded): Initialize the output timecode with timecode from the the source. If no embedded timecode is detected in the source, the system falls back to using “Start at 0” (zerobased). -System Clock (systemclock): Use the UTC time. -Start at 0 (zerobased): The time of the first frame of the event will be 00:00:00:00.

Returns:

  • (String)


12775
12776
12777
12778
12779
12780
# File 'lib/aws-sdk-medialive/types.rb', line 12775

class TimecodeConfig < Struct.new(
  :source,
  :sync_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#sync_thresholdInteger

Threshold in frames beyond which output timecode is resynchronized to the input timecode. Discrepancies below this threshold are permitted to avoid unnecessary discontinuities in the output timecode. No timecode sync when this is not specified.

Returns:

  • (Integer)


12775
12776
12777
12778
12779
12780
# File 'lib/aws-sdk-medialive/types.rb', line 12775

class TimecodeConfig < Struct.new(
  :source,
  :sync_threshold)
  SENSITIVE = []
  include Aws::Structure
end