Class: Aws::MediaLive::Types::TtmlDestinationSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Ttml Destination Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#positionTypes::TextCaptionPositionSettings

Specifies the position of the output captions. Applies only when styleControl is set to manual.



12932
12933
12934
12935
12936
12937
# File 'lib/aws-sdk-medialive/types.rb', line 12932

class TtmlDestinationSettings < Struct.new(
  :style_control,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#style_controlString

Controls the source of style and position information for the output captions. PASSTHROUGH - Preserve the style and position from the source captions. USE_CONFIGURED - Don't pass through the style. The output captions will use the default styling. MANUAL - Applies the specified styling and positioning. All other styling and positioning is given default values.

Returns:

  • (String)


12932
12933
12934
12935
12936
12937
# File 'lib/aws-sdk-medialive/types.rb', line 12932

class TtmlDestinationSettings < Struct.new(
  :style_control,
  :position)
  SENSITIVE = []
  include Aws::Structure
end