Class: Aws::MediaLive::Types::UdpGroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UdpGroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Udp Group Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_loss_action ⇒ String
Specifies behavior of last resort when input video is lost, and no more backup inputs are available.
-
#timed_metadata_id_3_frame ⇒ String
Indicates ID3 frame that has the timecode.
-
#timed_metadata_id_3_period ⇒ Integer
Timed Metadata interval in seconds.
Instance Attribute Details
#input_loss_action ⇒ String
Specifies behavior of last resort when input video is lost, and no more backup inputs are available. When dropTs is selected the entire transport stream will stop being emitted. When dropProgram is selected the program can be dropped from the transport stream (and replaced with null packets to meet the TS bitrate requirement). Or, when emitProgram is chosen the transport stream will continue to be produced normally with repeat frames, black frames, or slate frames substituted for the absent input video.
12947 12948 12949 12950 12951 12952 12953 |
# File 'lib/aws-sdk-medialive/types.rb', line 12947 class UdpGroupSettings < Struct.new( :input_loss_action, :timed_metadata_id_3_frame, :timed_metadata_id_3_period) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_id_3_frame ⇒ String
Indicates ID3 frame that has the timecode.
12947 12948 12949 12950 12951 12952 12953 |
# File 'lib/aws-sdk-medialive/types.rb', line 12947 class UdpGroupSettings < Struct.new( :input_loss_action, :timed_metadata_id_3_frame, :timed_metadata_id_3_period) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_id_3_period ⇒ Integer
Timed Metadata interval in seconds.
12947 12948 12949 12950 12951 12952 12953 |
# File 'lib/aws-sdk-medialive/types.rb', line 12947 class UdpGroupSettings < Struct.new( :input_loss_action, :timed_metadata_id_3_frame, :timed_metadata_id_3_period) SENSITIVE = [] include Aws::Structure end |