Class: Aws::MediaLive::Types::UpdateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::AnywhereSettings

Elemental anywhere settings



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionRequest



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_idString

Returns:

  • (String)


13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

Returns:

  • (Array<String>)


13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

Returns:



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Returns:

  • (Boolean)


13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

Encoder Settings



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::InferenceSettings

Configures Elemental Inference features in a channel.



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

Returns:



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::LinkedChannelSettings

Configuration for linked channel relationships



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level the user wants for their channel.

Returns:

  • (String)


13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceUpdateSettings



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Returns:

  • (String)


13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#special_router_settingsTypes::SpecialRouterSettings

When using MediaConnect Router as the source of a MediaLive input there's a special handoff that occurs when a router output is created. This group of settings is set on your behalf by the MediaConnect Router service using this set of settings. This setting object can only by used by that service.



13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
13305
13306
13307
13308
# File 'lib/aws-sdk-medialive/types.rb', line 13288

class UpdateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_id,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end