Class: Aws::MediaLive::Types::UpdateCloudWatchAlarmTemplateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#comparison_operatorString

The comparison operator used to compare the specified statistic and the threshold.

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#datapoints_to_alarmInteger

Returns:

  • (Integer)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_periodsInteger

Returns:

  • (Integer)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#group_identifierString

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#periodInteger

Returns:

  • (Integer)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#statisticString

The statistic to apply to the alarm’s metric data.

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#target_resource_typeString

The resource type this template should dynamically generate cloudwatch metric alarms for.

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#thresholdFloat

Returns:

  • (Float)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#treat_missing_dataString

Specifies how missing data points are treated when evaluating the alarm’s condition.

Returns:

  • (String)


17673
17674
17675
17676
17677
17678
17679
17680
17681
17682
17683
17684
17685
17686
17687
17688
17689
# File 'lib/aws-sdk-medialive/types.rb', line 17673

class UpdateCloudWatchAlarmTemplateRequest < Struct.new(
  :comparison_operator,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_identifier,
  :identifier,
  :metric_name,
  :name,
  :period,
  :statistic,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end