Class: Aws::MediaLive::Types::UpdateCloudWatchAlarmTemplateRequestContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateCloudWatchAlarmTemplateRequestContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
-
#datapoints_to_alarm ⇒ Integer
The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
-
#description ⇒ String
A resource's optional description.
-
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
-
#group_identifier ⇒ String
A cloudwatch alarm template group's identifier.
-
#metric_name ⇒ String
The name of the metric associated with the alarm.
-
#name ⇒ String
A resource's name.
-
#period ⇒ Integer
The period, in seconds, over which the specified statistic is applied.
-
#statistic ⇒ String
The statistic to apply to the alarm's metric data.
-
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
-
#threshold ⇒ Float
The threshold value to compare with the specified statistic.
-
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm's condition.
Instance Attribute Details
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#datapoints_to_alarm ⇒ Integer
The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A resource's optional description.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#group_identifier ⇒ String
A cloudwatch alarm template group's identifier. Can be either be its id or current name.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric associated with the alarm. Must be compatible with targetResourceType.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A resource's name. Names must be unique within the scope of a resource type in a specific region.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The period, in seconds, over which the specified statistic is applied.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic to apply to the alarm's metric data.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
The threshold value to compare with the specified statistic.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm's condition.
18007 18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 |
# File 'lib/aws-sdk-medialive/types.rb', line 18007 class UpdateCloudWatchAlarmTemplateRequestContent < Struct.new( :comparison_operator, :datapoints_to_alarm, :description, :evaluation_periods, :group_identifier, :metric_name, :name, :period, :statistic, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |