Class: Aws::MediaLive::Types::UpdateCloudWatchAlarmTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateCloudWatchAlarmTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #arn ⇒ String
-
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
- #created_at ⇒ Time
- #datapoints_to_alarm ⇒ Integer
- #description ⇒ String
- #evaluation_periods ⇒ Integer
- #group_id ⇒ String
- #id ⇒ String
- #metric_name ⇒ String
- #modified_at ⇒ Time
- #name ⇒ String
- #period ⇒ Integer
-
#statistic ⇒ String
The statistic to apply to the alarm’s metric data.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
-
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
- #threshold ⇒ Float
-
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm’s condition.
Instance Attribute Details
#arn ⇒ String
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#datapoints_to_alarm ⇒ Integer
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#evaluation_periods ⇒ Integer
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic to apply to the alarm’s metric data.
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm’s condition.
18008 18009 18010 18011 18012 18013 18014 18015 18016 18017 18018 18019 18020 18021 18022 18023 18024 18025 18026 18027 18028 |
# File 'lib/aws-sdk-medialive/types.rb', line 18008 class UpdateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |