Class: Aws::MediaLive::Types::UpdateCloudWatchAlarmTemplateResponseContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

A cloudwatch alarm template's ARN (Amazon Resource Name)



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#comparison_operatorString

The comparison operator used to compare the specified statistic and the threshold.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#datapoints_to_alarmInteger

The number of datapoints within the evaluation period that must be breaching to trigger the alarm.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A resource's optional description.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_periodsInteger

The number of periods over which data is compared to the specified threshold.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#group_idString

A cloudwatch alarm template group's id. AWS provided template groups have ids that start with aws-



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A cloudwatch alarm template's id. AWS provided templates have ids that start with aws-



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the metric associated with the alarm. Must be compatible with targetResourceType.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A resource's name. Names must be unique within the scope of a resource type in a specific region.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#periodInteger

The period, in seconds, over which the specified statistic is applied.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#statisticString

The statistic to apply to the alarm's metric data.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Represents the tags associated with a resource.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#target_resource_typeString

The resource type this template should dynamically generate cloudwatch metric alarms for.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#thresholdFloat

The threshold value to compare with the specified statistic.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end

#treat_missing_dataString

Specifies how missing data points are treated when evaluating the alarm's condition.



18258
18259
18260
18261
18262
18263
18264
18265
18266
18267
18268
18269
18270
18271
18272
18273
18274
18275
18276
18277
18278
# File 'lib/aws-sdk-medialive/types.rb', line 18258

class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new(
  :arn,
  :comparison_operator,
  :created_at,
  :datapoints_to_alarm,
  :description,
  :evaluation_periods,
  :group_id,
  :id,
  :metric_name,
  :modified_at,
  :name,
  :period,
  :statistic,
  :tags,
  :target_resource_type,
  :threshold,
  :treat_missing_data)
  SENSITIVE = []
  include Aws::Structure
end