Class: Aws::MediaLive::Types::UpdateClusterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Used in the UpdatedCluster operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_idString

Returns:

  • (String)


21055
21056
21057
21058
21059
21060
21061
# File 'lib/aws-sdk-medialive/types.rb', line 21055

class UpdateClusterRequest < Struct.new(
  :cluster_id,
  :name,
  :network_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Include this parameter only if you want to change the current name of the Cluster. Specify a name that is unique in the AWS account. You can’t change the name. Names are case-sensitive.

Returns:

  • (String)


21055
21056
21057
21058
21059
21060
21061
# File 'lib/aws-sdk-medialive/types.rb', line 21055

class UpdateClusterRequest < Struct.new(
  :cluster_id,
  :name,
  :network_settings)
  SENSITIVE = []
  include Aws::Structure
end

#network_settingsTypes::ClusterNetworkSettingsUpdateRequest

Include this property only if you want to change the current connections between the Nodes in the Cluster and the Networks the Cluster is associated with.



21055
21056
21057
21058
21059
21060
21061
# File 'lib/aws-sdk-medialive/types.rb', line 21055

class UpdateClusterRequest < Struct.new(
  :cluster_id,
  :name,
  :network_settings)
  SENSITIVE = []
  include Aws::Structure
end