Class: Aws::MediaLive::Types::UpdateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Types::InputDestinationRequest>
Destination settings for PUSH type inputs.
-
#input_devices ⇒ Array<Types::InputDeviceRequest>
Settings for the devices.
-
#input_security_groups ⇒ Array<String>
A list of security groups referenced by IDs to attach to the input.
-
#media_connect_flows ⇒ Array<Types::MediaConnectFlowRequest>
A list of the MediaConnect Flow ARNs that you want to use as the source of the input.
-
#multicast_settings ⇒ Types::MulticastSettingsUpdateRequest
Multicast Input settings.
-
#name ⇒ String
Name of the input.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role this input assumes during and after creation.
-
#sdi_sources ⇒ Array<String>
SDI Sources for this Input.
-
#smpte_2110_receiver_group_settings ⇒ Types::Smpte2110ReceiverGroupSettings
Include this parameter if the input is a SMPTE 2110 input, to identify the stream sources for this input.
-
#sources ⇒ Array<Types::InputSourceRequest>
The source URLs for a PULL-type input.
-
#special_router_settings ⇒ Types::SpecialRouterSettings
When using MediaConnect Router as the source of a MediaLive input there’s a special handoff that occurs when a router output is created.
-
#srt_settings ⇒ Types::SrtSettingsRequest
The settings associated with an SRT input.
Instance Attribute Details
#destinations ⇒ Array<Types::InputDestinationRequest>
Destination settings for PUSH type inputs.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#input_devices ⇒ Array<Types::InputDeviceRequest>
Settings for the devices.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#input_security_groups ⇒ Array<String>
A list of security groups referenced by IDs to attach to the input.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#media_connect_flows ⇒ Array<Types::MediaConnectFlowRequest>
A list of the MediaConnect Flow ARNs that you want to use as the source of the input. You can specify as few as one Flow and presently, as many as two. The only requirement is when you have more than one is that each Flow is in a separate Availability Zone as this ensures your EML input is redundant to AZ issues.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#multicast_settings ⇒ Types::MulticastSettingsUpdateRequest
Multicast Input settings.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of the input.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role this input assumes during and after creation.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#sdi_sources ⇒ Array<String>
SDI Sources for this Input.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#smpte_2110_receiver_group_settings ⇒ Types::Smpte2110ReceiverGroupSettings
Include this parameter if the input is a SMPTE 2110 input, to identify the stream sources for this input.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::InputSourceRequest>
The source URLs for a PULL-type input. Every PULL type input needs exactly two source URLs for redundancy. Only specify sources for PULL type Inputs. Leave Destinations empty.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#special_router_settings ⇒ Types::SpecialRouterSettings
When using MediaConnect Router as the source of a MediaLive input there’s a special handoff that occurs when a router output is created. This group of settings is set on your behalf by the MediaConnect Router service using this set of settings. This setting object can only by used by that service.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#srt_settings ⇒ Types::SrtSettingsRequest
The settings associated with an SRT input.
13346 13347 13348 13349 13350 13351 13352 13353 13354 13355 13356 13357 13358 13359 13360 13361 |
# File 'lib/aws-sdk-medialive/types.rb', line 13346 class UpdateInput < Struct.new( :destinations, :input_devices, :input_security_groups, :media_connect_flows, :name, :role_arn, :sources, :srt_settings, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :special_router_settings) SENSITIVE = [] include Aws::Structure end |