Class: Aws::MediaLive::Types::UpdateInputDeviceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateInputDeviceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #arn ⇒ String
- #availability_zone ⇒ String
-
#connection_state ⇒ String
The state of the connection between the input device and AWS.
-
#device_settings_sync_state ⇒ String
The status of the action to synchronize the device configuration.
-
#device_update_status ⇒ String
The status of software on the input device.
-
#hd_device_settings ⇒ Types::InputDeviceHdSettings
Settings that describe the active source from the input device, and the video characteristics of that source.
- #id ⇒ String
- #mac_address ⇒ String
- #medialive_input_arns ⇒ Array<String>
- #name ⇒ String
-
#network_settings ⇒ Types::InputDeviceNetworkSettings
The network settings for the input device.
-
#output_type ⇒ String
The output attachment type of the input device.
- #serial_number ⇒ String
- #tags ⇒ Hash<String,String>
-
#type ⇒ String
The type of the input device.
-
#uhd_device_settings ⇒ Types::InputDeviceUhdSettings
Settings that describe the active source from the input device, and the video characteristics of that source.
Instance Attribute Details
#arn ⇒ String
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#connection_state ⇒ String
The state of the connection between the input device and AWS.
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#device_settings_sync_state ⇒ String
The status of the action to synchronize the device configuration. If you change the configuration of the input device (for example, the maximum bitrate), MediaLive sends the new data to the device. The device might not update itself immediately. SYNCED means the device has updated its configuration. SYNCING means that it has not updated its configuration.
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#device_update_status ⇒ String
The status of software on the input device.
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#hd_device_settings ⇒ Types::InputDeviceHdSettings
Settings that describe the active source from the input device, and the video characteristics of that source.
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#mac_address ⇒ String
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#medialive_input_arns ⇒ Array<String>
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#network_settings ⇒ Types::InputDeviceNetworkSettings
The network settings for the input device.
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#output_type ⇒ String
The output attachment type of the input device.
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#serial_number ⇒ String
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the input device. For an AWS Elemental Link device that outputs resolutions up to 1080, choose "HD".
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |
#uhd_device_settings ⇒ Types::InputDeviceUhdSettings
Settings that describe the active source from the input device, and the video characteristics of that source.
13537 13538 13539 13540 13541 13542 13543 13544 13545 13546 13547 13548 13549 13550 13551 13552 13553 13554 13555 13556 |
# File 'lib/aws-sdk-medialive/types.rb', line 13537 class UpdateInputDeviceResponse < Struct.new( :arn, :connection_state, :device_settings_sync_state, :device_update_status, :hd_device_settings, :id, :mac_address, :name, :network_settings, :serial_number, :type, :uhd_device_settings, :tags, :availability_zone, :medialive_input_arns, :output_type) SENSITIVE = [] include Aws::Structure end |