Class: Aws::MediaLive::Types::UpdateNetworkResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Contains the response for the UpdateNetwork

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of this Network. It is automatically assigned when the Network is created.

Returns:

  • (String)


21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
# File 'lib/aws-sdk-medialive/types.rb', line 21411

class UpdateNetworkResult < Struct.new(
  :arn,
  :associated_cluster_ids,
  :id,
  :ip_pools,
  :name,
  :routes,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#associated_cluster_idsArray<String>

Returns:

  • (Array<String>)


21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
# File 'lib/aws-sdk-medialive/types.rb', line 21411

class UpdateNetworkResult < Struct.new(
  :arn,
  :associated_cluster_ids,
  :id,
  :ip_pools,
  :name,
  :routes,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the Network. Unique in the AWS account. The ID is the resource-id portion of the ARN.

Returns:

  • (String)


21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
# File 'lib/aws-sdk-medialive/types.rb', line 21411

class UpdateNetworkResult < Struct.new(
  :arn,
  :associated_cluster_ids,
  :id,
  :ip_pools,
  :name,
  :routes,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#ip_poolsArray<Types::IpPool>

An array of IpPools in your organization's network that identify a collection of IP addresses in this network that are reserved for use in MediaLive Anywhere. MediaLive Anywhere uses these IP addresses for Push inputs (in both Bridge and NAT networks) and for output destinations (only in Bridge networks). Each IpPool specifies one CIDR block.

Returns:



21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
# File 'lib/aws-sdk-medialive/types.rb', line 21411

class UpdateNetworkResult < Struct.new(
  :arn,
  :associated_cluster_ids,
  :id,
  :ip_pools,
  :name,
  :routes,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that you specified for the Network.

Returns:

  • (String)


21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
# File 'lib/aws-sdk-medialive/types.rb', line 21411

class UpdateNetworkResult < Struct.new(
  :arn,
  :associated_cluster_ids,
  :id,
  :ip_pools,
  :name,
  :routes,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#routesArray<Types::Route>

An array of Routes that MediaLive Anywhere needs to know about in order to route encoding traffic.

Returns:



21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
# File 'lib/aws-sdk-medialive/types.rb', line 21411

class UpdateNetworkResult < Struct.new(
  :arn,
  :associated_cluster_ids,
  :id,
  :ip_pools,
  :name,
  :routes,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the Network. Only MediaLive Anywhere can change the state.

Returns:

  • (String)


21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
# File 'lib/aws-sdk-medialive/types.rb', line 21411

class UpdateNetworkResult < Struct.new(
  :arn,
  :associated_cluster_ids,
  :id,
  :ip_pools,
  :name,
  :routes,
  :state)
  SENSITIVE = []
  include Aws::Structure
end