Class: Aws::MediaLive::Types::VideoDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Video settings for this stream.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codec_settingsTypes::VideoCodecSettings

Video codec settings.



14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end

#crop_rectangleTypes::VideoPositionRectangle

Region of the input video to crop before scaling. If not specified, the entire input frame is used. Note: Unlike outputPositionRectangle, the bounds of cropRectangle are validated at ingest time by the encoder/scaler rather than at the API level, because the input resolution is not known until the source is probed. Field-level constraints on (x, y, width, height) defined on VideoPositionRectangle still apply.



14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end

#heightInteger

Output video height, in pixels. Must be an even number. For most codecs, you can leave this field and width blank in order to use the height and width (resolution) from the source. Note, however, that leaving blank is not recommended. For the Frame Capture codec, height and width are required.

Returns:

  • (Integer)


14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of this VideoDescription. Outputs will use this name to uniquely identify this Description. Description names should be unique within this Live Event.

Returns:

  • (String)


14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end

#output_position_rectangleTypes::VideoPositionRectangle

Position of the encoded video within the output frame. The area outside the rectangle is filled with black. If not specified, the video fills the entire output frame. When used, both width and height of the VideoDescription must be explicitly specified so that the rectangle can be validated against the output frame.



14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end

#respond_to_afdString

Indicates how MediaLive will respond to the AFD values that might be in the input video. If you do not know what AFD signaling is, or if your downstream system has not given you guidance, choose PASSTHROUGH. RESPOND: MediaLive clips the input video using a formula that uses the AFD values (configured in afdSignaling ), the input display aspect ratio, and the output display aspect ratio. MediaLive also includes the AFD values in the output, unless the codec for this encode is FRAME_CAPTURE. PASSTHROUGH: MediaLive ignores the AFD values and does not clip the video. But MediaLive does include the values in the output. NONE: MediaLive does not clip the input video and does not include the AFD values in the output

Returns:

  • (String)


14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_behaviorString

Configures how MediaLive transforms the video picture to match the output frame. Use STRETCH_TO_OUTPUT to stretch the video to fill the output frame. The video might get distorted. Use DEFAULT to insert pillar boxes or letter boxes around the video to fill the output frame. The video won't get distorted. Use SMART_CROP to enable the smart crop feature that uses the Elemental Inference service to crop the frame using AI - see the MediaLive User Guide for more information.

Returns:

  • (String)


14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end

#sharpnessInteger

Changes the strength of the anti-alias filter used for scaling. 0 is the softest setting, 100 is the sharpest. A setting of 50 is recommended for most content.

Returns:

  • (Integer)


14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end

#widthInteger

Output video width, in pixels. Must be an even number. For most codecs, you can leave this field and height blank in order to use the height and width (resolution) from the source. Note, however, that leaving blank is not recommended. For the Frame Capture codec, height and width are required.

Returns:

  • (Integer)


14014
14015
14016
14017
14018
14019
14020
14021
14022
14023
14024
14025
14026
# File 'lib/aws-sdk-medialive/types.rb', line 14014

class VideoDescription < Struct.new(
  :codec_settings,
  :height,
  :name,
  :respond_to_afd,
  :scaling_behavior,
  :sharpness,
  :width,
  :crop_rectangle,
  :output_position_rectangle)
  SENSITIVE = []
  include Aws::Structure
end