Class: Aws::MediaLive::Types::VpcOutputSettingsDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::VpcOutputSettingsDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
The properties for a private VPC Output
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zones ⇒ Array<String>
The Availability Zones where the vpc subnets are located.
-
#network_interface_ids ⇒ Array<String>
A list of Elastic Network Interfaces created by MediaLive in the customer’s VPC.
-
#security_group_ids ⇒ Array<String>
A list of up EC2 VPC security group IDs attached to the Output VPC network interfaces.
-
#subnet_ids ⇒ Array<String>
A list of VPC subnet IDs from the same VPC.
Instance Attribute Details
#availability_zones ⇒ Array<String>
The Availability Zones where the vpc subnets are located. The first Availability Zone applies to the first subnet in the list of subnets. The second Availability Zone applies to the second subnet.
14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-medialive/types.rb', line 14107 class VpcOutputSettingsDescription < Struct.new( :availability_zones, :network_interface_ids, :security_group_ids, :subnet_ids) SENSITIVE = [] include Aws::Structure end |
#network_interface_ids ⇒ Array<String>
A list of Elastic Network Interfaces created by MediaLive in the customer’s VPC
14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-medialive/types.rb', line 14107 class VpcOutputSettingsDescription < Struct.new( :availability_zones, :network_interface_ids, :security_group_ids, :subnet_ids) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
A list of up EC2 VPC security group IDs attached to the Output VPC network interfaces.
14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-medialive/types.rb', line 14107 class VpcOutputSettingsDescription < Struct.new( :availability_zones, :network_interface_ids, :security_group_ids, :subnet_ids) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
A list of VPC subnet IDs from the same VPC. If STANDARD channel, subnet IDs must be mapped to two unique availability zones (AZ).
14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-medialive/types.rb', line 14107 class VpcOutputSettingsDescription < Struct.new( :availability_zones, :network_interface_ids, :security_group_ids, :subnet_ids) SENSITIVE = [] include Aws::Structure end |