Class: Aws::MediaLive::Waiters::ChannelRunning
- Inherits:
-
Object
- Object
- Aws::MediaLive::Waiters::ChannelRunning
- Defined in:
- lib/aws-sdk-medialive/waiters.rb,
sig/waiters.rbs
Overview
Wait until a channel is running
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ChannelRunning
constructor
A new instance of ChannelRunning.
-
#wait(params = {}) ⇒ Types::DescribeChannelResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ChannelRunning
Returns a new instance of ChannelRunning.
362 363 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 362
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
399 400 401 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 399 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeChannelResponse
Returns a response object which responds to the following methods:
- #arn => String
- #cdi_input_specification => Types::CdiInputSpecification
- #channel_class => String
- #destinations => Array<Types::OutputDestination>
- #egress_endpoints => Array<Types::ChannelEgressEndpoint>
- #encoder_settings => Types::EncoderSettings
- #id => String
- #input_attachments => Array<Types::InputAttachment>
- #input_specification => Types::InputSpecification
- #log_level => String
- #maintenance => Types::MaintenanceStatus
- #name => String
- #pipeline_details => Array<Types::PipelineDetail>
- #pipelines_running_count => Integer
- #role_arn => String
- #state => String
- #tags => Hash<String,String>
- #vpc => Types::VpcOutputSettingsDescription
- #anywhere_settings => Types::DescribeAnywhereSettings
- #channel_engine_version => Types::ChannelEngineVersionResponse
- #linked_channel_settings => Types::DescribeLinkedChannelSettings
- #channel_security_groups => Array<String>
- #inference_settings => Types::DescribeInferenceSettings
394 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 394
def wait: (
|