Class: Aws::MediaLive::Waiters::ClusterCreated
- Inherits:
-
Object
- Object
- Aws::MediaLive::Waiters::ClusterCreated
- Defined in:
- lib/aws-sdk-medialive/waiters.rb,
sig/waiters.rbs
Overview
Wait until a cluster has been created
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ClusterCreated
constructor
A new instance of ClusterCreated.
-
#wait(params = {}) ⇒ Types::DescribeClusterResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ClusterCreated
Returns a new instance of ClusterCreated.
462 463 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 462
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
505 506 507 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 505 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeClusterResponse
Returns a response object which responds to the following methods:
- #arn => String
- #channel_ids => Array<String>
- #cluster_type => String
- #id => String
- #instance_role_arn => String
- #name => String
- #network_settings => Types::ClusterNetworkSettings
- #state => String
500 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 500
def wait: (
|