Class: Aws::MediaLive::Waiters::InputAttached
- Inherits:
-
Object
- Object
- Aws::MediaLive::Waiters::InputAttached
- Defined in:
- lib/aws-sdk-medialive/waiters.rb,
sig/waiters.rbs
Overview
Wait until an input has been attached
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ InputAttached
constructor
A new instance of InputAttached.
-
#wait(params = {}) ⇒ Types::DescribeInputResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ InputAttached
Returns a new instance of InputAttached.
568 569 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 568
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
605 606 607 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 605 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeInputResponse
Returns a response object which responds to the following methods:
- #arn => String
- #attached_channels => Array<String>
- #destinations => Array<Types::InputDestination>
- #id => String
- #input_class => String
- #input_devices => Array<Types::InputDeviceSettings>
- #input_partner_ids => Array<String>
- #input_source_type => String
- #media_connect_flows => Array<Types::MediaConnectFlow>
- #name => String
- #role_arn => String
- #security_groups => Array<String>
- #sources => Array<Types::InputSource>
- #state => String
- #tags => Hash<String,String>
- #type => String
- #srt_settings => Types::SrtSettings
- #input_network_location => String
- #multicast_settings => Types::MulticastSettings
- #smpte_2110_receiver_group_settings => Types::Smpte2110ReceiverGroupSettings
- #sdi_sources => Array<String>
- #router_settings => Types::RouterInputSettings
600 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 600
def wait: (
|