Class: Aws::MediaLive::Waiters::InputDetached
- Inherits:
-
Object
- Object
- Aws::MediaLive::Waiters::InputDetached
- Defined in:
- lib/aws-sdk-medialive/waiters.rb,
sig/waiters.rbs
Overview
Wait until an input has been detached
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ InputDetached
constructor
A new instance of InputDetached.
-
#wait(params = {}) ⇒ Types::DescribeInputResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ InputDetached
Returns a new instance of InputDetached.
668 669 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 668
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
711 712 713 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 711 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeInputResponse
Returns a response object which responds to the following methods:
- #arn => String
- #attached_channels => Array<String>
- #destinations => Array<Types::InputDestination>
- #id => String
- #input_class => String
- #input_devices => Array<Types::InputDeviceSettings>
- #input_partner_ids => Array<String>
- #input_source_type => String
- #media_connect_flows => Array<Types::MediaConnectFlow>
- #name => String
- #role_arn => String
- #security_groups => Array<String>
- #sources => Array<Types::InputSource>
- #state => String
- #tags => Hash<String,String>
- #type => String
- #srt_settings => Types::SrtSettings
- #input_network_location => String
- #multicast_settings => Types::MulticastSettings
- #smpte_2110_receiver_group_settings => Types::Smpte2110ReceiverGroupSettings
- #sdi_sources => Array<String>
- #router_settings => Types::RouterInputSettings
706 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 706
def wait: (
|