Class: Aws::MediaLive::Waiters::MultiplexRunning
- Inherits:
-
Object
- Object
- Aws::MediaLive::Waiters::MultiplexRunning
- Defined in:
- lib/aws-sdk-medialive/waiters.rb,
sig/waiters.rbs
Overview
Wait until a multiplex is running
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ MultiplexRunning
constructor
A new instance of MultiplexRunning.
-
#wait(params = {}) ⇒ Types::DescribeMultiplexResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ MultiplexRunning
Returns a new instance of MultiplexRunning.
830 831 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 830
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
867 868 869 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 867 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeMultiplexResponse
Returns a response object which responds to the following methods:
- #arn => String
- #availability_zones => Array<String>
- #destinations => Array<Types::MultiplexOutputDestination>
- #id => String
- #multiplex_settings => Types::MultiplexSettings
- #name => String
- #pipelines_running_count => Integer
- #program_count => Integer
- #state => String
- #tags => Hash<String,String>
862 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 862
def wait: (
|