Class: Aws::MediaLive::Waiters::MultiplexStopped
- Inherits:
-
Object
- Object
- Aws::MediaLive::Waiters::MultiplexStopped
- Defined in:
- lib/aws-sdk-medialive/waiters.rb,
sig/waiters.rbs
Overview
Wait until a multiplex has is stopped
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ MultiplexStopped
constructor
A new instance of MultiplexStopped.
-
#wait(params = {}) ⇒ Types::DescribeMultiplexResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ MultiplexStopped
Returns a new instance of MultiplexStopped.
880 881 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 880
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
917 918 919 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 917 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeMultiplexResponse
Returns a response object which responds to the following methods:
- #arn => String
- #availability_zones => Array<String>
- #destinations => Array<Types::MultiplexOutputDestination>
- #id => String
- #multiplex_settings => Types::MultiplexSettings
- #name => String
- #pipelines_running_count => Integer
- #program_count => Integer
- #state => String
- #tags => Hash<String,String>
912 |
# File 'lib/aws-sdk-medialive/waiters.rb', line 912
def wait: (
|