Class: Aws::MediaLive::Types::AudioFeedInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::AudioFeedInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Maps an audio selector in the channel to a feed input on the associated Elemental Inference feed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_selector_name ⇒ String
The name of the audio selector in the channel that will be sent to the Elemental Inference feed input.
-
#feed_input ⇒ String
The name of the feed input on the Elemental Inference feed that will receive the audio from the specified audio selector.
Instance Attribute Details
#audio_selector_name ⇒ String
The name of the audio selector in the channel that will be sent to the Elemental Inference feed input.
23153 23154 23155 23156 23157 23158 |
# File 'lib/aws-sdk-medialive/types.rb', line 23153 class AudioFeedInput < Struct.new( :audio_selector_name, :feed_input) SENSITIVE = [] include Aws::Structure end |
#feed_input ⇒ String
The name of the feed input on the Elemental Inference feed that will receive the audio from the specified audio selector.
23153 23154 23155 23156 23157 23158 |
# File 'lib/aws-sdk-medialive/types.rb', line 23153 class AudioFeedInput < Struct.new( :audio_selector_name, :feed_input) SENSITIVE = [] include Aws::Structure end |