Class: Aws::MediaLive::Types::AudioPreMixerSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::AudioPreMixerSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Audio pre-mixer settings for normalizing audio before interleaving. These settings can be applied to individual PIDs or tracks before they are combined.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_normalization_settings ⇒ Types::AudioNormalizationSettings
Audio normalization settings for loudness control.
-
#channels ⇒ Integer
Number of audio channels.
-
#gain_db ⇒ Float
Gain adjustment in dB to apply.
-
#remix_settings ⇒ Types::RemixSettings
Settings that control how input audio channels are remixed.
Instance Attribute Details
#audio_normalization_settings ⇒ Types::AudioNormalizationSettings
Audio normalization settings for loudness control. When specified, audio loudness will be normalized according to the chosen algorithm.
23278 23279 23280 23281 23282 23283 23284 23285 |
# File 'lib/aws-sdk-medialive/types.rb', line 23278 class AudioPreMixerSettings < Struct.new( :audio_normalization_settings, :channels, :gain_db, :remix_settings) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Integer
Number of audio channels. If specified, the audio will be remixed to match this channel count. Ignored if remixSettings is specified.
23278 23279 23280 23281 23282 23283 23284 23285 |
# File 'lib/aws-sdk-medialive/types.rb', line 23278 class AudioPreMixerSettings < Struct.new( :audio_normalization_settings, :channels, :gain_db, :remix_settings) SENSITIVE = [] include Aws::Structure end |
#gain_db ⇒ Float
Gain adjustment in dB to apply. Range: -60 to +60 dB
23278 23279 23280 23281 23282 23283 23284 23285 |
# File 'lib/aws-sdk-medialive/types.rb', line 23278 class AudioPreMixerSettings < Struct.new( :audio_normalization_settings, :channels, :gain_db, :remix_settings) SENSITIVE = [] include Aws::Structure end |
#remix_settings ⇒ Types::RemixSettings
Settings that control how input audio channels are remixed. When specified, allows fine-grained control over channel mapping and gain levels. Takes precedence over the ‘channels’ setting.
23278 23279 23280 23281 23282 23283 23284 23285 |
# File 'lib/aws-sdk-medialive/types.rb', line 23278 class AudioPreMixerSettings < Struct.new( :audio_normalization_settings, :channels, :gain_db, :remix_settings) SENSITIVE = [] include Aws::Structure end |