Class: Aws::MediaLive::Types::AudioTrack
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::AudioTrack
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Represents a single audio track for selection with optional pre-mixer settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#premix_settings ⇒ Types::AudioPreMixerSettings
Optional audio pre-mixer settings for this track.
-
#track ⇒ Integer
1-based integer value that maps to a specific audio track.
Instance Attribute Details
#premix_settings ⇒ Types::AudioPreMixerSettings
Optional audio pre-mixer settings for this track. When specified, allows per-track audio processing including channel remixing, gain adjustment, and loudness normalization before interleaving.
748 749 750 751 752 753 |
# File 'lib/aws-sdk-medialive/types.rb', line 748 class AudioTrack < Struct.new( :track, :premix_settings) SENSITIVE = [] include Aws::Structure end |
#track ⇒ Integer
1-based integer value that maps to a specific audio track
748 749 750 751 752 753 |
# File 'lib/aws-sdk-medialive/types.rb', line 748 class AudioTrack < Struct.new( :track, :premix_settings) SENSITIVE = [] include Aws::Structure end |