Class: Aws::MediaLive::Types::ChannelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::ChannelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::DescribeAnywhereSettings
AnywhereSettings settings for this channel.
-
#arn ⇒ String
The unique arn of the channel.
-
#cdi_input_specification ⇒ Types::CdiInputSpecification
Specification of CDI inputs for this channel.
-
#channel_class ⇒ String
The class for this channel.
-
#channel_engine_version ⇒ Types::ChannelEngineVersionResponse
The engine version that you requested for this channel.
-
#channel_security_groups ⇒ Array<String>
A list of IDs for all the Input Security Groups attached to the channel.
-
#destinations ⇒ Array<Types::OutputDestination>
A list of destinations of the channel.
-
#egress_endpoints ⇒ Array<Types::ChannelEgressEndpoint>
The endpoints where outgoing connections initiate from.
-
#id ⇒ String
The unique id of the channel.
-
#inference_settings ⇒ Types::DescribeInferenceSettings
Include this setting to include Elemental Inference features in this channel.
-
#input_attachments ⇒ Array<Types::InputAttachment>
List of input attachments for channel.
-
#input_specification ⇒ Types::InputSpecification
Specification of network and file inputs for this channel.
-
#linked_channel_settings ⇒ Types::DescribeLinkedChannelSettings
Linked Channel Settings for this channel.
-
#log_level ⇒ String
The log level being written to CloudWatch Logs.
-
#maintenance ⇒ Types::MaintenanceStatus
Maintenance settings for this channel.
-
#name ⇒ String
The name of the channel.
-
#pipelines_running_count ⇒ Integer
The number of currently healthy pipelines.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role assumed when running the Channel.
- #state ⇒ String
-
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
-
#used_channel_engine_versions ⇒ Array<Types::ChannelEngineVersionResponse>
The engine version that the running pipelines are using.
-
#vpc ⇒ Types::VpcOutputSettingsDescription
Settings for any VPC outputs.
Instance Attribute Details
#anywhere_settings ⇒ Types::DescribeAnywhereSettings
AnywhereSettings settings for this channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The unique arn of the channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
Specification of CDI inputs for this channel
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_class ⇒ String
The class for this channel. STANDARD for a channel with two pipelines or SINGLE_PIPELINE for a channel with one pipeline.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionResponse
The engine version that you requested for this channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_security_groups ⇒ Array<String>
A list of IDs for all the Input Security Groups attached to the channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
A list of destinations of the channel. For UDP outputs, there is one destination per output. For other types (HLS, for example), there is one destination per packager.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#egress_endpoints ⇒ Array<Types::ChannelEgressEndpoint>
The endpoints where outgoing connections initiate from
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique id of the channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#inference_settings ⇒ Types::DescribeInferenceSettings
Include this setting to include Elemental Inference features in this channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
List of input attachments for channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
Specification of network and file inputs for this channel
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::DescribeLinkedChannelSettings
Linked Channel Settings for this channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level being written to CloudWatch Logs.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceStatus
Maintenance settings for this channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the channel. (user-mutable)
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#pipelines_running_count ⇒ Integer
The number of currently healthy pipelines.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the role assumed when running the Channel.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#used_channel_engine_versions ⇒ Array<Types::ChannelEngineVersionResponse>
The engine version that the running pipelines are using.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#vpc ⇒ Types::VpcOutputSettingsDescription
Settings for any VPC outputs.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-medialive/types.rb', line 2098 class ChannelSummary < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :used_channel_engine_versions, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |