Class: Aws::MediaLive::Types::CloudWatchAlarmTemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CloudWatchAlarmTemplateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
A cloudwatch alarm template’s ARN (Amazon Resource Name).
-
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
- #created_at ⇒ Time
-
#datapoints_to_alarm ⇒ Integer
The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
-
#description ⇒ String
A resource’s optional description.
-
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
-
#group_id ⇒ String
A cloudwatch alarm template group’s id.
-
#id ⇒ String
A cloudwatch alarm template’s id.
-
#metric_name ⇒ String
The name of the metric associated with the alarm.
- #modified_at ⇒ Time
-
#name ⇒ String
A resource’s name.
-
#period ⇒ Integer
The period, in seconds, over which the specified statistic is applied.
-
#statistic ⇒ String
The statistic to apply to the alarm’s metric data.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
-
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
-
#threshold ⇒ Float
The threshold value to compare with the specified statistic.
-
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm’s condition.
Instance Attribute Details
#arn ⇒ String
A cloudwatch alarm template’s ARN (Amazon Resource Name)
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#datapoints_to_alarm ⇒ Integer
The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A resource’s optional description.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
A cloudwatch alarm template group’s id. AWS provided template groups have ids that start with ‘aws-`
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A cloudwatch alarm template’s id. AWS provided templates have ids that start with ‘aws-`
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric associated with the alarm. Must be compatible with targetResourceType.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A resource’s name. Names must be unique within the scope of a resource type in a specific region.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The period, in seconds, over which the specified statistic is applied.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic to apply to the alarm’s metric data.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
The threshold value to compare with the specified statistic.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm’s condition.
14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 |
# File 'lib/aws-sdk-medialive/types.rb', line 14662 class CloudWatchAlarmTemplateSummary < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |