Class: Aws::MediaLive::Types::ClusterAlert
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::ClusterAlert
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
An alert on a cluster
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alert_type ⇒ String
The type of the alert.
-
#channel_id ⇒ String
The ID of the channel this alert is associated with.
- #cleared_timestamp ⇒ Time
-
#id ⇒ String
The further subtype of this alert.
-
#message ⇒ String
The user facing alert message which can have more context.
-
#node_id ⇒ String
The ID of the node this alert is associated with.
- #set_timestamp ⇒ Time
-
#state ⇒ String
The state of the alert.
Instance Attribute Details
#alert_type ⇒ String
The type of the alert
22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22166 class ClusterAlert < Struct.new( :alert_type, :channel_id, :cleared_timestamp, :id, :message, :node_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#channel_id ⇒ String
The ID of the channel this alert is associated with
22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22166 class ClusterAlert < Struct.new( :alert_type, :channel_id, :cleared_timestamp, :id, :message, :node_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#cleared_timestamp ⇒ Time
22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22166 class ClusterAlert < Struct.new( :alert_type, :channel_id, :cleared_timestamp, :id, :message, :node_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The further subtype of this alert
22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22166 class ClusterAlert < Struct.new( :alert_type, :channel_id, :cleared_timestamp, :id, :message, :node_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The user facing alert message which can have more context
22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22166 class ClusterAlert < Struct.new( :alert_type, :channel_id, :cleared_timestamp, :id, :message, :node_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
The ID of the node this alert is associated with
22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22166 class ClusterAlert < Struct.new( :alert_type, :channel_id, :cleared_timestamp, :id, :message, :node_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#set_timestamp ⇒ Time
22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22166 class ClusterAlert < Struct.new( :alert_type, :channel_id, :cleared_timestamp, :id, :message, :node_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the alert
22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22166 class ClusterAlert < Struct.new( :alert_type, :channel_id, :cleared_timestamp, :id, :message, :node_id, :set_timestamp, :state) SENSITIVE = [] include Aws::Structure end |