Class: Aws::MediaLive::Types::CmafIngestCaptionLanguageMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CmafIngestCaptionLanguageMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Add an array item for each language. Follow the order of the caption descriptions. For example, if the first caption description is for German, then the first array item must be for German, and its caption channel must be set to 1. The second array item must be 2, and so on.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#caption_channel ⇒ Integer
A number for the channel for this caption, 1 to 4.
-
#language_code ⇒ String
Language code for the language of the caption in this channel.
Instance Attribute Details
#caption_channel ⇒ Integer
A number for the channel for this caption, 1 to 4.
22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22172 class CmafIngestCaptionLanguageMapping < Struct.new( :caption_channel, :language_code) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
Language code for the language of the caption in this channel. For example, ger/deu. See www.loc.gov/standards/iso639-2
22172 22173 22174 22175 22176 22177 |
# File 'lib/aws-sdk-medialive/types.rb', line 22172 class CmafIngestCaptionLanguageMapping < Struct.new( :caption_channel, :language_code) SENSITIVE = [] include Aws::Structure end |