Class: Aws::MediaLive::Types::CmafIngestGroupSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Cmaf Ingest Group Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_destinationsArray<Types::AdditionalDestinations>

Optional an array of additional destinational HTTP destinations for the OutputGroup outputs

Returns:



14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#caption_language_mappingsArray<Types::CmafIngestCaptionLanguageMapping>

An array that identifies the languages in the four caption channels in the embedded captions.



14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#destinationTypes::OutputLocationRef

A HTTP destination for the tracks



14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#id_3_behaviorString

Set to ENABLED to enable ID3 metadata insertion. To include metadata, you configure other parameters in the output group, or you add an ID3 action to the channel schedule.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#id_3_name_modifierString

Change the modifier that MediaLive automatically adds to the Streams() name that identifies an ID3 track. The default is "id3", which means the default name will be Streams(id3.cmfm). Any string you enter here will replace the "id3" string.\nThe modifier can only contain: numbers, letters, plus (+), minus (-), underscore (_) and period (.) and has a maximum length of 100 characters.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#klv_behaviorString

If set to passthrough, passes any KLV data from the input source to this output.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#klv_name_modifierString

Change the modifier that MediaLive automatically adds to the Streams() name that identifies a KLV track. The default is "klv", which means the default name will be Streams(klv.cmfm). Any string you enter here will replace the "klv" string.\nThe modifier can only contain: numbers, letters, plus (+), minus (-), underscore (_) and period (.) and has a maximum length of 100 characters.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#nielsen_id_3_behaviorString

If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#nielsen_id_3_name_modifierString

Change the modifier that MediaLive automatically adds to the Streams() name that identifies a Nielsen ID3 track. The default is "nid3", which means the default name will be Streams(nid3.cmfm). Any string you enter here will replace the "nid3" string.\nThe modifier can only contain: numbers, letters, plus (+), minus (-), underscore (_) and period (.) and has a maximum length of 100 characters.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#scte_35_name_modifierString

Change the modifier that MediaLive automatically adds to the Streams() name for a SCTE 35 track. The default is "scte", which means the default name will be Streams(scte.cmfm). Any string you enter here will replace the "scte" string.\nThe modifier can only contain: numbers, letters, plus (+), minus (-), underscore (_) and period (.) and has a maximum length of 100 characters.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#scte_35_typeString

SCTE-35 insertion type. Option "none" indicates that a SCTE-35 marker will not be inserted, nor will an IDR be inserted at the SCTE-35 cue point, nor will the segment be segmented. Option "scte35WithoutIdr" indicates that a SCTE-35 marker will be inserted to indicate the cue point, but MediaLive will not insert an IDR on that frame nor will it introduce a new segment boundary there if it wasn't already going to be one (this option is required for use with downstream multiview bitstream stitching workflows). Option "scte35WithoutSegmentation" indicates that a SCTE-35 marker will be inserted to indicate the cue point, and an IDR will be inserted on that frame so that a downstream re-packager might split the segment there, but MediaLive itself will not introduce a new segment boundary there.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#segment_lengthInteger

The nominal duration of segments. The units are specified in SegmentLengthUnits. The segments will end on the next keyframe after the specified duration, so the actual segment length might be longer, and it might be a fraction of the units.

Returns:

  • (Integer)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#segment_length_unitsString

Time unit for segment length parameter.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#send_delay_msInteger

Number of milliseconds to delay the output from the second pipeline.

Returns:

  • (Integer)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#timed_metadata_id_3_frameString

Set to none if you don't want to insert a timecode in the output. Otherwise choose the frame type for the timecode.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#timed_metadata_id_3_periodInteger

If you set up to insert a timecode in the output, specify the frequency for the frame, in seconds.

Returns:

  • (Integer)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end

#timed_metadata_passthroughString

Set to enabled to pass through ID3 metadata from the input sources.

Returns:

  • (String)


14518
14519
14520
14521
14522
14523
14524
14525
14526
14527
14528
14529
14530
14531
14532
14533
14534
14535
14536
14537
14538
# File 'lib/aws-sdk-medialive/types.rb', line 14518

class CmafIngestGroupSettings < Struct.new(
  :destination,
  :nielsen_id_3_behavior,
  :scte_35_type,
  :segment_length,
  :segment_length_units,
  :send_delay_ms,
  :klv_behavior,
  :klv_name_modifier,
  :nielsen_id_3_name_modifier,
  :scte_35_name_modifier,
  :id_3_behavior,
  :id_3_name_modifier,
  :caption_language_mappings,
  :timed_metadata_id_3_frame,
  :timed_metadata_id_3_period,
  :timed_metadata_passthrough,
  :additional_destinations)
  SENSITIVE = []
  include Aws::Structure
end