Class: Aws::MediaLive::Types::CreateChannel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::AnywhereSettings

The Elemental Anywhere settings for this channel.



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification

Specification of CDI inputs for this channel



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_classString

The class for this channel. STANDARD for a channel with two pipelines or SINGLE_PIPELINE for a channel with one pipeline.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionRequest

The desired engine version for this channel.



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

A list of IDs for all the Input Security Groups attached to the channel.

Returns:

  • (Array<String>)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

Returns:



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Returns:

  • (Boolean)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

Encoder Settings



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::InferenceSettings

Include this setting to include Elemental Inference features in this channel.



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

List of input attachments for channel.

Returns:



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification

Specification of network and file inputs for this channel



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::LinkedChannelSettings

The linked channel settings for the channel.



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level to write to CloudWatch Logs.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceCreateSettings

Maintenance settings for this channel.



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of channel.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

Unique request ID to be specified. This is needed to prevent retries from creating multiple resources.**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#reservedString

Deprecated field that’s only usable by whitelisted customers.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

An optional Amazon Resource Name (ARN) of the role to assume when running the Channel.

Returns:

  • (String)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of key-value pairs.

Returns:

  • (Hash<String,String>)


2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vpcTypes::VpcOutputSettings

Settings for the VPC outputs



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-medialive/types.rb', line 2297

class CreateChannel < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end