Class: Aws::MediaLive::Types::CreateChannel
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateChannel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::AnywhereSettings
The Elemental Anywhere settings for this channel.
-
#cdi_input_specification ⇒ Types::CdiInputSpecification
Specification of CDI inputs for this channel.
-
#channel_class ⇒ String
The class for this channel.
-
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
The desired engine version for this channel.
- #destinations ⇒ Array<Types::OutputDestination>
- #dry_run ⇒ Boolean
-
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings.
-
#input_attachments ⇒ Array<Types::InputAttachment>
List of input attachments for channel.
-
#input_specification ⇒ Types::InputSpecification
Specification of network and file inputs for this channel.
-
#linked_channel_settings ⇒ Types::LinkedChannelSettings
The linked channel settings for the channel.
-
#log_level ⇒ String
The log level to write to CloudWatch Logs.
-
#maintenance ⇒ Types::MaintenanceCreateSettings
Maintenance settings for this channel.
-
#name ⇒ String
Name of channel.
-
#request_id ⇒ String
Unique request ID to be specified.
-
#reserved ⇒ String
Deprecated field that’s only usable by whitelisted customers.
-
#role_arn ⇒ String
An optional Amazon Resource Name (ARN) of the role to assume when running the Channel.
-
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
-
#vpc ⇒ Types::VpcOutputSettings
Settings for the VPC outputs.
Instance Attribute Details
#anywhere_settings ⇒ Types::AnywhereSettings
The Elemental Anywhere settings for this channel.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
Specification of CDI inputs for this channel
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#channel_class ⇒ String
The class for this channel. STANDARD for a channel with two pipelines or SINGLE_PIPELINE for a channel with one pipeline.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
The desired engine version for this channel.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
List of input attachments for channel.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
Specification of network and file inputs for this channel
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::LinkedChannelSettings
The linked channel settings for the channel.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level to write to CloudWatch Logs.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceCreateSettings
Maintenance settings for this channel.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of channel.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
Unique request ID to be specified. This is needed to prevent retries from creating multiple resources.**A suitable default value is auto-generated.** You should normally not need to pass this option.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#reserved ⇒ String
Deprecated field that’s only usable by whitelisted customers.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
An optional Amazon Resource Name (ARN) of the role to assume when running the Channel.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#vpc ⇒ Types::VpcOutputSettings
Settings for the VPC outputs
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 |
# File 'lib/aws-sdk-medialive/types.rb', line 2219 class CreateChannel < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |