Class: Aws::MediaLive::Types::CreateChannelPlacementGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_idString

Returns:

  • (String)


19050
19051
19052
19053
19054
19055
19056
19057
19058
# File 'lib/aws-sdk-medialive/types.rb', line 19050

class CreateChannelPlacementGroupRequest < Struct.new(
  :cluster_id,
  :name,
  :nodes,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Specify a name that is unique in the Cluster. You can't change the name. Names are case-sensitive.

Returns:

  • (String)


19050
19051
19052
19053
19054
19055
19056
19057
19058
# File 'lib/aws-sdk-medialive/types.rb', line 19050

class CreateChannelPlacementGroupRequest < Struct.new(
  :cluster_id,
  :name,
  :nodes,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nodesArray<String>

An array of one ID for the Node that you want to associate with the ChannelPlacementGroup. (You can't associate more than one Node with the ChannelPlacementGroup.) The Node and the ChannelPlacementGroup must be in the same Cluster.

Returns:

  • (Array<String>)


19050
19051
19052
19053
19054
19055
19056
19057
19058
# File 'lib/aws-sdk-medialive/types.rb', line 19050

class CreateChannelPlacementGroupRequest < Struct.new(
  :cluster_id,
  :name,
  :nodes,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

An ID that you assign to a create request. This ID ensures idempotency when creating resources. the request.A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


19050
19051
19052
19053
19054
19055
19056
19057
19058
# File 'lib/aws-sdk-medialive/types.rb', line 19050

class CreateChannelPlacementGroupRequest < Struct.new(
  :cluster_id,
  :name,
  :nodes,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A collection of key-value pairs.

Returns:

  • (Hash<String,String>)


19050
19051
19052
19053
19054
19055
19056
19057
19058
# File 'lib/aws-sdk-medialive/types.rb', line 19050

class CreateChannelPlacementGroupRequest < Struct.new(
  :cluster_id,
  :name,
  :nodes,
  :request_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end