Class: Aws::MediaLive::Types::CreateChannelPlacementGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateChannelPlacementGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #cluster_id ⇒ String
-
#name ⇒ String
Specify a name that is unique in the Cluster.
-
#nodes ⇒ Array<String>
An array of one ID for the Node that you want to associate with the ChannelPlacementGroup.
-
#request_id ⇒ String
An ID that you assign to a create request.
-
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
Instance Attribute Details
#cluster_id ⇒ String
19029 19030 19031 19032 19033 19034 19035 19036 19037 |
# File 'lib/aws-sdk-medialive/types.rb', line 19029 class CreateChannelPlacementGroupRequest < Struct.new( :cluster_id, :name, :nodes, :request_id, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specify a name that is unique in the Cluster. You can't change the name. Names are case-sensitive.
19029 19030 19031 19032 19033 19034 19035 19036 19037 |
# File 'lib/aws-sdk-medialive/types.rb', line 19029 class CreateChannelPlacementGroupRequest < Struct.new( :cluster_id, :name, :nodes, :request_id, :tags) SENSITIVE = [] include Aws::Structure end |
#nodes ⇒ Array<String>
An array of one ID for the Node that you want to associate with the ChannelPlacementGroup. (You can't associate more than one Node with the ChannelPlacementGroup.) The Node and the ChannelPlacementGroup must be in the same Cluster.
19029 19030 19031 19032 19033 19034 19035 19036 19037 |
# File 'lib/aws-sdk-medialive/types.rb', line 19029 class CreateChannelPlacementGroupRequest < Struct.new( :cluster_id, :name, :nodes, :request_id, :tags) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
An ID that you assign to a create request. This ID ensures idempotency when creating resources. the request.A suitable default value is auto-generated. You should normally not need to pass this option.
19029 19030 19031 19032 19033 19034 19035 19036 19037 |
# File 'lib/aws-sdk-medialive/types.rb', line 19029 class CreateChannelPlacementGroupRequest < Struct.new( :cluster_id, :name, :nodes, :request_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
19029 19030 19031 19032 19033 19034 19035 19036 19037 |
# File 'lib/aws-sdk-medialive/types.rb', line 19029 class CreateChannelPlacementGroupRequest < Struct.new( :cluster_id, :name, :nodes, :request_id, :tags) SENSITIVE = [] include Aws::Structure end |