Class: Aws::MediaLive::Types::CreateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::AnywhereSettings

Elemental anywhere settings



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_classString

A standard channel has two encoding pipelines and a single pipeline channel only has one.

Returns:

  • (String)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionRequest



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

Returns:

  • (Array<String>)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

Returns:



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Returns:

  • (Boolean)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

Encoder Settings



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::InferenceSettings

Configures Elemental Inference features in a channel.



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

Returns:



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::LinkedChannelSettings

Configuration for linked channel relationships



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level the user wants for their channel.

Returns:

  • (String)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceCreateSettings



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#reservedString

Returns:

  • (String)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Returns:

  • (String)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Returns:

  • (Hash<String,String>)


2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vpcTypes::VpcOutputSettings

The properties for a private VPC Output When this property is specified, the output egress addresses will be created in a user specified VPC



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/aws-sdk-medialive/types.rb', line 2396

class CreateChannelRequest < Struct.new(
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :request_id,
  :reserved,
  :role_arn,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :dry_run,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end