Class: Aws::MediaLive::Types::CreateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::AnywhereSettings
Elemental anywhere settings.
- #cdi_input_specification ⇒ Types::CdiInputSpecification
-
#channel_class ⇒ String
A standard channel has two encoding pipelines and a single pipeline channel only has one.
- #channel_engine_version ⇒ Types::ChannelEngineVersionRequest
- #channel_security_groups ⇒ Array<String>
- #destinations ⇒ Array<Types::OutputDestination>
- #dry_run ⇒ Boolean
-
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings.
-
#inference_settings ⇒ Types::InferenceSettings
Configures Elemental Inference features in a channel.
- #input_attachments ⇒ Array<Types::InputAttachment>
- #input_specification ⇒ Types::InputSpecification
-
#linked_channel_settings ⇒ Types::LinkedChannelSettings
Configuration for linked channel relationships.
-
#log_level ⇒ String
The log level the user wants for their channel.
- #maintenance ⇒ Types::MaintenanceCreateSettings
- #name ⇒ String
-
#request_id ⇒ String
**A suitable default value is auto-generated.** You should normally not need to pass this option.
- #reserved ⇒ String
- #role_arn ⇒ String
- #tags ⇒ Hash<String,String>
-
#vpc ⇒ Types::VpcOutputSettings
The properties for a private VPC Output When this property is specified, the output egress addresses will be created in a user specified VPC.
Instance Attribute Details
#anywhere_settings ⇒ Types::AnywhereSettings
Elemental anywhere settings
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_class ⇒ String
A standard channel has two encoding pipelines and a single pipeline channel only has one.
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_security_groups ⇒ Array<String>
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#inference_settings ⇒ Types::InferenceSettings
Configures Elemental Inference features in a channel.
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::LinkedChannelSettings
Configuration for linked channel relationships
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level the user wants for their channel.
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceCreateSettings
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#reserved ⇒ String
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#vpc ⇒ Types::VpcOutputSettings
The properties for a private VPC Output When this property is specified, the output egress addresses will be created in a user specified VPC
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/aws-sdk-medialive/types.rb', line 2396 class CreateChannelRequest < Struct.new( :cdi_input_specification, :channel_class, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :request_id, :reserved, :role_arn, :tags, :vpc, :anywhere_settings, :channel_engine_version, :dry_run, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |