Class: Aws::MediaLive::Types::CreateCloudWatchAlarmTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateCloudWatchAlarmTemplateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #arn ⇒ String
-
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
- #created_at ⇒ Time
- #datapoints_to_alarm ⇒ Integer
- #description ⇒ String
- #evaluation_periods ⇒ Integer
- #group_id ⇒ String
- #id ⇒ String
- #metric_name ⇒ String
- #modified_at ⇒ Time
- #name ⇒ String
- #period ⇒ Integer
-
#statistic ⇒ String
The statistic to apply to the alarm’s metric data.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
-
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
- #threshold ⇒ Float
-
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm’s condition.
Instance Attribute Details
#arn ⇒ String
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#datapoints_to_alarm ⇒ Integer
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#evaluation_periods ⇒ Integer
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic to apply to the alarm’s metric data.
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm’s condition.
15008 15009 15010 15011 15012 15013 15014 15015 15016 15017 15018 15019 15020 15021 15022 15023 15024 15025 15026 15027 15028 |
# File 'lib/aws-sdk-medialive/types.rb', line 15008 class CreateCloudWatchAlarmTemplateResponse < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |