Class: Aws::MediaLive::Types::CreateEventBridgeRuleTemplateGroupResponseContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

An eventbridge rule template group’s ARN (Amazon Resource Name)



15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
# File 'lib/aws-sdk-medialive/types.rb', line 15207

class CreateEventBridgeRuleTemplateGroupResponseContent < Struct.new(
  :arn,
  :created_at,
  :description,
  :id,
  :modified_at,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime



15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
# File 'lib/aws-sdk-medialive/types.rb', line 15207

class CreateEventBridgeRuleTemplateGroupResponseContent < Struct.new(
  :arn,
  :created_at,
  :description,
  :id,
  :modified_at,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A resource’s optional description.



15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
# File 'lib/aws-sdk-medialive/types.rb', line 15207

class CreateEventBridgeRuleTemplateGroupResponseContent < Struct.new(
  :arn,
  :created_at,
  :description,
  :id,
  :modified_at,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

An eventbridge rule template group’s id. AWS provided template groups have ids that start with aws-



15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
# File 'lib/aws-sdk-medialive/types.rb', line 15207

class CreateEventBridgeRuleTemplateGroupResponseContent < Struct.new(
  :arn,
  :created_at,
  :description,
  :id,
  :modified_at,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime



15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
# File 'lib/aws-sdk-medialive/types.rb', line 15207

class CreateEventBridgeRuleTemplateGroupResponseContent < Struct.new(
  :arn,
  :created_at,
  :description,
  :id,
  :modified_at,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A resource’s name. Names must be unique within the scope of a resource type in a specific region.



15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
# File 'lib/aws-sdk-medialive/types.rb', line 15207

class CreateEventBridgeRuleTemplateGroupResponseContent < Struct.new(
  :arn,
  :created_at,
  :description,
  :id,
  :modified_at,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Represents the tags associated with a resource.



15207
15208
15209
15210
15211
15212
15213
15214
15215
15216
15217
# File 'lib/aws-sdk-medialive/types.rb', line 15207

class CreateEventBridgeRuleTemplateGroupResponseContent < Struct.new(
  :arn,
  :created_at,
  :description,
  :id,
  :modified_at,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end