Class: Aws::MediaLive::Types::CreateSignalMapResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::CreateSignalMapResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #arn ⇒ String
- #cloud_watch_alarm_template_group_ids ⇒ Array<String>
- #created_at ⇒ Time
- #description ⇒ String
- #discovery_entry_point_arn ⇒ String
- #error_message ⇒ String
- #event_bridge_rule_template_group_ids ⇒ Array<String>
-
#failed_media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an incomplete AWS media workflow as a graph.
- #id ⇒ String
- #last_discovered_at ⇒ Time
-
#last_successful_monitor_deployment ⇒ Types::SuccessfulMonitorDeployment
Represents the latest successful monitor deployment of a signal map.
-
#media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an AWS media workflow as a graph.
- #modified_at ⇒ Time
- #monitor_changes_pending_deployment ⇒ Boolean
-
#monitor_deployment ⇒ Types::MonitorDeployment
Represents the latest monitor deployment of a signal map.
- #name ⇒ String
-
#status ⇒ String
A signal map’s current status which is dependent on its lifecycle actions or associated jobs.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
Instance Attribute Details
#arn ⇒ String
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#cloud_watch_alarm_template_group_ids ⇒ Array<String>
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#discovery_entry_point_arn ⇒ String
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#event_bridge_rule_template_group_ids ⇒ Array<String>
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#failed_media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an incomplete AWS media workflow as a graph.
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#last_discovered_at ⇒ Time
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#last_successful_monitor_deployment ⇒ Types::SuccessfulMonitorDeployment
Represents the latest successful monitor deployment of a signal map.
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an AWS media workflow as a graph.
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_changes_pending_deployment ⇒ Boolean
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_deployment ⇒ Types::MonitorDeployment
Represents the latest monitor deployment of a signal map.
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A signal map’s current status which is dependent on its lifecycle actions or associated jobs.
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
15601 15602 15603 15604 15605 15606 15607 15608 15609 15610 15611 15612 15613 15614 15615 15616 15617 15618 15619 15620 15621 15622 |
# File 'lib/aws-sdk-medialive/types.rb', line 15601 class CreateSignalMapResponse < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |