Class: Aws::MediaLive::Types::DeleteChannelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::DescribeAnywhereSettings

Elemental anywhere settings



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

Returns:

  • (String)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_classString

A standard channel has two encoding pipelines and a single pipeline channel only has one.

Returns:

  • (String)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionResponse



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

Returns:

  • (Array<String>)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

Returns:



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#egress_endpointsArray<Types::ChannelEgressEndpoint>

Returns:



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

Encoder Settings



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Returns:

  • (String)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::DescribeInferenceSettings

Configures Elemental Inference features in a channel.



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

Returns:



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::DescribeLinkedChannelSettings

Linked channel configuration details



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level the user wants for their channel.

Returns:

  • (String)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceStatus



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_detailsArray<Types::PipelineDetail>

Returns:



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipelines_running_countInteger

Returns:

  • (Integer)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Returns:

  • (String)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Returns:

  • (String)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Returns:

  • (Hash<String,String>)


2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vpcTypes::VpcOutputSettingsDescription

The properties for a private VPC Output



2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
# File 'lib/aws-sdk-medialive/types.rb', line 2994

class DeleteChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end