Class: Aws::MediaLive::Types::DescribeClusterResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Contains the response for CreateCluster, DescribeCluster, DeleteCluster, UpdateCluster

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of this Cluster. It is automatically assigned when the Cluster is created.

Returns:

  • (String)


19628
19629
19630
19631
19632
19633
19634
19635
19636
19637
19638
19639
# File 'lib/aws-sdk-medialive/types.rb', line 19628

class DescribeClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#channel_idsArray<String>

Returns:

  • (Array<String>)


19628
19629
19630
19631
19632
19633
19634
19635
19636
19637
19638
19639
# File 'lib/aws-sdk-medialive/types.rb', line 19628

class DescribeClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_typeString

The hardware type for the Cluster

Returns:

  • (String)


19628
19629
19630
19631
19632
19633
19634
19635
19636
19637
19638
19639
# File 'lib/aws-sdk-medialive/types.rb', line 19628

class DescribeClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the Cluster. Unique in the AWS account. The ID is the resource-id portion of the ARN.

Returns:

  • (String)


19628
19629
19630
19631
19632
19633
19634
19635
19636
19637
19638
19639
# File 'lib/aws-sdk-medialive/types.rb', line 19628

class DescribeClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#instance_role_arnString

The ARN of the IAM role for the Node in this Cluster. Any Nodes that are associated with this Cluster assume this role. The role gives permissions to the operations that you expect these Node to perform.

Returns:

  • (String)


19628
19629
19630
19631
19632
19633
19634
19635
19636
19637
19638
19639
# File 'lib/aws-sdk-medialive/types.rb', line 19628

class DescribeClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that you specified for the Cluster.

Returns:

  • (String)


19628
19629
19630
19631
19632
19633
19634
19635
19636
19637
19638
19639
# File 'lib/aws-sdk-medialive/types.rb', line 19628

class DescribeClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#network_settingsTypes::ClusterNetworkSettings

Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.



19628
19629
19630
19631
19632
19633
19634
19635
19636
19637
19638
19639
# File 'lib/aws-sdk-medialive/types.rb', line 19628

class DescribeClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the Cluster.

Returns:

  • (String)


19628
19629
19630
19631
19632
19633
19634
19635
19636
19637
19638
19639
# File 'lib/aws-sdk-medialive/types.rb', line 19628

class DescribeClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end