Class: Aws::MediaLive::Types::DescribeClusterResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DescribeClusterResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Contains the response for CreateCluster, DescribeCluster, DeleteCluster, UpdateCluster
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of this Cluster.
- #channel_ids ⇒ Array<String>
-
#cluster_type ⇒ String
The hardware type for the Cluster.
-
#id ⇒ String
The ID of the Cluster.
-
#instance_role_arn ⇒ String
The ARN of the IAM role for the Node in this Cluster.
-
#name ⇒ String
The name that you specified for the Cluster.
-
#network_settings ⇒ Types::ClusterNetworkSettings
Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.
-
#state ⇒ String
The current state of the Cluster.
Instance Attribute Details
#arn ⇒ String
The ARN of this Cluster. It is automatically assigned when the Cluster is created.
19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 |
# File 'lib/aws-sdk-medialive/types.rb', line 19992 class DescribeClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#channel_ids ⇒ Array<String>
19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 |
# File 'lib/aws-sdk-medialive/types.rb', line 19992 class DescribeClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#cluster_type ⇒ String
The hardware type for the Cluster
19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 |
# File 'lib/aws-sdk-medialive/types.rb', line 19992 class DescribeClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the Cluster. Unique in the AWS account. The ID is the resource-id portion of the ARN.
19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 |
# File 'lib/aws-sdk-medialive/types.rb', line 19992 class DescribeClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#instance_role_arn ⇒ String
The ARN of the IAM role for the Node in this Cluster. Any Nodes that are associated with this Cluster assume this role. The role gives permissions to the operations that you expect these Node to perform.
19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 |
# File 'lib/aws-sdk-medialive/types.rb', line 19992 class DescribeClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you specified for the Cluster.
19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 |
# File 'lib/aws-sdk-medialive/types.rb', line 19992 class DescribeClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#network_settings ⇒ Types::ClusterNetworkSettings
Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.
19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 |
# File 'lib/aws-sdk-medialive/types.rb', line 19992 class DescribeClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Cluster.
19992 19993 19994 19995 19996 19997 19998 19999 20000 20001 20002 20003 |
# File 'lib/aws-sdk-medialive/types.rb', line 19992 class DescribeClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :instance_role_arn, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |