Class: Aws::MediaLive::Types::DescribeClusterSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Used in ListClustersResult.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of this Cluster. It is automatically assigned when the Cluster is created.

Returns:

  • (String)


19685
19686
19687
19688
19689
19690
19691
19692
19693
19694
19695
19696
# File 'lib/aws-sdk-medialive/types.rb', line 19685

class DescribeClusterSummary < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#channel_idsArray<String>

An array of the IDs of the Channels that are associated with this Cluster. One Channel is associated with the Cluster as follows: A Channel belongs to a ChannelPlacementGroup. A ChannelPlacementGroup is attached to a Node. A Node belongs to a Cluster.

Returns:

  • (Array<String>)


19685
19686
19687
19688
19689
19690
19691
19692
19693
19694
19695
19696
# File 'lib/aws-sdk-medialive/types.rb', line 19685

class DescribeClusterSummary < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_typeString

The hardware type for the Cluster.

Returns:

  • (String)


19685
19686
19687
19688
19689
19690
19691
19692
19693
19694
19695
19696
# File 'lib/aws-sdk-medialive/types.rb', line 19685

class DescribeClusterSummary < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the Cluster. Unique in the AWS account. The ID is the resource-id portion of the ARN.

Returns:

  • (String)


19685
19686
19687
19688
19689
19690
19691
19692
19693
19694
19695
19696
# File 'lib/aws-sdk-medialive/types.rb', line 19685

class DescribeClusterSummary < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#instance_role_arnString

The ARN of the IAM role for the Node in this Cluster. Any Nodes that are associated with this Cluster assume this role. The role gives permissions to the operations that you expect these Node to perform.

Returns:

  • (String)


19685
19686
19687
19688
19689
19690
19691
19692
19693
19694
19695
19696
# File 'lib/aws-sdk-medialive/types.rb', line 19685

class DescribeClusterSummary < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that you specified for the Cluster.

Returns:

  • (String)


19685
19686
19687
19688
19689
19690
19691
19692
19693
19694
19695
19696
# File 'lib/aws-sdk-medialive/types.rb', line 19685

class DescribeClusterSummary < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#network_settingsTypes::ClusterNetworkSettings

Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.



19685
19686
19687
19688
19689
19690
19691
19692
19693
19694
19695
19696
# File 'lib/aws-sdk-medialive/types.rb', line 19685

class DescribeClusterSummary < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the Cluster.

Returns:

  • (String)


19685
19686
19687
19688
19689
19690
19691
19692
19693
19694
19695
19696
# File 'lib/aws-sdk-medialive/types.rb', line 19685

class DescribeClusterSummary < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :instance_role_arn,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end