Class: Aws::MediaLive::Types::DescribeInferenceSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Configures Elemental Inference features in a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audio_feed_inputsArray<Types::AudioFeedInput>

A list of audio feed inputs that map audio selectors in the channel to feed inputs on the associated Elemental Inference feed.

Returns:



22998
22999
23000
23001
23002
23003
# File 'lib/aws-sdk-medialive/types.rb', line 22998

class DescribeInferenceSettings < Struct.new(
  :feed_arn,
  :audio_feed_inputs)
  SENSITIVE = []
  include Aws::Structure
end

#feed_arnString

The ARN of the feed resource that is associated with this channel. The feed is a resource in the Elemental Inference service.

Returns:

  • (String)


22998
22999
23000
23001
23002
23003
# File 'lib/aws-sdk-medialive/types.rb', line 22998

class DescribeInferenceSettings < Struct.new(
  :feed_arn,
  :audio_feed_inputs)
  SENSITIVE = []
  include Aws::Structure
end