Class: Aws::MediaLive::Types::DescribeInferenceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DescribeInferenceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Configures Elemental Inference features in a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_feed_inputs ⇒ Array<Types::AudioFeedInput>
A list of audio feed inputs that map audio selectors in the channel to feed inputs on the associated Elemental Inference feed.
-
#feed_arn ⇒ String
The ARN of the feed resource that is associated with this channel.
Instance Attribute Details
#audio_feed_inputs ⇒ Array<Types::AudioFeedInput>
A list of audio feed inputs that map audio selectors in the channel to feed inputs on the associated Elemental Inference feed.
22998 22999 23000 23001 23002 23003 |
# File 'lib/aws-sdk-medialive/types.rb', line 22998 class DescribeInferenceSettings < Struct.new( :feed_arn, :audio_feed_inputs) SENSITIVE = [] include Aws::Structure end |
#feed_arn ⇒ String
The ARN of the feed resource that is associated with this channel. The feed is a resource in the Elemental Inference service.
22998 22999 23000 23001 23002 23003 |
# File 'lib/aws-sdk-medialive/types.rb', line 22998 class DescribeInferenceSettings < Struct.new( :feed_arn, :audio_feed_inputs) SENSITIVE = [] include Aws::Structure end |