Class: Aws::MediaLive::Types::DescribeInputResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::DescribeInputResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #arn ⇒ String
- #attached_channels ⇒ Array<String>
- #destinations ⇒ Array<Types::InputDestination>
- #id ⇒ String
-
#input_class ⇒ String
A standard input has two sources and a single pipeline input only has one.
- #input_devices ⇒ Array<Types::InputDeviceSettings>
-
#input_network_location ⇒ String
With the introduction of MediaLive Anywhere, a MediaLive input can now exist in two different places: AWS or inside an on-premises datacenter.
- #input_partner_ids ⇒ Array<String>
-
#input_source_type ⇒ String
There are two types of input sources, static and dynamic.
- #media_connect_flows ⇒ Array<Types::MediaConnectFlow>
-
#multicast_settings ⇒ Types::MulticastSettings
Settings for a Multicast input.
- #name ⇒ String
- #role_arn ⇒ String
-
#router_settings ⇒ Types::RouterInputSettings
The settings for a MediaConnect Router Input.
-
#sdi_sources ⇒ Array<String>
SDI Sources for this Input.
- #security_groups ⇒ Array<String>
-
#smpte_2110_receiver_group_settings ⇒ Types::Smpte2110ReceiverGroupSettings
Configures the sources for the SMPTE 2110 Receiver Group input.
- #sources ⇒ Array<Types::InputSource>
-
#srt_settings ⇒ Types::SrtSettings
The configured settings for SRT inputs (caller and listener).
- #state ⇒ String
- #tags ⇒ Hash<String,String>
-
#type ⇒ String
The different types of inputs that AWS Elemental MediaLive supports.
Instance Attribute Details
#arn ⇒ String
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#attached_channels ⇒ Array<String>
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::InputDestination>
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#input_class ⇒ String
A standard input has two sources and a single pipeline input only has one.
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#input_devices ⇒ Array<Types::InputDeviceSettings>
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#input_network_location ⇒ String
With the introduction of MediaLive Anywhere, a MediaLive input can now exist in two different places: AWS or inside an on-premises datacenter. By default all inputs will continue to be AWS inputs.
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#input_partner_ids ⇒ Array<String>
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#input_source_type ⇒ String
There are two types of input sources, static and dynamic. If an input source is dynamic you can change the source url of the input dynamically using an input switch action. Currently, two input types support a dynamic url at this time, MP4_FILE and TS_FILE. By default all input sources are static.
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#media_connect_flows ⇒ Array<Types::MediaConnectFlow>
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#multicast_settings ⇒ Types::MulticastSettings
Settings for a Multicast input. Contains a list of multicast Urls and optional source ip addresses.
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#router_settings ⇒ Types::RouterInputSettings
The settings for a MediaConnect Router Input.
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#sdi_sources ⇒ Array<String>
SDI Sources for this Input.
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#smpte_2110_receiver_group_settings ⇒ Types::Smpte2110ReceiverGroupSettings
Configures the sources for the SMPTE 2110 Receiver Group input.
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::InputSource>
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#srt_settings ⇒ Types::SrtSettings
The configured settings for SRT inputs (caller and listener).
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The different types of inputs that AWS Elemental MediaLive supports.
3714 3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-medialive/types.rb', line 3714 class DescribeInputResponse < Struct.new( :arn, :attached_channels, :destinations, :id, :input_class, :input_devices, :input_partner_ids, :input_source_type, :media_connect_flows, :name, :role_arn, :security_groups, :sources, :state, :tags, :type, :srt_settings, :input_network_location, :multicast_settings, :smpte_2110_receiver_group_settings, :sdi_sources, :router_settings) SENSITIVE = [] include Aws::Structure end |