Class: Aws::MediaLive::Types::EmbeddedCaptionPositionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::EmbeddedCaptionPositionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Embedded Caption Position Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#y_position_line ⇒ Integer
Specifies the vertical position of the caption as a row counted from the top of the output.
Instance Attribute Details
#y_position_line ⇒ Integer
Specifies the vertical position of the caption as a row counted from the top of the output. Row 1 is the topmost row. Acceptable values are 1 through 15.
23658 23659 23660 23661 23662 |
# File 'lib/aws-sdk-medialive/types.rb', line 23658 class EmbeddedCaptionPositionSettings < Struct.new( :y_position_line) SENSITIVE = [] include Aws::Structure end |