Class: Aws::MediaLive::Types::EmbeddedDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::EmbeddedDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Embedded Destination Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#position ⇒ Types::EmbeddedCaptionPositionSettings
Specifies the position of the output captions.
-
#style_control ⇒ String
Controls the source of position and style information for the output captions.
Instance Attribute Details
#position ⇒ Types::EmbeddedCaptionPositionSettings
Specifies the position of the output captions. Applies only when styleControl is set to manual.
4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-medialive/types.rb', line 4671 class EmbeddedDestinationSettings < Struct.new( :position, :style_control) SENSITIVE = [] include Aws::Structure end |
#style_control ⇒ String
Controls the source of position and style information for the output captions. - "passthrough": Carry the caption position and style from the source captions. When the source captions are embedded, SCTE-20, or ancillary, the position and style are preserved exactly. When the source captions are another format, the position and any supported style are carried over. - "manual": Applies the specified styling and positioning. All other styling and positioning is given default values.
4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-medialive/types.rb', line 4671 class EmbeddedDestinationSettings < Struct.new( :position, :style_control) SENSITIVE = [] include Aws::Structure end |