Class: Aws::MediaLive::Types::Hdr10Settings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Hdr10 Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_cllInteger

Maximum Content Light Level An integer metadata value defining the maximum light level, in nits, of any single pixel within an encoded HDR video stream or file.

Returns:

  • (Integer)


5899
5900
5901
5902
5903
5904
# File 'lib/aws-sdk-medialive/types.rb', line 5899

class Hdr10Settings < Struct.new(
  :max_cll,
  :max_fall)
  SENSITIVE = []
  include Aws::Structure
end

#max_fallInteger

Maximum Frame Average Light Level An integer metadata value defining the maximum average light level, in nits, for any single frame within an encoded HDR video stream or file.

Returns:

  • (Integer)


5899
5900
5901
5902
5903
5904
# File 'lib/aws-sdk-medialive/types.rb', line 5899

class Hdr10Settings < Struct.new(
  :max_cll,
  :max_fall)
  SENSITIVE = []
  include Aws::Structure
end