Class: Aws::MediaLive::Types::HlsBasicPutSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::HlsBasicPutSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Hls Basic Put Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_retry_interval ⇒ Integer
Number of seconds to wait before retrying connection to the CDN if the connection is lost.
-
#filecache_duration ⇒ Integer
Size in seconds of file cache for streaming outputs.
-
#num_retries ⇒ Integer
Number of retry attempts that will be made before the Live Event is put into an error state.
-
#restart_delay ⇒ Integer
If a streaming output fails, number of seconds to wait until a restart is initiated.
Instance Attribute Details
#connection_retry_interval ⇒ Integer
Number of seconds to wait before retrying connection to the CDN if the connection is lost.
6093 6094 6095 6096 6097 6098 6099 6100 |
# File 'lib/aws-sdk-medialive/types.rb', line 6093 class HlsBasicPutSettings < Struct.new( :connection_retry_interval, :filecache_duration, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#filecache_duration ⇒ Integer
Size in seconds of file cache for streaming outputs.
6093 6094 6095 6096 6097 6098 6099 6100 |
# File 'lib/aws-sdk-medialive/types.rb', line 6093 class HlsBasicPutSettings < Struct.new( :connection_retry_interval, :filecache_duration, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#num_retries ⇒ Integer
Number of retry attempts that will be made before the Live Event is put into an error state. Applies only if the CDN destination URI begins with “s3” or “mediastore”. For other URIs, the value is always 3.
6093 6094 6095 6096 6097 6098 6099 6100 |
# File 'lib/aws-sdk-medialive/types.rb', line 6093 class HlsBasicPutSettings < Struct.new( :connection_retry_interval, :filecache_duration, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#restart_delay ⇒ Integer
If a streaming output fails, number of seconds to wait until a restart is initiated. A value of 0 means never restart.
6093 6094 6095 6096 6097 6098 6099 6100 |
# File 'lib/aws-sdk-medialive/types.rb', line 6093 class HlsBasicPutSettings < Struct.new( :connection_retry_interval, :filecache_duration, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |