Class: Aws::MediaLive::Types::HlsMediaStoreSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Hls Media Store Settings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_retry_intervalInteger

Number of seconds to wait before retrying connection to the CDN if the connection is lost.

Returns:

  • (Integer)


6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-medialive/types.rb', line 6469

class HlsMediaStoreSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :media_store_storage_class,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end

#filecache_durationInteger

Size in seconds of file cache for streaming outputs.

Returns:

  • (Integer)


6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-medialive/types.rb', line 6469

class HlsMediaStoreSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :media_store_storage_class,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end

#media_store_storage_classString

When set to temporal, output files are stored in non-persistent memory for faster reading and writing.

Returns:

  • (String)


6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-medialive/types.rb', line 6469

class HlsMediaStoreSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :media_store_storage_class,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end

#num_retriesInteger

Number of retry attempts that will be made before the Live Event is put into an error state. Applies only if the CDN destination URI begins with “s3” or “mediastore”. For other URIs, the value is always 3.

Returns:

  • (Integer)


6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-medialive/types.rb', line 6469

class HlsMediaStoreSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :media_store_storage_class,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end

#restart_delayInteger

If a streaming output fails, number of seconds to wait until a restart is initiated. A value of 0 means never restart.

Returns:

  • (Integer)


6469
6470
6471
6472
6473
6474
6475
6476
6477
# File 'lib/aws-sdk-medialive/types.rb', line 6469

class HlsMediaStoreSettings < Struct.new(
  :connection_retry_interval,
  :filecache_duration,
  :media_store_storage_class,
  :num_retries,
  :restart_delay)
  SENSITIVE = []
  include Aws::Structure
end