Class: Aws::MediaLive::Types::HlsWebdavSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::HlsWebdavSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Hls Webdav Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_retry_interval ⇒ Integer
Number of seconds to wait before retrying connection to the CDN if the connection is lost.
-
#filecache_duration ⇒ Integer
Size in seconds of file cache for streaming outputs.
-
#http_transfer_mode ⇒ String
Specify whether or not to use chunked transfer encoding to WebDAV.
-
#num_retries ⇒ Integer
Number of retry attempts that will be made before the Live Event is put into an error state.
-
#restart_delay ⇒ Integer
If a streaming output fails, number of seconds to wait until a restart is initiated.
Instance Attribute Details
#connection_retry_interval ⇒ Integer
Number of seconds to wait before retrying connection to the CDN if the connection is lost.
6673 6674 6675 6676 6677 6678 6679 6680 6681 |
# File 'lib/aws-sdk-medialive/types.rb', line 6673 class HlsWebdavSettings < Struct.new( :connection_retry_interval, :filecache_duration, :http_transfer_mode, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#filecache_duration ⇒ Integer
Size in seconds of file cache for streaming outputs.
6673 6674 6675 6676 6677 6678 6679 6680 6681 |
# File 'lib/aws-sdk-medialive/types.rb', line 6673 class HlsWebdavSettings < Struct.new( :connection_retry_interval, :filecache_duration, :http_transfer_mode, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#http_transfer_mode ⇒ String
Specify whether or not to use chunked transfer encoding to WebDAV.
6673 6674 6675 6676 6677 6678 6679 6680 6681 |
# File 'lib/aws-sdk-medialive/types.rb', line 6673 class HlsWebdavSettings < Struct.new( :connection_retry_interval, :filecache_duration, :http_transfer_mode, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#num_retries ⇒ Integer
Number of retry attempts that will be made before the Live Event is put into an error state. Applies only if the CDN destination URI begins with “s3” or “mediastore”. For other URIs, the value is always 3.
6673 6674 6675 6676 6677 6678 6679 6680 6681 |
# File 'lib/aws-sdk-medialive/types.rb', line 6673 class HlsWebdavSettings < Struct.new( :connection_retry_interval, :filecache_duration, :http_transfer_mode, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |
#restart_delay ⇒ Integer
If a streaming output fails, number of seconds to wait until a restart is initiated. A value of 0 means never restart.
6673 6674 6675 6676 6677 6678 6679 6680 6681 |
# File 'lib/aws-sdk-medialive/types.rb', line 6673 class HlsWebdavSettings < Struct.new( :connection_retry_interval, :filecache_duration, :http_transfer_mode, :num_retries, :restart_delay) SENSITIVE = [] include Aws::Structure end |