Class: Aws::MediaLive::Types::InferenceSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::InferenceSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Configures Elemental Inference features in a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_feed_inputs ⇒ Array<Types::AudioFeedInput>
A list of audio feed inputs that map audio selectors in the channel to feed inputs on the associated Elemental Inference feed.
-
#feed_arn ⇒ String
The ARN of the feed resource that is associated with this channel.
Instance Attribute Details
#audio_feed_inputs ⇒ Array<Types::AudioFeedInput>
A list of audio feed inputs that map audio selectors in the channel to feed inputs on the associated Elemental Inference feed.
23019 23020 23021 23022 23023 23024 |
# File 'lib/aws-sdk-medialive/types.rb', line 23019 class InferenceSettings < Struct.new( :feed_arn, :audio_feed_inputs) SENSITIVE = [] include Aws::Structure end |
#feed_arn ⇒ String
The ARN of the feed resource that is associated with this channel. The feed is a resource in the Elemental Inference service.
23019 23020 23021 23022 23023 23024 |
# File 'lib/aws-sdk-medialive/types.rb', line 23019 class InferenceSettings < Struct.new( :feed_arn, :audio_feed_inputs) SENSITIVE = [] include Aws::Structure end |