Class: Aws::MediaLive::Types::InputDeviceMediaConnectConfigurableSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::InputDeviceMediaConnectConfigurableSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Parameters required to attach a MediaConnect flow to the device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_arn ⇒ String
The ARN of the MediaConnect flow to attach this device to.
-
#role_arn ⇒ String
The ARN for the role that MediaLive assumes to access the attached flow and secret.
-
#secret_arn ⇒ String
The ARN for the secret that holds the encryption key to encrypt the content output by the device.
-
#source_name ⇒ String
The name of the MediaConnect Flow source to stream to.
Instance Attribute Details
#flow_arn ⇒ String
The ARN of the MediaConnect flow to attach this device to.
7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-medialive/types.rb', line 7260 class InputDeviceMediaConnectConfigurableSettings < Struct.new( :flow_arn, :role_arn, :secret_arn, :source_name) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN for the role that MediaLive assumes to access the attached flow and secret. For more information about how to create this role, see the MediaLive user guide.
7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-medialive/types.rb', line 7260 class InputDeviceMediaConnectConfigurableSettings < Struct.new( :flow_arn, :role_arn, :secret_arn, :source_name) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The ARN for the secret that holds the encryption key to encrypt the content output by the device.
7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-medialive/types.rb', line 7260 class InputDeviceMediaConnectConfigurableSettings < Struct.new( :flow_arn, :role_arn, :secret_arn, :source_name) SENSITIVE = [] include Aws::Structure end |
#source_name ⇒ String
The name of the MediaConnect Flow source to stream to.
7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-medialive/types.rb', line 7260 class InputDeviceMediaConnectConfigurableSettings < Struct.new( :flow_arn, :role_arn, :secret_arn, :source_name) SENSITIVE = [] include Aws::Structure end |