Class: Aws::MediaLive::Types::InterfaceMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::InterfaceMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in ClusterNetworkSettings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#logical_interface_name ⇒ String
The logical name for one interface (on every Node) that handles a specific type of traffic.
-
#network_id ⇒ String
The ID of the network that you want to connect to the specified logicalInterfaceName.
Instance Attribute Details
#logical_interface_name ⇒ String
The logical name for one interface (on every Node) that handles a specific type of traffic. We recommend that the name hints at the physical interface it applies to. For example, it could refer to the traffic that the physical interface handles. For example, my-Inputs-Interface.
20355 20356 20357 20358 20359 20360 |
# File 'lib/aws-sdk-medialive/types.rb', line 20355 class InterfaceMapping < Struct.new( :logical_interface_name, :network_id) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the network that you want to connect to the specified logicalInterfaceName.
20355 20356 20357 20358 20359 20360 |
# File 'lib/aws-sdk-medialive/types.rb', line 20355 class InterfaceMapping < Struct.new( :logical_interface_name, :network_id) SENSITIVE = [] include Aws::Structure end |