Class: Aws::MediaLive::Types::InterfaceMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Used in ClusterNetworkSettings

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#logical_interface_nameString

The logical name for one interface (on every Node) that handles a specific type of traffic. We recommend that the name hints at the physical interface it applies to. For example, it could refer to the traffic that the physical interface handles. For example, my-Inputs-Interface.

Returns:

  • (String)


20350
20351
20352
20353
20354
20355
# File 'lib/aws-sdk-medialive/types.rb', line 20350

class InterfaceMapping < Struct.new(
  :logical_interface_name,
  :network_id)
  SENSITIVE = []
  include Aws::Structure
end

#network_idString

The ID of the network that you want to connect to the specified logicalInterfaceName.

Returns:

  • (String)


20350
20351
20352
20353
20354
20355
# File 'lib/aws-sdk-medialive/types.rb', line 20350

class InterfaceMapping < Struct.new(
  :logical_interface_name,
  :network_id)
  SENSITIVE = []
  include Aws::Structure
end