Class: Aws::MediaLive::Types::InterfaceMappingUpdateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::InterfaceMappingUpdateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#logical_interface_name ⇒ String
The logical name for one interface (on every Node) that handles a specific type of traffic.
-
#network_id ⇒ String
The ID of the network that you want to connect to the specified logicalInterfaceName.
Instance Attribute Details
#logical_interface_name ⇒ String
The logical name for one interface (on every Node) that handles a specific type of traffic. We recommend that the name hints at the physical interface it applies to. For example, it could refer to the traffic that the physical interface handles. For example, my-Inputs-Interface.
20183 20184 20185 20186 20187 20188 |
# File 'lib/aws-sdk-medialive/types.rb', line 20183 class InterfaceMappingUpdateRequest < Struct.new( :logical_interface_name, :network_id) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
The ID of the network that you want to connect to the specified logicalInterfaceName. You can use the ListNetworks operation to discover all the IDs.
20183 20184 20185 20186 20187 20188 |
# File 'lib/aws-sdk-medialive/types.rb', line 20183 class InterfaceMappingUpdateRequest < Struct.new( :logical_interface_name, :network_id) SENSITIVE = [] include Aws::Structure end |