Class: Aws::MediaLive::Types::MediaPackageV2DestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::MediaPackageV2DestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Media Package V2 Destination Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio_group_id ⇒ String
Applies only to an output that contains audio.
-
#audio_rendition_sets ⇒ String
Applies only to an output that contains video, and only if you want to associate one or more audio groups to this video.
-
#hls_auto_select ⇒ String
Specifies whether MediaPackage should set this output as the auto-select rendition in the HLS manifest.
-
#hls_default ⇒ String
Specifies whether MediaPackage should set this output as the default rendition in the HLS manifest.
-
#output_usage ⇒ Array<String>
List of usage tags declaring how this MediaPackage V2 output is used.
Instance Attribute Details
#audio_group_id ⇒ String
Applies only to an output that contains audio. If you want to put several audio encodes into one audio rendition group, decide on a name (ID) for the group. Then in every audio output that you want to belong to that group, enter that ID in this field. Note that this information is part of the HLS specification (not the CMAF specification), but if you include it then MediaPackage will include it in the manifest it creates for the video player.
22413 22414 22415 22416 22417 22418 22419 22420 22421 |
# File 'lib/aws-sdk-medialive/types.rb', line 22413 class MediaPackageV2DestinationSettings < Struct.new( :audio_group_id, :audio_rendition_sets, :hls_auto_select, :hls_default, :output_usage) SENSITIVE = [] include Aws::Structure end |
#audio_rendition_sets ⇒ String
Applies only to an output that contains video, and only if you want to associate one or more audio groups to this video. In this field you assign the groups that you create (in the Group ID fields in the various audio outputs). Enter one group ID, or enter a comma-separated list of group IDs. Note that this information is part of the HLS specification (not the CMAF specification), but if you include it then MediaPackage will include it in the manifest it creates for the video player.
22413 22414 22415 22416 22417 22418 22419 22420 22421 |
# File 'lib/aws-sdk-medialive/types.rb', line 22413 class MediaPackageV2DestinationSettings < Struct.new( :audio_group_id, :audio_rendition_sets, :hls_auto_select, :hls_default, :output_usage) SENSITIVE = [] include Aws::Structure end |
#hls_auto_select ⇒ String
Specifies whether MediaPackage should set this output as the auto-select rendition in the HLS manifest. YES means this must be the auto-select. NO means this should never be the auto-select. OMIT means MediaPackage decides what to set on this rendition. When you consider all the renditions, follow these guidelines. You can set zero or one renditions to YES. You can set zero or more renditions to NO, but you can't set all renditions to NO. You can set zero, some, or all to OMIT.
22413 22414 22415 22416 22417 22418 22419 22420 22421 |
# File 'lib/aws-sdk-medialive/types.rb', line 22413 class MediaPackageV2DestinationSettings < Struct.new( :audio_group_id, :audio_rendition_sets, :hls_auto_select, :hls_default, :output_usage) SENSITIVE = [] include Aws::Structure end |
#hls_default ⇒ String
Specifies whether MediaPackage should set this output as the default rendition in the HLS manifest. YES means this must be the default. NO means this should never be the default. OMIT means MediaPackage decides what to set on this rendition. When you consider all the renditions, follow these guidelines. You can set zero or one renditions to YES. You can set zero or more renditions to NO, but you can't set all renditions to NO. You can set zero, some, or all to OMIT.
22413 22414 22415 22416 22417 22418 22419 22420 22421 |
# File 'lib/aws-sdk-medialive/types.rb', line 22413 class MediaPackageV2DestinationSettings < Struct.new( :audio_group_id, :audio_rendition_sets, :hls_auto_select, :hls_default, :output_usage) SENSITIVE = [] include Aws::Structure end |
#output_usage ⇒ Array<String>
List of usage tags declaring how this MediaPackage V2 output is used. Currently these are all multiview-related (multiviewPrimaryView, multiviewSecondaryView, multiviewEqualSizeView) and enable multiview validations and augmentations to help ensure proper multiview configuration and compatibility with MediaPackage. Leave empty (the default) if this output has no multiview role. If any video-carrying MediaPackage V2 output in an output group specifies a multiview value, every video-carrying MediaPackage V2 output in the group must also specify a multiview value; place standalone video outputs in a separate output group.
22413 22414 22415 22416 22417 22418 22419 22420 22421 |
# File 'lib/aws-sdk-medialive/types.rb', line 22413 class MediaPackageV2DestinationSettings < Struct.new( :audio_group_id, :audio_rendition_sets, :hls_auto_select, :hls_default, :output_usage) SENSITIVE = [] include Aws::Structure end |