Class: Aws::MediaLive::Types::MediaPackageV2GroupSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::MediaPackageV2GroupSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Media Package V2 Group Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_destinations ⇒ Array<Types::MediaPackageAdditionalDestinations>
Optional an array of additional destinational HTTP destinations for the OutputGroup outputs.
-
#caption_language_mappings ⇒ Array<Types::CaptionLanguageMapping>
Mapping of up to 4 caption channels to caption languages.
-
#id_3_behavior ⇒ String
Set to ENABLED to enable ID3 metadata insertion.
-
#klv_behavior ⇒ String
If set to passthrough, passes any KLV data from the input source to this output.
-
#nielsen_id_3_behavior ⇒ String
If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.
-
#scte_35_type ⇒ String
Type of scte35 track to add.
-
#segment_length ⇒ Integer
The nominal duration of segments.
-
#segment_length_units ⇒ String
Time unit for segment length parameter.
-
#timed_metadata_id_3_frame ⇒ String
Set to none if you don’t want to insert a timecode in the output.
-
#timed_metadata_id_3_period ⇒ Integer
If you set up to insert a timecode in the output, specify the frequency for the frame, in seconds.
-
#timed_metadata_passthrough ⇒ String
Set to enabled to pass through ID3 metadata from the input sources.
Instance Attribute Details
#additional_destinations ⇒ Array<Types::MediaPackageAdditionalDestinations>
Optional an array of additional destinational HTTP destinations for the OutputGroup outputs
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#caption_language_mappings ⇒ Array<Types::CaptionLanguageMapping>
Mapping of up to 4 caption channels to caption languages.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#id_3_behavior ⇒ String
Set to ENABLED to enable ID3 metadata insertion. To include metadata, you configure other parameters in the output group, or you add an ID3 action to the channel schedule.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#klv_behavior ⇒ String
If set to passthrough, passes any KLV data from the input source to this output.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#nielsen_id_3_behavior ⇒ String
If set to passthrough, Nielsen inaudible tones for media tracking will be detected in the input audio and an equivalent ID3 tag will be inserted in the output.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#scte_35_type ⇒ String
Type of scte35 track to add. none or scte35WithoutSegmentation
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#segment_length ⇒ Integer
The nominal duration of segments. The units are specified in SegmentLengthUnits. The segments will end on the next keyframe after the specified duration, so the actual segment length might be longer, and it might be a fraction of the units.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#segment_length_units ⇒ String
Time unit for segment length parameter.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_id_3_frame ⇒ String
Set to none if you don’t want to insert a timecode in the output. Otherwise choose the frame type for the timecode.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_id_3_period ⇒ Integer
If you set up to insert a timecode in the output, specify the frequency for the frame, in seconds.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |
#timed_metadata_passthrough ⇒ String
Set to enabled to pass through ID3 metadata from the input sources.
22074 22075 22076 22077 22078 22079 22080 22081 22082 22083 22084 22085 22086 22087 22088 |
# File 'lib/aws-sdk-medialive/types.rb', line 22074 class MediaPackageV2GroupSettings < Struct.new( :caption_language_mappings, :id_3_behavior, :klv_behavior, :nielsen_id_3_behavior, :scte_35_type, :segment_length, :segment_length_units, :timed_metadata_id_3_frame, :timed_metadata_id_3_period, :timed_metadata_passthrough, :additional_destinations) SENSITIVE = [] include Aws::Structure end |