Class: Aws::MediaLive::Types::PurchaseOffering
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::PurchaseOffering
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
PurchaseOffering request
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Integer
Number of resources.
-
#name ⇒ String
Name for the new reservation.
-
#renewal_settings ⇒ Types::RenewalSettings
Renewal settings for the reservation.
-
#request_id ⇒ String
Unique request ID to be specified.
-
#start ⇒ String
Requested reservation start time (UTC) in ISO-8601 format.
-
#tags ⇒ Hash<String,String>
A collection of key-value pairs.
Instance Attribute Details
#count ⇒ Integer
Number of resources
10896 10897 10898 10899 10900 10901 10902 10903 10904 10905 |
# File 'lib/aws-sdk-medialive/types.rb', line 10896 class PurchaseOffering < Struct.new( :count, :name, :renewal_settings, :request_id, :start, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name for the new reservation
10896 10897 10898 10899 10900 10901 10902 10903 10904 10905 |
# File 'lib/aws-sdk-medialive/types.rb', line 10896 class PurchaseOffering < Struct.new( :count, :name, :renewal_settings, :request_id, :start, :tags) SENSITIVE = [] include Aws::Structure end |
#renewal_settings ⇒ Types::RenewalSettings
Renewal settings for the reservation
10896 10897 10898 10899 10900 10901 10902 10903 10904 10905 |
# File 'lib/aws-sdk-medialive/types.rb', line 10896 class PurchaseOffering < Struct.new( :count, :name, :renewal_settings, :request_id, :start, :tags) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
Unique request ID to be specified. This is needed to prevent retries from creating multiple resources.A suitable default value is auto-generated. You should normally not need to pass this option.
10896 10897 10898 10899 10900 10901 10902 10903 10904 10905 |
# File 'lib/aws-sdk-medialive/types.rb', line 10896 class PurchaseOffering < Struct.new( :count, :name, :renewal_settings, :request_id, :start, :tags) SENSITIVE = [] include Aws::Structure end |
#start ⇒ String
Requested reservation start time (UTC) in ISO-8601 format. The specified time must be between the first day of the current month and one year from now. If no value is given, the default is now.
10896 10897 10898 10899 10900 10901 10902 10903 10904 10905 |
# File 'lib/aws-sdk-medialive/types.rb', line 10896 class PurchaseOffering < Struct.new( :count, :name, :renewal_settings, :request_id, :start, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A collection of key-value pairs
10896 10897 10898 10899 10900 10901 10902 10903 10904 10905 |
# File 'lib/aws-sdk-medialive/types.rb', line 10896 class PurchaseOffering < Struct.new( :count, :name, :renewal_settings, :request_id, :start, :tags) SENSITIVE = [] include Aws::Structure end |