Class: Aws::MediaLive::Types::SdiSourceMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::SdiSourceMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in DescribeNodeSummary, DescribeNodeResult.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#card_number ⇒ Integer
A number that uniquely identifies the SDI card on the node hardware.
-
#channel_number ⇒ Integer
A number that uniquely identifies a port on the SDI card.
-
#sdi_source ⇒ String
The ID of the SdiSource to associate with this port on this card.
Instance Attribute Details
#card_number ⇒ Integer
A number that uniquely identifies the SDI card on the node hardware.
22063 22064 22065 22066 22067 22068 22069 |
# File 'lib/aws-sdk-medialive/types.rb', line 22063 class SdiSourceMapping < Struct.new( :card_number, :channel_number, :sdi_source) SENSITIVE = [] include Aws::Structure end |
#channel_number ⇒ Integer
A number that uniquely identifies a port on the SDI card.
22063 22064 22065 22066 22067 22068 22069 |
# File 'lib/aws-sdk-medialive/types.rb', line 22063 class SdiSourceMapping < Struct.new( :card_number, :channel_number, :sdi_source) SENSITIVE = [] include Aws::Structure end |
#sdi_source ⇒ String
The ID of the SdiSource to associate with this port on this card. You can use the ListSdiSources operation to discover all the IDs.
22063 22064 22065 22066 22067 22068 22069 |
# File 'lib/aws-sdk-medialive/types.rb', line 22063 class SdiSourceMapping < Struct.new( :card_number, :channel_number, :sdi_source) SENSITIVE = [] include Aws::Structure end |