Class: Aws::MediaLive::Types::SdiSourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::SdiSourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in CreateSdiSourceResponse, DeleteSdiSourceResponse, DescribeSdiSourceResponse, ListSdiSourcesResponse, UpdateSdiSourceResponse
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of this SdiSource.
-
#id ⇒ String
The ID of the SdiSource.
-
#inputs ⇒ Array<String>
The list of inputs that are currently using this SDI source.
-
#mode ⇒ String
Applies only if the type is QUAD.
-
#name ⇒ String
The name of the SdiSource.
-
#state ⇒ String
Specifies whether the SDI source is attached to an SDI input (IN_USE) or not (IDLE).
-
#type ⇒ String
Used in SdiSource, CreateSdiSourceRequest, UpdateSdiSourceRequest.
Instance Attribute Details
#arn ⇒ String
The ARN of this SdiSource. It is automatically assigned when the SdiSource is created.
21860 21861 21862 21863 21864 21865 21866 21867 21868 21869 21870 |
# File 'lib/aws-sdk-medialive/types.rb', line 21860 class SdiSourceSummary < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the SdiSource. Unique in the AWS account.The ID is the resource-id portion of the ARN.
21860 21861 21862 21863 21864 21865 21866 21867 21868 21869 21870 |
# File 'lib/aws-sdk-medialive/types.rb', line 21860 class SdiSourceSummary < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<String>
The list of inputs that are currently using this SDI source. This list will be empty if the SdiSource has just been deleted.
21860 21861 21862 21863 21864 21865 21866 21867 21868 21869 21870 |
# File 'lib/aws-sdk-medialive/types.rb', line 21860 class SdiSourceSummary < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Applies only if the type is QUAD. The mode for handling the quad-link signal QUADRANT or INTERLEAVE.
21860 21861 21862 21863 21864 21865 21866 21867 21868 21869 21870 |
# File 'lib/aws-sdk-medialive/types.rb', line 21860 class SdiSourceSummary < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SdiSource.
21860 21861 21862 21863 21864 21865 21866 21867 21868 21869 21870 |
# File 'lib/aws-sdk-medialive/types.rb', line 21860 class SdiSourceSummary < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Specifies whether the SDI source is attached to an SDI input (IN_USE) or not (IDLE).
21860 21861 21862 21863 21864 21865 21866 21867 21868 21869 21870 |
# File 'lib/aws-sdk-medialive/types.rb', line 21860 class SdiSourceSummary < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Used in SdiSource, CreateSdiSourceRequest, UpdateSdiSourceRequest.
21860 21861 21862 21863 21864 21865 21866 21867 21868 21869 21870 |
# File 'lib/aws-sdk-medialive/types.rb', line 21860 class SdiSourceSummary < Struct.new( :arn, :id, :inputs, :mode, :name, :state, :type) SENSITIVE = [] include Aws::Structure end |