Class: Aws::MediaLive::Types::SrtOutputDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::SrtOutputDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_mode ⇒ String
Specifies the mode the output should use for connection establishment.
-
#encryption_passphrase_secret_arn ⇒ String
Arn used to extract the password from Secrets Manager.
-
#listener_port ⇒ Integer
Port number for listener mode connections (required when connectionMode is LISTENER, must not be provided when connectionMode is CALLER).
-
#stream_id ⇒ String
Stream id for SRT destinations (URLs of type srt://).
-
#url ⇒ String
A URL specifying a destination.
Instance Attribute Details
#connection_mode ⇒ String
Specifies the mode the output should use for connection establishment. CALLER mode requires URL, LISTENER mode requires port.
20959 20960 20961 20962 20963 20964 20965 20966 20967 |
# File 'lib/aws-sdk-medialive/types.rb', line 20959 class SrtOutputDestinationSettings < Struct.new( :encryption_passphrase_secret_arn, :stream_id, :url, :connection_mode, :listener_port) SENSITIVE = [] include Aws::Structure end |
#encryption_passphrase_secret_arn ⇒ String
Arn used to extract the password from Secrets Manager
20959 20960 20961 20962 20963 20964 20965 20966 20967 |
# File 'lib/aws-sdk-medialive/types.rb', line 20959 class SrtOutputDestinationSettings < Struct.new( :encryption_passphrase_secret_arn, :stream_id, :url, :connection_mode, :listener_port) SENSITIVE = [] include Aws::Structure end |
#listener_port ⇒ Integer
Port number for listener mode connections (required when connectionMode is LISTENER, must not be provided when connectionMode is CALLER).
20959 20960 20961 20962 20963 20964 20965 20966 20967 |
# File 'lib/aws-sdk-medialive/types.rb', line 20959 class SrtOutputDestinationSettings < Struct.new( :encryption_passphrase_secret_arn, :stream_id, :url, :connection_mode, :listener_port) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Stream id for SRT destinations (URLs of type srt://)
20959 20960 20961 20962 20963 20964 20965 20966 20967 |
# File 'lib/aws-sdk-medialive/types.rb', line 20959 class SrtOutputDestinationSettings < Struct.new( :encryption_passphrase_secret_arn, :stream_id, :url, :connection_mode, :listener_port) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
A URL specifying a destination
20959 20960 20961 20962 20963 20964 20965 20966 20967 |
# File 'lib/aws-sdk-medialive/types.rb', line 20959 class SrtOutputDestinationSettings < Struct.new( :encryption_passphrase_secret_arn, :stream_id, :url, :connection_mode, :listener_port) SENSITIVE = [] include Aws::Structure end |