Class: Aws::MediaLive::Types::StartChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::StartChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::DescribeAnywhereSettings
Elemental anywhere settings.
- #arn ⇒ String
- #cdi_input_specification ⇒ Types::CdiInputSpecification
-
#channel_class ⇒ String
A standard channel has two encoding pipelines and a single pipeline channel only has one.
- #channel_engine_version ⇒ Types::ChannelEngineVersionResponse
- #channel_security_groups ⇒ Array<String>
- #destinations ⇒ Array<Types::OutputDestination>
- #egress_endpoints ⇒ Array<Types::ChannelEgressEndpoint>
-
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings.
- #id ⇒ String
-
#inference_settings ⇒ Types::DescribeInferenceSettings
Configures Elemental Inference features in a channel.
- #input_attachments ⇒ Array<Types::InputAttachment>
- #input_specification ⇒ Types::InputSpecification
-
#linked_channel_settings ⇒ Types::DescribeLinkedChannelSettings
Linked channel configuration details.
-
#log_level ⇒ String
The log level the user wants for their channel.
- #maintenance ⇒ Types::MaintenanceStatus
- #name ⇒ String
- #pipeline_details ⇒ Array<Types::PipelineDetail>
- #pipelines_running_count ⇒ Integer
- #role_arn ⇒ String
- #state ⇒ String
- #tags ⇒ Hash<String,String>
-
#vpc ⇒ Types::VpcOutputSettingsDescription
The properties for a private VPC Output.
Instance Attribute Details
#anywhere_settings ⇒ Types::DescribeAnywhereSettings
Elemental anywhere settings
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_class ⇒ String
A standard channel has two encoding pipelines and a single pipeline channel only has one.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionResponse
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_security_groups ⇒ Array<String>
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#egress_endpoints ⇒ Array<Types::ChannelEgressEndpoint>
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#inference_settings ⇒ Types::DescribeInferenceSettings
Configures Elemental Inference features in a channel.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::DescribeLinkedChannelSettings
Linked channel configuration details
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level the user wants for their channel.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceStatus
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#pipeline_details ⇒ Array<Types::PipelineDetail>
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#pipelines_running_count ⇒ Integer
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#vpc ⇒ Types::VpcOutputSettingsDescription
The properties for a private VPC Output
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 12024 12025 12026 12027 12028 12029 12030 12031 12032 12033 12034 12035 12036 12037 12038 |
# File 'lib/aws-sdk-medialive/types.rb', line 12012 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |