Class: Aws::MediaLive::Types::StartChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::StartChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::DescribeAnywhereSettings
Elemental anywhere settings.
- #arn ⇒ String
- #cdi_input_specification ⇒ Types::CdiInputSpecification
-
#channel_class ⇒ String
A standard channel has two encoding pipelines and a single pipeline channel only has one.
- #channel_engine_version ⇒ Types::ChannelEngineVersionResponse
- #channel_security_groups ⇒ Array<String>
- #destinations ⇒ Array<Types::OutputDestination>
- #egress_endpoints ⇒ Array<Types::ChannelEgressEndpoint>
-
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings.
- #id ⇒ String
-
#inference_settings ⇒ Types::DescribeInferenceSettings
Configures Elemental Inference features in a channel.
- #input_attachments ⇒ Array<Types::InputAttachment>
- #input_specification ⇒ Types::InputSpecification
-
#linked_channel_settings ⇒ Types::DescribeLinkedChannelSettings
Linked channel configuration details.
-
#log_level ⇒ String
The log level the user wants for their channel.
- #maintenance ⇒ Types::MaintenanceStatus
- #name ⇒ String
- #pipeline_details ⇒ Array<Types::PipelineDetail>
- #pipelines_running_count ⇒ Integer
- #role_arn ⇒ String
- #state ⇒ String
- #tags ⇒ Hash<String,String>
-
#vpc ⇒ Types::VpcOutputSettingsDescription
The properties for a private VPC Output.
Instance Attribute Details
#anywhere_settings ⇒ Types::DescribeAnywhereSettings
Elemental anywhere settings
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_class ⇒ String
A standard channel has two encoding pipelines and a single pipeline channel only has one.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionResponse
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_security_groups ⇒ Array<String>
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#egress_endpoints ⇒ Array<Types::ChannelEgressEndpoint>
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#inference_settings ⇒ Types::DescribeInferenceSettings
Configures Elemental Inference features in a channel.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::DescribeLinkedChannelSettings
Linked channel configuration details
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level the user wants for their channel.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceStatus
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#pipeline_details ⇒ Array<Types::PipelineDetail>
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#pipelines_running_count ⇒ Integer
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#vpc ⇒ Types::VpcOutputSettingsDescription
The properties for a private VPC Output
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 12009 12010 12011 12012 12013 12014 12015 12016 12017 |
# File 'lib/aws-sdk-medialive/types.rb', line 11991 class StartChannelResponse < Struct.new( :arn, :cdi_input_specification, :channel_class, :destinations, :egress_endpoints, :encoder_settings, :id, :input_attachments, :input_specification, :log_level, :maintenance, :name, :pipeline_details, :pipelines_running_count, :role_arn, :state, :tags, :vpc, :anywhere_settings, :channel_engine_version, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |