Class: Aws::MediaLive::Types::StartUpdateSignalMapResponseContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::StartUpdateSignalMapResponseContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
A signal map's ARN (Amazon Resource Name).
- #cloud_watch_alarm_template_group_ids ⇒ Array<String>
- #created_at ⇒ Time
-
#description ⇒ String
A resource's optional description.
-
#discovery_entry_point_arn ⇒ String
A top-level supported AWS resource ARN to discovery a signal map from.
-
#error_message ⇒ String
Error message associated with a failed creation or failed update attempt of a signal map.
- #event_bridge_rule_template_group_ids ⇒ Array<String>
-
#failed_media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an incomplete AWS media workflow as a graph.
-
#id ⇒ String
A signal map's id.
- #last_discovered_at ⇒ Time
-
#last_successful_monitor_deployment ⇒ Types::SuccessfulMonitorDeployment
Represents the latest successful monitor deployment of a signal map.
-
#media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an AWS media workflow as a graph.
- #modified_at ⇒ Time
-
#monitor_changes_pending_deployment ⇒ Boolean
If true, there are pending monitor changes for this signal map that can be deployed.
-
#monitor_deployment ⇒ Types::MonitorDeployment
Represents the latest monitor deployment of a signal map.
-
#name ⇒ String
A resource's name.
-
#status ⇒ String
A signal map's current status which is dependent on its lifecycle actions or associated jobs.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
Instance Attribute Details
#arn ⇒ String
A signal map's ARN (Amazon Resource Name)
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#cloud_watch_alarm_template_group_ids ⇒ Array<String>
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A resource's optional description.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#discovery_entry_point_arn ⇒ String
A top-level supported AWS resource ARN to discovery a signal map from.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
Error message associated with a failed creation or failed update attempt of a signal map.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#event_bridge_rule_template_group_ids ⇒ Array<String>
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#failed_media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an incomplete AWS media workflow as a graph.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A signal map's id.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#last_discovered_at ⇒ Time
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#last_successful_monitor_deployment ⇒ Types::SuccessfulMonitorDeployment
Represents the latest successful monitor deployment of a signal map.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#media_resource_map ⇒ Hash<String,Types::MediaResource>
A map representing an AWS media workflow as a graph.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_changes_pending_deployment ⇒ Boolean
If true, there are pending monitor changes for this signal map that can be deployed.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#monitor_deployment ⇒ Types::MonitorDeployment
Represents the latest monitor deployment of a signal map.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A resource's name. Names must be unique within the scope of a resource type in a specific region.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
A signal map's current status which is dependent on its lifecycle actions or associated jobs.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
17721 17722 17723 17724 17725 17726 17727 17728 17729 17730 17731 17732 17733 17734 17735 17736 17737 17738 17739 17740 17741 17742 |
# File 'lib/aws-sdk-medialive/types.rb', line 17721 class StartUpdateSignalMapResponseContent < Struct.new( :arn, :cloud_watch_alarm_template_group_ids, :created_at, :description, :discovery_entry_point_arn, :error_message, :event_bridge_rule_template_group_ids, :failed_media_resource_map, :id, :last_discovered_at, :last_successful_monitor_deployment, :media_resource_map, :modified_at, :monitor_changes_pending_deployment, :monitor_deployment, :name, :status, :tags) SENSITIVE = [] include Aws::Structure end |