Class: Aws::MediaLive::Types::StopChannelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::DescribeAnywhereSettings

Elemental anywhere settings



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

Returns:

  • (String)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_classString

A standard channel has two encoding pipelines and a single pipeline channel only has one.

Returns:

  • (String)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionResponse



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

Returns:

  • (Array<String>)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

Returns:



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#egress_endpointsArray<Types::ChannelEgressEndpoint>

Returns:



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

Encoder Settings



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Returns:

  • (String)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::DescribeInferenceSettings

Configures Elemental Inference features in a channel.



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

Returns:



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::DescribeLinkedChannelSettings

Linked channel configuration details



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level the user wants for their channel.

Returns:

  • (String)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceStatus



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Returns:

  • (String)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_detailsArray<Types::PipelineDetail>

Returns:



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#pipelines_running_countInteger

Returns:

  • (Integer)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Returns:

  • (String)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Returns:

  • (String)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Returns:

  • (Hash<String,String>)


12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#vpcTypes::VpcOutputSettingsDescription

The properties for a private VPC Output



12473
12474
12475
12476
12477
12478
12479
12480
12481
12482
12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
12493
12494
12495
12496
12497
12498
12499
# File 'lib/aws-sdk-medialive/types.rb', line 12473

class StopChannelResponse < Struct.new(
  :arn,
  :cdi_input_specification,
  :channel_class,
  :destinations,
  :egress_endpoints,
  :encoder_settings,
  :id,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :pipeline_details,
  :pipelines_running_count,
  :role_arn,
  :state,
  :tags,
  :vpc,
  :anywhere_settings,
  :channel_engine_version,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end