Class: Aws::MediaLive::Types::UpdateChannel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::AnywhereSettings

The Elemental Anywhere settings for this channel.



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification

Specification of CDI inputs for this channel



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionRequest

Channel engine version for this channel



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

A list of IDs for all the Input Security Groups attached to the channel.

Returns:

  • (Array<String>)


13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

A list of output destinations for this channel.

Returns:



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Returns:

  • (Boolean)


13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

The encoder settings for this channel.



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::InferenceSettings

Include this setting to include Elemental Inference features in this channel.



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

Returns:



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification

Specification of network and file inputs for this channel



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::LinkedChannelSettings

The linked channel settings for the channel.



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level to write to CloudWatch Logs.

Returns:

  • (String)


13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceUpdateSettings

Maintenance settings for this channel.



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the channel.

Returns:

  • (String)


13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

An optional Amazon Resource Name (ARN) of the role to assume when running the Channel. If you do not specify this on an update call but the role was previously set that role will be removed.

Returns:

  • (String)


13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#special_router_settingsTypes::SpecialRouterSettings

When using MediaConnect Router as the source of a MediaLive input there's a special handoff that occurs when a router output is created. This group of settings is set on your behalf by the MediaConnect Router service using this set of settings. This setting object can only by used by that service.



13126
13127
13128
13129
13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
# File 'lib/aws-sdk-medialive/types.rb', line 13126

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end