Class: Aws::MediaLive::Types::UpdateChannel
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateChannel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::AnywhereSettings
The Elemental Anywhere settings for this channel.
-
#cdi_input_specification ⇒ Types::CdiInputSpecification
Specification of CDI inputs for this channel.
-
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
Channel engine version for this channel.
-
#channel_security_groups ⇒ Array<String>
A list of IDs for all the Input Security Groups attached to the channel.
-
#destinations ⇒ Array<Types::OutputDestination>
A list of output destinations for this channel.
- #dry_run ⇒ Boolean
-
#encoder_settings ⇒ Types::EncoderSettings
The encoder settings for this channel.
-
#inference_settings ⇒ Types::InferenceSettings
Include this setting to include Elemental Inference features in this channel.
- #input_attachments ⇒ Array<Types::InputAttachment>
-
#input_specification ⇒ Types::InputSpecification
Specification of network and file inputs for this channel.
-
#linked_channel_settings ⇒ Types::LinkedChannelSettings
The linked channel settings for the channel.
-
#log_level ⇒ String
The log level to write to CloudWatch Logs.
-
#maintenance ⇒ Types::MaintenanceUpdateSettings
Maintenance settings for this channel.
-
#name ⇒ String
The name of the channel.
-
#role_arn ⇒ String
An optional Amazon Resource Name (ARN) of the role to assume when running the Channel.
-
#special_router_settings ⇒ Types::SpecialRouterSettings
When using MediaConnect Router as the source of a MediaLive input there’s a special handoff that occurs when a router output is created.
Instance Attribute Details
#anywhere_settings ⇒ Types::AnywhereSettings
The Elemental Anywhere settings for this channel.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
Specification of CDI inputs for this channel
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
Channel engine version for this channel
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#channel_security_groups ⇒ Array<String>
A list of IDs for all the Input Security Groups attached to the channel.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
A list of output destinations for this channel.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#encoder_settings ⇒ Types::EncoderSettings
The encoder settings for this channel.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#inference_settings ⇒ Types::InferenceSettings
Include this setting to include Elemental Inference features in this channel.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
Specification of network and file inputs for this channel
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::LinkedChannelSettings
The linked channel settings for the channel.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level to write to CloudWatch Logs.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceUpdateSettings
Maintenance settings for this channel.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the channel.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
An optional Amazon Resource Name (ARN) of the role to assume when running the Channel. If you do not specify this on an update call but the role was previously set that role will be removed.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#special_router_settings ⇒ Types::SpecialRouterSettings
When using MediaConnect Router as the source of a MediaLive input there’s a special handoff that occurs when a router output is created. This group of settings is set on your behalf by the MediaConnect Router service using this set of settings. This setting object can only by used by that service.
13105 13106 13107 13108 13109 13110 13111 13112 13113 13114 13115 13116 13117 13118 13119 13120 13121 13122 13123 13124 |
# File 'lib/aws-sdk-medialive/types.rb', line 13105 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |