Class: Aws::MediaLive::Types::UpdateChannel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::AnywhereSettings

The Elemental Anywhere settings for this channel.



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification

Specification of CDI inputs for this channel



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionRequest

Channel engine version for this channel



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

A list of output destinations for this channel.

Returns:



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Returns:

  • (Boolean)


12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

The encoder settings for this channel.



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

Returns:



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification

Specification of network and file inputs for this channel



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::LinkedChannelSettings

The linked channel settings for the channel.



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level to write to CloudWatch Logs.

Returns:

  • (String)


12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceUpdateSettings

Maintenance settings for this channel.



12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the channel.

Returns:

  • (String)


12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

An optional Amazon Resource Name (ARN) of the role to assume when running the Channel. If you do not specify this on an update call but the role was previously set that role will be removed.

Returns:

  • (String)


12914
12915
12916
12917
12918
12919
12920
12921
12922
12923
12924
12925
12926
12927
12928
12929
12930
# File 'lib/aws-sdk-medialive/types.rb', line 12914

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings)
  SENSITIVE = []
  include Aws::Structure
end