Class: Aws::MediaLive::Types::UpdateChannel
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateChannel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::AnywhereSettings
The Elemental Anywhere settings for this channel.
-
#cdi_input_specification ⇒ Types::CdiInputSpecification
Specification of CDI inputs for this channel.
-
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
Channel engine version for this channel.
-
#destinations ⇒ Array<Types::OutputDestination>
A list of output destinations for this channel.
- #dry_run ⇒ Boolean
-
#encoder_settings ⇒ Types::EncoderSettings
The encoder settings for this channel.
- #input_attachments ⇒ Array<Types::InputAttachment>
-
#input_specification ⇒ Types::InputSpecification
Specification of network and file inputs for this channel.
-
#linked_channel_settings ⇒ Types::LinkedChannelSettings
The linked channel settings for the channel.
-
#log_level ⇒ String
The log level to write to CloudWatch Logs.
-
#maintenance ⇒ Types::MaintenanceUpdateSettings
Maintenance settings for this channel.
-
#name ⇒ String
The name of the channel.
-
#role_arn ⇒ String
An optional Amazon Resource Name (ARN) of the role to assume when running the Channel.
Instance Attribute Details
#anywhere_settings ⇒ Types::AnywhereSettings
The Elemental Anywhere settings for this channel.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
Specification of CDI inputs for this channel
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
Channel engine version for this channel
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
A list of output destinations for this channel.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#encoder_settings ⇒ Types::EncoderSettings
The encoder settings for this channel.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
Specification of network and file inputs for this channel
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::LinkedChannelSettings
The linked channel settings for the channel.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level to write to CloudWatch Logs.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceUpdateSettings
Maintenance settings for this channel.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the channel.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
An optional Amazon Resource Name (ARN) of the role to assume when running the Channel. If you do not specify this on an update call but the role was previously set that role will be removed.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/aws-sdk-medialive/types.rb', line 12914 class UpdateChannel < Struct.new( :cdi_input_specification, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings) SENSITIVE = [] include Aws::Structure end |