Class: Aws::MediaLive::Types::UpdateChannel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anywhere_settingsTypes::AnywhereSettings

The Elemental Anywhere settings for this channel.



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#cdi_input_specificationTypes::CdiInputSpecification

Specification of CDI inputs for this channel



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_engine_versionTypes::ChannelEngineVersionRequest

Channel engine version for this channel



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#channel_security_groupsArray<String>

A list of IDs for all the Input Security Groups attached to the channel.

Returns:

  • (Array<String>)


13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<Types::OutputDestination>

A list of output destinations for this channel.

Returns:



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Returns:

  • (Boolean)


13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#encoder_settingsTypes::EncoderSettings

The encoder settings for this channel.



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#inference_settingsTypes::InferenceSettings

Include this setting to include Elemental Inference features in this channel.



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_attachmentsArray<Types::InputAttachment>

Returns:



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_specificationTypes::InputSpecification

Specification of network and file inputs for this channel



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#linked_channel_settingsTypes::LinkedChannelSettings

The linked channel settings for the channel.



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#log_levelString

The log level to write to CloudWatch Logs.

Returns:

  • (String)


13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#maintenanceTypes::MaintenanceUpdateSettings

Maintenance settings for this channel.



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the channel.

Returns:

  • (String)


13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

An optional Amazon Resource Name (ARN) of the role to assume when running the Channel. If you do not specify this on an update call but the role was previously set that role will be removed.

Returns:

  • (String)


13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
13048
# File 'lib/aws-sdk-medialive/types.rb', line 13030

class UpdateChannel < Struct.new(
  :cdi_input_specification,
  :destinations,
  :encoder_settings,
  :input_attachments,
  :input_specification,
  :log_level,
  :maintenance,
  :name,
  :role_arn,
  :channel_engine_version,
  :dry_run,
  :anywhere_settings,
  :linked_channel_settings,
  :channel_security_groups,
  :inference_settings)
  SENSITIVE = []
  include Aws::Structure
end