Class: Aws::MediaLive::Types::UpdateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::AnywhereSettings
Elemental anywhere settings.
- #cdi_input_specification ⇒ Types::CdiInputSpecification
- #channel_engine_version ⇒ Types::ChannelEngineVersionRequest
- #channel_id ⇒ String
- #channel_security_groups ⇒ Array<String>
- #destinations ⇒ Array<Types::OutputDestination>
- #dry_run ⇒ Boolean
-
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings.
-
#inference_settings ⇒ Types::InferenceSettings
Configures Elemental Inference features in a channel.
- #input_attachments ⇒ Array<Types::InputAttachment>
- #input_specification ⇒ Types::InputSpecification
-
#linked_channel_settings ⇒ Types::LinkedChannelSettings
Configuration for linked channel relationships.
-
#log_level ⇒ String
The log level the user wants for their channel.
- #maintenance ⇒ Types::MaintenanceUpdateSettings
- #name ⇒ String
- #role_arn ⇒ String
-
#special_router_settings ⇒ Types::SpecialRouterSettings
When using MediaConnect Router as the source of a MediaLive input there's a special handoff that occurs when a router output is created.
Instance Attribute Details
#anywhere_settings ⇒ Types::AnywhereSettings
Elemental anywhere settings
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#channel_id ⇒ String
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#channel_security_groups ⇒ Array<String>
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#inference_settings ⇒ Types::InferenceSettings
Configures Elemental Inference features in a channel.
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::LinkedChannelSettings
Configuration for linked channel relationships
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level the user wants for their channel.
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceUpdateSettings
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |
#special_router_settings ⇒ Types::SpecialRouterSettings
When using MediaConnect Router as the source of a MediaLive input there's a special handoff that occurs when a router output is created. This group of settings is set on your behalf by the MediaConnect Router service using this set of settings. This setting object can only by used by that service.
13259 13260 13261 13262 13263 13264 13265 13266 13267 13268 13269 13270 13271 13272 13273 13274 13275 13276 13277 13278 13279 |
# File 'lib/aws-sdk-medialive/types.rb', line 13259 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings, :special_router_settings) SENSITIVE = [] include Aws::Structure end |