Class: Aws::MediaLive::Types::UpdateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anywhere_settings ⇒ Types::AnywhereSettings
Elemental anywhere settings.
- #cdi_input_specification ⇒ Types::CdiInputSpecification
- #channel_engine_version ⇒ Types::ChannelEngineVersionRequest
- #channel_id ⇒ String
- #channel_security_groups ⇒ Array<String>
- #destinations ⇒ Array<Types::OutputDestination>
- #dry_run ⇒ Boolean
-
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings.
-
#inference_settings ⇒ Types::InferenceSettings
Configures Elemental Inference features in a channel.
- #input_attachments ⇒ Array<Types::InputAttachment>
- #input_specification ⇒ Types::InputSpecification
-
#linked_channel_settings ⇒ Types::LinkedChannelSettings
Configuration for linked channel relationships.
-
#log_level ⇒ String
The log level the user wants for their channel.
- #maintenance ⇒ Types::MaintenanceUpdateSettings
- #name ⇒ String
- #role_arn ⇒ String
Instance Attribute Details
#anywhere_settings ⇒ Types::AnywhereSettings
Elemental anywhere settings
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#cdi_input_specification ⇒ Types::CdiInputSpecification
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_engine_version ⇒ Types::ChannelEngineVersionRequest
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_id ⇒ String
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#channel_security_groups ⇒ Array<String>
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::OutputDestination>
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#encoder_settings ⇒ Types::EncoderSettings
Encoder Settings
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#inference_settings ⇒ Types::InferenceSettings
Configures Elemental Inference features in a channel.
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_attachments ⇒ Array<Types::InputAttachment>
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#input_specification ⇒ Types::InputSpecification
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#linked_channel_settings ⇒ Types::LinkedChannelSettings
Configuration for linked channel relationships
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#log_level ⇒ String
The log level the user wants for their channel.
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#maintenance ⇒ Types::MaintenanceUpdateSettings
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
13154 13155 13156 13157 13158 13159 13160 13161 13162 13163 13164 13165 13166 13167 13168 13169 13170 13171 13172 13173 |
# File 'lib/aws-sdk-medialive/types.rb', line 13154 class UpdateChannelRequest < Struct.new( :cdi_input_specification, :channel_id, :destinations, :encoder_settings, :input_attachments, :input_specification, :log_level, :maintenance, :name, :role_arn, :channel_engine_version, :dry_run, :anywhere_settings, :linked_channel_settings, :channel_security_groups, :inference_settings) SENSITIVE = [] include Aws::Structure end |