Class: Aws::MediaLive::Types::UpdateCloudWatchAlarmTemplateResponseContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateCloudWatchAlarmTemplateResponseContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
A cloudwatch alarm template’s ARN (Amazon Resource Name).
-
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
- #created_at ⇒ Time
-
#datapoints_to_alarm ⇒ Integer
The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
-
#description ⇒ String
A resource’s optional description.
-
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
-
#group_id ⇒ String
A cloudwatch alarm template group’s id.
-
#id ⇒ String
A cloudwatch alarm template’s id.
-
#metric_name ⇒ String
The name of the metric associated with the alarm.
- #modified_at ⇒ Time
-
#name ⇒ String
A resource’s name.
-
#period ⇒ Integer
The period, in seconds, over which the specified statistic is applied.
-
#statistic ⇒ String
The statistic to apply to the alarm’s metric data.
-
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
-
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
-
#threshold ⇒ Float
The threshold value to compare with the specified statistic.
-
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm’s condition.
Instance Attribute Details
#arn ⇒ String
A cloudwatch alarm template’s ARN (Amazon Resource Name)
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#comparison_operator ⇒ String
The comparison operator used to compare the specified statistic and the threshold.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#datapoints_to_alarm ⇒ Integer
The number of datapoints within the evaluation period that must be breaching to trigger the alarm.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A resource’s optional description.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#evaluation_periods ⇒ Integer
The number of periods over which data is compared to the specified threshold.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#group_id ⇒ String
A cloudwatch alarm template group’s id. AWS provided template groups have ids that start with ‘aws-`
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A cloudwatch alarm template’s id. AWS provided templates have ids that start with ‘aws-`
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric associated with the alarm. Must be compatible with targetResourceType.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A resource’s name. Names must be unique within the scope of a resource type in a specific region.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
The period, in seconds, over which the specified statistic is applied.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#statistic ⇒ String
The statistic to apply to the alarm’s metric data.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Represents the tags associated with a resource.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#target_resource_type ⇒ String
The resource type this template should dynamically generate cloudwatch metric alarms for.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ Float
The threshold value to compare with the specified statistic.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |
#treat_missing_data ⇒ String
Specifies how missing data points are treated when evaluating the alarm’s condition.
17928 17929 17930 17931 17932 17933 17934 17935 17936 17937 17938 17939 17940 17941 17942 17943 17944 17945 17946 17947 17948 |
# File 'lib/aws-sdk-medialive/types.rb', line 17928 class UpdateCloudWatchAlarmTemplateResponseContent < Struct.new( :arn, :comparison_operator, :created_at, :datapoints_to_alarm, :description, :evaluation_periods, :group_id, :id, :metric_name, :modified_at, :name, :period, :statistic, :tags, :target_resource_type, :threshold, :treat_missing_data) SENSITIVE = [] include Aws::Structure end |