Class: Aws::MediaLive::Types::UpdateClusterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateClusterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in the UpdatedCluster operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #cluster_id ⇒ String
-
#name ⇒ String
Include this parameter only if you want to change the current name of the Cluster.
-
#network_settings ⇒ Types::ClusterNetworkSettingsUpdateRequest
Include this property only if you want to change the current connections between the Nodes in the Cluster and the Networks the Cluster is associated with.
Instance Attribute Details
#cluster_id ⇒ String
21106 21107 21108 21109 21110 21111 21112 |
# File 'lib/aws-sdk-medialive/types.rb', line 21106 class UpdateClusterRequest < Struct.new( :cluster_id, :name, :network_settings) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Include this parameter only if you want to change the current name of the Cluster. Specify a name that is unique in the AWS account. You can’t change the name. Names are case-sensitive.
21106 21107 21108 21109 21110 21111 21112 |
# File 'lib/aws-sdk-medialive/types.rb', line 21106 class UpdateClusterRequest < Struct.new( :cluster_id, :name, :network_settings) SENSITIVE = [] include Aws::Structure end |
#network_settings ⇒ Types::ClusterNetworkSettingsUpdateRequest
Include this property only if you want to change the current connections between the Nodes in the Cluster and the Networks the Cluster is associated with.
21106 21107 21108 21109 21110 21111 21112 |
# File 'lib/aws-sdk-medialive/types.rb', line 21106 class UpdateClusterRequest < Struct.new( :cluster_id, :name, :network_settings) SENSITIVE = [] include Aws::Structure end |