Class: Aws::MediaLive::Types::UpdateClusterResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateClusterResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
The name that you specified for the Cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Cluster.
-
#channel_ids ⇒ Array<String>
An array of the IDs of the Channels that are associated with this Cluster.
-
#cluster_type ⇒ String
The hardware type for the Cluster.
-
#id ⇒ String
The unique ID of the Cluster.
-
#name ⇒ String
The user-specified name of the Cluster.
-
#network_settings ⇒ Types::ClusterNetworkSettings
Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.
-
#state ⇒ String
The current state of the Cluster.
Instance Attribute Details
#arn ⇒ String
The ARN of the Cluster.
21186 21187 21188 21189 21190 21191 21192 21193 21194 21195 21196 |
# File 'lib/aws-sdk-medialive/types.rb', line 21186 class UpdateClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#channel_ids ⇒ Array<String>
An array of the IDs of the Channels that are associated with this Cluster. One Channel is associated with the Cluster as follows: A Channel belongs to a ChannelPlacementGroup. A ChannelPlacementGroup is attached to a Node. A Node belongs to a Cluster.
21186 21187 21188 21189 21190 21191 21192 21193 21194 21195 21196 |
# File 'lib/aws-sdk-medialive/types.rb', line 21186 class UpdateClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#cluster_type ⇒ String
The hardware type for the Cluster
21186 21187 21188 21189 21190 21191 21192 21193 21194 21195 21196 |
# File 'lib/aws-sdk-medialive/types.rb', line 21186 class UpdateClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID of the Cluster.
21186 21187 21188 21189 21190 21191 21192 21193 21194 21195 21196 |
# File 'lib/aws-sdk-medialive/types.rb', line 21186 class UpdateClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The user-specified name of the Cluster.
21186 21187 21188 21189 21190 21191 21192 21193 21194 21195 21196 |
# File 'lib/aws-sdk-medialive/types.rb', line 21186 class UpdateClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#network_settings ⇒ Types::ClusterNetworkSettings
Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.
21186 21187 21188 21189 21190 21191 21192 21193 21194 21195 21196 |
# File 'lib/aws-sdk-medialive/types.rb', line 21186 class UpdateClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Cluster.
21186 21187 21188 21189 21190 21191 21192 21193 21194 21195 21196 |
# File 'lib/aws-sdk-medialive/types.rb', line 21186 class UpdateClusterResult < Struct.new( :arn, :channel_ids, :cluster_type, :id, :name, :network_settings, :state) SENSITIVE = [] include Aws::Structure end |