Class: Aws::MediaLive::Types::UpdateClusterResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

The name that you specified for the Cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the Cluster.

Returns:

  • (String)


20952
20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
# File 'lib/aws-sdk-medialive/types.rb', line 20952

class UpdateClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#channel_idsArray<String>

An array of the IDs of the Channels that are associated with this Cluster. One Channel is associated with the Cluster as follows: A Channel belongs to a ChannelPlacementGroup. A ChannelPlacementGroup is attached to a Node. A Node belongs to a Cluster.

Returns:

  • (Array<String>)


20952
20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
# File 'lib/aws-sdk-medialive/types.rb', line 20952

class UpdateClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_typeString

The hardware type for the Cluster

Returns:

  • (String)


20952
20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
# File 'lib/aws-sdk-medialive/types.rb', line 20952

class UpdateClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique ID of the Cluster.

Returns:

  • (String)


20952
20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
# File 'lib/aws-sdk-medialive/types.rb', line 20952

class UpdateClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The user-specified name of the Cluster.

Returns:

  • (String)


20952
20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
# File 'lib/aws-sdk-medialive/types.rb', line 20952

class UpdateClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#network_settingsTypes::ClusterNetworkSettings

Network settings that connect the Nodes in the Cluster to one or more of the Networks that the Cluster is associated with.



20952
20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
# File 'lib/aws-sdk-medialive/types.rb', line 20952

class UpdateClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the Cluster.

Returns:

  • (String)


20952
20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
# File 'lib/aws-sdk-medialive/types.rb', line 20952

class UpdateClusterResult < Struct.new(
  :arn,
  :channel_ids,
  :cluster_type,
  :id,
  :name,
  :network_settings,
  :state)
  SENSITIVE = []
  include Aws::Structure
end