Class: Aws::MediaLive::Types::UpdateInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medialive/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destinationsArray<Types::InputDestinationRequest>

Destination settings for PUSH type inputs.

Returns:



13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_devicesArray<Types::InputDeviceRequest>

Settings for the devices.

Returns:



13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#input_security_groupsArray<String>

A list of security groups referenced by IDs to attach to the input.

Returns:

  • (Array<String>)


13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#media_connect_flowsArray<Types::MediaConnectFlowRequest>

A list of the MediaConnect Flow ARNs that you want to use as the source of the input. You can specify as few as one Flow and presently, as many as two. The only requirement is when you have more than one is that each Flow is in a separate Availability Zone as this ensures your EML input is redundant to AZ issues.

Returns:



13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#multicast_settingsTypes::MulticastSettingsUpdateRequest

Multicast Input settings.



13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the input.

Returns:

  • (String)


13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the role this input assumes during and after creation.

Returns:

  • (String)


13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#sdi_sourcesArray<String>

SDI Sources for this Input.

Returns:

  • (Array<String>)


13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#smpte_2110_receiver_group_settingsTypes::Smpte2110ReceiverGroupSettings

Include this parameter if the input is a SMPTE 2110 input, to identify the stream sources for this input.



13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::InputSourceRequest>

The source URLs for a PULL-type input. Every PULL type input needs exactly two source URLs for redundancy. Only specify sources for PULL type Inputs. Leave Destinations empty.

Returns:



13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#special_router_settingsTypes::SpecialRouterSettings

When using MediaConnect Router as the source of a MediaLive input there’s a special handoff that occurs when a router output is created. This group of settings is set on your behalf by the MediaConnect Router service using this set of settings. This setting object can only by used by that service.



13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end

#srt_settingsTypes::SrtSettingsRequest

The settings associated with an SRT input.



13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
# File 'lib/aws-sdk-medialive/types.rb', line 13134

class UpdateInput < Struct.new(
  :destinations,
  :input_devices,
  :input_security_groups,
  :media_connect_flows,
  :name,
  :role_arn,
  :sources,
  :srt_settings,
  :multicast_settings,
  :smpte_2110_receiver_group_settings,
  :sdi_sources,
  :special_router_settings)
  SENSITIVE = []
  include Aws::Structure
end