Class: Aws::MediaLive::Types::UpdateNetworkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateNetworkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Used in the UpdateNetwork operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ip_pools ⇒ Array<Types::IpPoolUpdateRequest>
Include this parameter only if you want to change the pool of IP addresses in the network.
-
#name ⇒ String
Include this parameter only if you want to change the name of the Network.
- #network_id ⇒ String
-
#routes ⇒ Array<Types::RouteUpdateRequest>
Include this parameter only if you want to change or add routes in the Network.
Instance Attribute Details
#ip_pools ⇒ Array<Types::IpPoolUpdateRequest>
Include this parameter only if you want to change the pool of IP addresses in the network. An array of IpPoolCreateRequests that identify a collection of IP addresses in this network that you want to reserve for use in MediaLive Anywhere. MediaLive Anywhere uses these IP addresses for Push inputs (in both Bridge and NAT networks) and for output destinations (only in Bridge networks). Each IpPoolUpdateRequest specifies one CIDR block.
21227 21228 21229 21230 21231 21232 21233 21234 |
# File 'lib/aws-sdk-medialive/types.rb', line 21227 class UpdateNetworkRequest < Struct.new( :ip_pools, :name, :network_id, :routes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Include this parameter only if you want to change the name of the Network. Specify a name that is unique in the AWS account. Names are case-sensitive.
21227 21228 21229 21230 21231 21232 21233 21234 |
# File 'lib/aws-sdk-medialive/types.rb', line 21227 class UpdateNetworkRequest < Struct.new( :ip_pools, :name, :network_id, :routes) SENSITIVE = [] include Aws::Structure end |
#network_id ⇒ String
21227 21228 21229 21230 21231 21232 21233 21234 |
# File 'lib/aws-sdk-medialive/types.rb', line 21227 class UpdateNetworkRequest < Struct.new( :ip_pools, :name, :network_id, :routes) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::RouteUpdateRequest>
Include this parameter only if you want to change or add routes in the Network. An array of Routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
21227 21228 21229 21230 21231 21232 21233 21234 |
# File 'lib/aws-sdk-medialive/types.rb', line 21227 class UpdateNetworkRequest < Struct.new( :ip_pools, :name, :network_id, :routes) SENSITIVE = [] include Aws::Structure end |