Class: Aws::MediaLive::Types::UpdateNetworkResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::UpdateNetworkResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Contains the response for the UpdateNetwork
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of this Network.
- #associated_cluster_ids ⇒ Array<String>
-
#id ⇒ String
The ID of the Network.
-
#ip_pools ⇒ Array<Types::IpPool>
An array of IpPools in your organization’s network that identify a collection of IP addresses in this network that are reserved for use in MediaLive Anywhere.
-
#name ⇒ String
The name that you specified for the Network.
-
#routes ⇒ Array<Types::Route>
An array of Routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
-
#state ⇒ String
The current state of the Network.
Instance Attribute Details
#arn ⇒ String
The ARN of this Network. It is automatically assigned when the Network is created.
21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 21089 |
# File 'lib/aws-sdk-medialive/types.rb', line 21079 class UpdateNetworkResult < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#associated_cluster_ids ⇒ Array<String>
21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 21089 |
# File 'lib/aws-sdk-medialive/types.rb', line 21079 class UpdateNetworkResult < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the Network. Unique in the AWS account. The ID is the resource-id portion of the ARN.
21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 21089 |
# File 'lib/aws-sdk-medialive/types.rb', line 21079 class UpdateNetworkResult < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#ip_pools ⇒ Array<Types::IpPool>
An array of IpPools in your organization’s network that identify a collection of IP addresses in this network that are reserved for use in MediaLive Anywhere. MediaLive Anywhere uses these IP addresses for Push inputs (in both Bridge and NAT networks) and for output destinations (only in Bridge networks). Each IpPool specifies one CIDR block.
21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 21089 |
# File 'lib/aws-sdk-medialive/types.rb', line 21079 class UpdateNetworkResult < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you specified for the Network.
21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 21089 |
# File 'lib/aws-sdk-medialive/types.rb', line 21079 class UpdateNetworkResult < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::Route>
An array of Routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 21089 |
# File 'lib/aws-sdk-medialive/types.rb', line 21079 class UpdateNetworkResult < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the Network. Only MediaLive Anywhere can change the state.
21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 21089 |
# File 'lib/aws-sdk-medialive/types.rb', line 21079 class UpdateNetworkResult < Struct.new( :arn, :associated_cluster_ids, :id, :ip_pools, :name, :routes, :state) SENSITIVE = [] include Aws::Structure end |