Class: Aws::MediaLive::Types::WebvttDestinationSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::MediaLive::Types::WebvttDestinationSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medialive/types.rb
Overview
Webvtt Destination Settings
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#position ⇒ Types::TextCaptionPositionSettings
Specifies the position of the output captions.
-
#style_control ⇒ String
Controls whether the color and position of the source captions is passed through to the WebVTT output captions.
Instance Attribute Details
#position ⇒ Types::TextCaptionPositionSettings
Specifies the position of the output captions. Applies only when styleControl is set to manual.
14285 14286 14287 14288 14289 14290 |
# File 'lib/aws-sdk-medialive/types.rb', line 14285 class WebvttDestinationSettings < Struct.new( :style_control, :position) SENSITIVE = [] include Aws::Structure end |
#style_control ⇒ String
Controls whether the color and position of the source captions is passed through to the WebVTT output captions. PASSTHROUGH - Valid only if the source captions are EMBEDDED, TELETEXT, or SMART SUBTITLES. NO_STYLE_DATA - Don't pass through the style. The output captions will not contain any font styling information. MANUAL - Applies the specified styling and positioning. All other styling and positioning is given default values.
14285 14286 14287 14288 14289 14290 |
# File 'lib/aws-sdk-medialive/types.rb', line 14285 class WebvttDestinationSettings < Struct.new( :style_control, :position) SENSITIVE = [] include Aws::Structure end |